/********************************************************************************
** Form generated from reading UI file 'invatedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INVATEDIALOG_H
#define UI_INVATEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_InvateDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QLabel *leJid;
    QLabel *label;
    QComboBox *cbResource;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *btnBlack;
    QPushButton *btnWhite;
    QPushButton *btnCancel;

    void setupUi(QDialog *InvateDialog)
    {
        if (InvateDialog->objectName().isEmpty())
            InvateDialog->setObjectName(QString::fromUtf8("InvateDialog"));
        InvateDialog->resize(413, 78);
        verticalLayout = new QVBoxLayout(InvateDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_2 = new QLabel(InvateDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        leJid = new QLabel(InvateDialog);
        leJid->setObjectName(QString::fromUtf8("leJid"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        leJid->setFont(font);

        horizontalLayout->addWidget(leJid);

        label = new QLabel(InvateDialog);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        cbResource = new QComboBox(InvateDialog);
        cbResource->setObjectName(QString::fromUtf8("cbResource"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbResource->sizePolicy().hasHeightForWidth());
        cbResource->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(cbResource);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        btnBlack = new QPushButton(InvateDialog);
        btnBlack->setObjectName(QString::fromUtf8("btnBlack"));

        horizontalLayout_2->addWidget(btnBlack);

        btnWhite = new QPushButton(InvateDialog);
        btnWhite->setObjectName(QString::fromUtf8("btnWhite"));

        horizontalLayout_2->addWidget(btnWhite);

        btnCancel = new QPushButton(InvateDialog);
        btnCancel->setObjectName(QString::fromUtf8("btnCancel"));

        horizontalLayout_2->addWidget(btnCancel);


        verticalLayout->addLayout(horizontalLayout_2);

        QWidget::setTabOrder(cbResource, btnBlack);
        QWidget::setTabOrder(btnBlack, btnWhite);
        QWidget::setTabOrder(btnWhite, btnCancel);

        retranslateUi(InvateDialog);
        QObject::connect(btnBlack, SIGNAL(clicked()), InvateDialog, SLOT(acceptBlack()));
        QObject::connect(btnWhite, SIGNAL(clicked()), InvateDialog, SLOT(acceptWhite()));
        QObject::connect(btnCancel, SIGNAL(clicked()), InvateDialog, SLOT(close()));

        QMetaObject::connectSlotsByName(InvateDialog);
    } // setupUi

    void retranslateUi(QDialog *InvateDialog)
    {
        InvateDialog->setWindowTitle(QCoreApplication::translate("InvateDialog", "Gomoku Game Plugin - Invite", nullptr));
        label_2->setText(QCoreApplication::translate("InvateDialog", "Opponent:", nullptr));
        leJid->setText(QString());
        label->setText(QCoreApplication::translate("InvateDialog", "Select resource:", nullptr));
        btnBlack->setText(QCoreApplication::translate("InvateDialog", "Play Black", nullptr));
        btnWhite->setText(QCoreApplication::translate("InvateDialog", "Play White", nullptr));
        btnCancel->setText(QCoreApplication::translate("InvateDialog", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InvateDialog: public Ui_InvateDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INVATEDIALOG_H
