/********************************************************************************
** Form generated from reading UI file 'skinsplugin.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKINSPLUGIN_H
#define UI_SKINSPLUGIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SkinsPlugin
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QListWidget *lw_skins;
    QVBoxLayout *verticalLayout;
    QPushButton *pb_preview;
    QPushButton *pb_update;
    QPushButton *pb_apply;
    QPushButton *pb_open;
    QPushButton *pb_remove;
    QSpacerItem *verticalSpacer;
    QCheckBox *cb_hack;
    QPushButton *pb_save;
    QPushButton *pb_create;
    QCheckBox *cb_backup;
    QLabel *lbl_wiki;

    void setupUi(QWidget *SkinsPlugin)
    {
        if (SkinsPlugin->objectName().isEmpty())
            SkinsPlugin->setObjectName(QString::fromUtf8("SkinsPlugin"));
        SkinsPlugin->resize(490, 336);
        verticalLayout_2 = new QVBoxLayout(SkinsPlugin);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        lw_skins = new QListWidget(SkinsPlugin);
        lw_skins->setObjectName(QString::fromUtf8("lw_skins"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lw_skins->sizePolicy().hasHeightForWidth());
        lw_skins->setSizePolicy(sizePolicy);
        lw_skins->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout->addWidget(lw_skins);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        pb_preview = new QPushButton(SkinsPlugin);
        pb_preview->setObjectName(QString::fromUtf8("pb_preview"));

        verticalLayout->addWidget(pb_preview);

        pb_update = new QPushButton(SkinsPlugin);
        pb_update->setObjectName(QString::fromUtf8("pb_update"));

        verticalLayout->addWidget(pb_update);

        pb_apply = new QPushButton(SkinsPlugin);
        pb_apply->setObjectName(QString::fromUtf8("pb_apply"));

        verticalLayout->addWidget(pb_apply);

        pb_open = new QPushButton(SkinsPlugin);
        pb_open->setObjectName(QString::fromUtf8("pb_open"));

        verticalLayout->addWidget(pb_open);

        pb_remove = new QPushButton(SkinsPlugin);
        pb_remove->setObjectName(QString::fromUtf8("pb_remove"));

        verticalLayout->addWidget(pb_remove);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        cb_hack = new QCheckBox(SkinsPlugin);
        cb_hack->setObjectName(QString::fromUtf8("cb_hack"));
        cb_hack->setEnabled(true);

        verticalLayout->addWidget(cb_hack);

        pb_save = new QPushButton(SkinsPlugin);
        pb_save->setObjectName(QString::fromUtf8("pb_save"));

        verticalLayout->addWidget(pb_save);

        pb_create = new QPushButton(SkinsPlugin);
        pb_create->setObjectName(QString::fromUtf8("pb_create"));

        verticalLayout->addWidget(pb_create);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        cb_backup = new QCheckBox(SkinsPlugin);
        cb_backup->setObjectName(QString::fromUtf8("cb_backup"));
        cb_backup->setChecked(true);
        cb_backup->setProperty("isOption", QVariant(false));

        verticalLayout_2->addWidget(cb_backup);

        lbl_wiki = new QLabel(SkinsPlugin);
        lbl_wiki->setObjectName(QString::fromUtf8("lbl_wiki"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lbl_wiki->sizePolicy().hasHeightForWidth());
        lbl_wiki->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(lbl_wiki);


        retranslateUi(SkinsPlugin);

        QMetaObject::connectSlotsByName(SkinsPlugin);
    } // setupUi

    void retranslateUi(QWidget *SkinsPlugin)
    {
        SkinsPlugin->setWindowTitle(QCoreApplication::translate("SkinsPlugin", "Form", nullptr));
#if QT_CONFIG(tooltip)
        SkinsPlugin->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pb_preview->setToolTip(QCoreApplication::translate("SkinsPlugin", "Preview skin", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_preview->setText(QCoreApplication::translate("SkinsPlugin", "Preview", nullptr));
#if QT_CONFIG(tooltip)
        pb_update->setToolTip(QCoreApplication::translate("SkinsPlugin", "Update skins list", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_update->setText(QCoreApplication::translate("SkinsPlugin", "Update", nullptr));
#if QT_CONFIG(tooltip)
        pb_apply->setToolTip(QCoreApplication::translate("SkinsPlugin", "Apply selected skin", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_apply->setText(QCoreApplication::translate("SkinsPlugin", "Apply", nullptr));
#if QT_CONFIG(tooltip)
        pb_open->setToolTip(QCoreApplication::translate("SkinsPlugin", "Open skin file", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_open->setText(QCoreApplication::translate("SkinsPlugin", "Open", nullptr));
#if QT_CONFIG(tooltip)
        pb_remove->setToolTip(QCoreApplication::translate("SkinsPlugin", "Remove selected skin", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_remove->setText(QCoreApplication::translate("SkinsPlugin", "Remove", nullptr));
        cb_hack->setText(QString());
#if QT_CONFIG(tooltip)
        pb_save->setToolTip(QCoreApplication::translate("SkinsPlugin", "Overwrite selected skin with the current settings ", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_save->setText(QCoreApplication::translate("SkinsPlugin", "Save", nullptr));
#if QT_CONFIG(tooltip)
        pb_create->setToolTip(QCoreApplication::translate("SkinsPlugin", "Create new skin from current settings", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_create->setText(QCoreApplication::translate("SkinsPlugin", "Create", nullptr));
        cb_backup->setText(QCoreApplication::translate("SkinsPlugin", "Backup skin before applying", nullptr));
        lbl_wiki->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class SkinsPlugin: public Ui_SkinsPlugin {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SKINSPLUGIN_H
