/****************************************************************************
** Meta object code from reading C++ file 'jd_mainwin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../jd_mainwin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jd_mainwin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_JDMainWin_t {
    QByteArrayData data[17];
    char stringdata0[176];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_JDMainWin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_JDMainWin_t qt_meta_stringdata_JDMainWin = {
    {
QT_MOC_LITERAL(0, 0, 9), // "JDMainWin"
QT_MOC_LITERAL(1, 10, 15), // "incomingMessage"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 7), // "message"
QT_MOC_LITERAL(4, 35, 19), // "JDCommands::Command"
QT_MOC_LITERAL(5, 55, 7), // "command"
QT_MOC_LITERAL(6, 63, 7), // "refresh"
QT_MOC_LITERAL(7, 71, 6), // "doSend"
QT_MOC_LITERAL(8, 78, 15), // "outgoingMessage"
QT_MOC_LITERAL(9, 94, 12), // "indexChanged"
QT_MOC_LITERAL(10, 107, 11), // "QModelIndex"
QT_MOC_LITERAL(11, 119, 5), // "index"
QT_MOC_LITERAL(12, 125, 16), // "indexContextMenu"
QT_MOC_LITERAL(13, 142, 8), // "moveItem"
QT_MOC_LITERAL(14, 151, 7), // "oldPath"
QT_MOC_LITERAL(15, 159, 7), // "newPath"
QT_MOC_LITERAL(16, 167, 8) // "clearLog"

    },
    "JDMainWin\0incomingMessage\0\0message\0"
    "JDCommands::Command\0command\0refresh\0"
    "doSend\0outgoingMessage\0indexChanged\0"
    "QModelIndex\0index\0indexContextMenu\0"
    "moveItem\0oldPath\0newPath\0clearLog"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_JDMainWin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x08 /* Private */,
       6,    0,   59,    2, 0x08 /* Private */,
       7,    0,   60,    2, 0x08 /* Private */,
       8,    1,   61,    2, 0x08 /* Private */,
       9,    1,   64,    2, 0x08 /* Private */,
      12,    1,   67,    2, 0x08 /* Private */,
      13,    2,   70,    2, 0x08 /* Private */,
      16,    0,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
    QMetaType::Void,

       0        // eod
};

void JDMainWin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<JDMainWin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->incomingMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< JDCommands::Command(*)>(_a[2]))); break;
        case 1: _t->refresh(); break;
        case 2: _t->doSend(); break;
        case 3: _t->outgoingMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->indexChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 5: _t->indexContextMenu((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 6: _t->moveItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->clearLog(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject JDMainWin::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_JDMainWin.data,
    qt_meta_data_JDMainWin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *JDMainWin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JDMainWin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_JDMainWin.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int JDMainWin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
