/********************************************************************************
** Form generated from reading UI file 'icqdieoptions.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ICQDIEOPTIONS_H
#define UI_ICQDIEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_options
{
public:
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTextEdit *messageRecv;
    QLabel *label_2;
    QTextEdit *messageNoRecv;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_3;
    QTextEdit *custom;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *pauseWidget;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer;
    QSpinBox *messageCount;
    QCheckBox *activetabWidget;
    QSpacerItem *verticalSpacer;
    QLabel *label_7;
    QTextEdit *transportsWidget;
    QLabel *wiki;

    void setupUi(QWidget *options)
    {
        if (options->objectName().isEmpty())
            options->setObjectName(QString::fromUtf8("options"));
        options->resize(575, 489);
        verticalLayout_4 = new QVBoxLayout(options);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(options);
        label->setObjectName(QString::fromUtf8("label"));
        label->setTextFormat(Qt::PlainText);

        verticalLayout->addWidget(label);

        messageRecv = new QTextEdit(options);
        messageRecv->setObjectName(QString::fromUtf8("messageRecv"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(messageRecv->sizePolicy().hasHeightForWidth());
        messageRecv->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(messageRecv);

        label_2 = new QLabel(options);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setTextFormat(Qt::PlainText);

        verticalLayout->addWidget(label_2);

        messageNoRecv = new QTextEdit(options);
        messageNoRecv->setObjectName(QString::fromUtf8("messageNoRecv"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(messageNoRecv->sizePolicy().hasHeightForWidth());
        messageNoRecv->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(messageNoRecv);


        verticalLayout_4->addLayout(verticalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label_3 = new QLabel(options);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        verticalLayout_2->addWidget(label_3);

        custom = new QTextEdit(options);
        custom->setObjectName(QString::fromUtf8("custom"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(custom->sizePolicy().hasHeightForWidth());
        custom->setSizePolicy(sizePolicy2);

        verticalLayout_2->addWidget(custom);


        horizontalLayout_2->addLayout(verticalLayout_2);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_4 = new QLabel(options);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setTextFormat(Qt::PlainText);

        horizontalLayout->addWidget(label_4);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        pauseWidget = new QSpinBox(options);
        pauseWidget->setObjectName(QString::fromUtf8("pauseWidget"));
        pauseWidget->setMinimum(1);
        pauseWidget->setMaximum(2000);

        horizontalLayout->addWidget(pauseWidget);

        label_5 = new QLabel(options);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout->addWidget(label_5);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_6 = new QLabel(options);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        horizontalLayout_3->addWidget(label_6);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        messageCount = new QSpinBox(options);
        messageCount->setObjectName(QString::fromUtf8("messageCount"));
        messageCount->setMaximumSize(QSize(182, 16777215));

        horizontalLayout_3->addWidget(messageCount);


        verticalLayout_3->addLayout(horizontalLayout_3);

        activetabWidget = new QCheckBox(options);
        activetabWidget->setObjectName(QString::fromUtf8("activetabWidget"));

        verticalLayout_3->addWidget(activetabWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        label_7 = new QLabel(options);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        verticalLayout_3->addWidget(label_7);

        transportsWidget = new QTextEdit(options);
        transportsWidget->setObjectName(QString::fromUtf8("transportsWidget"));
        transportsWidget->setEnabled(true);
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(1);
        sizePolicy3.setHeightForWidth(transportsWidget->sizePolicy().hasHeightForWidth());
        transportsWidget->setSizePolicy(sizePolicy3);

        verticalLayout_3->addWidget(transportsWidget);


        horizontalLayout_2->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout_2);

        wiki = new QLabel(options);
        wiki->setObjectName(QString::fromUtf8("wiki"));

        verticalLayout_4->addWidget(wiki);


        retranslateUi(options);

        QMetaObject::connectSlotsByName(options);
    } // setupUi

    void retranslateUi(QWidget *options)
    {
        options->setWindowTitle(QCoreApplication::translate("options", "Form", nullptr));
        label->setText(QCoreApplication::translate("options", "Auto Reply Message If Recv:", nullptr));
        label_2->setText(QCoreApplication::translate("options", "Auto Reply Message If No Recv:", nullptr));
        label_3->setText(QCoreApplication::translate("options", "Custom options:\n"
"-uin - do nothing\n"
"+uin - send replay\n"
"!uin - block message\n"
"[-+!]other - default\n"
"[-+!]nil - not in list\n"
"# - comment to end line", nullptr));
        label_4->setText(QCoreApplication::translate("options", "Pause for next Recv message:", nullptr));
        label_5->setText(QCoreApplication::translate("options", "min.", nullptr));
        label_6->setText(QCoreApplication::translate("options", "Max messages to contact:", nullptr));
        activetabWidget->setText(QCoreApplication::translate("options", "Disable if chat window is active", nullptr));
        label_7->setText(QCoreApplication::translate("options", "Transports:", nullptr));
        wiki->setText(QCoreApplication::translate("options", "<a href=\"http://code.google.com/p/psi-dev/wiki/plugins#ICQ_Must_Die_Plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class options: public Ui_options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ICQDIEOPTIONS_H
