/********************************************************************************
** Form generated from reading UI file 'previewer.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREVIEWER_H
#define UI_PREVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_Previewer
{
public:
    QHBoxLayout *horizontalLayout_2;
    QLabel *lbl_preview;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *lbl_name;
    QLabel *label_2;
    QLabel *lbl_author;
    QLabel *label_3;
    QLabel *lbl_version;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QPushButton *pb_apply;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_close;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *Previewer)
    {
        if (Previewer->objectName().isEmpty())
            Previewer->setObjectName(QString::fromUtf8("Previewer"));
        Previewer->resize(441, 385);
        horizontalLayout_2 = new QHBoxLayout(Previewer);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        lbl_preview = new QLabel(Previewer);
        lbl_preview->setObjectName(QString::fromUtf8("lbl_preview"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lbl_preview->sizePolicy().hasHeightForWidth());
        lbl_preview->setSizePolicy(sizePolicy);
        lbl_preview->setAlignment(Qt::AlignCenter);

        horizontalLayout_2->addWidget(lbl_preview);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(Previewer);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lbl_name = new QLabel(Previewer);
        lbl_name->setObjectName(QString::fromUtf8("lbl_name"));

        gridLayout->addWidget(lbl_name, 0, 1, 1, 1);

        label_2 = new QLabel(Previewer);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        lbl_author = new QLabel(Previewer);
        lbl_author->setObjectName(QString::fromUtf8("lbl_author"));

        gridLayout->addWidget(lbl_author, 1, 1, 1, 1);

        label_3 = new QLabel(Previewer);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        lbl_version = new QLabel(Previewer);
        lbl_version->setObjectName(QString::fromUtf8("lbl_version"));

        gridLayout->addWidget(lbl_version, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pb_apply = new QPushButton(Previewer);
        pb_apply->setObjectName(QString::fromUtf8("pb_apply"));

        horizontalLayout->addWidget(pb_apply);

        horizontalSpacer = new QSpacerItem(0, 10, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pb_close = new QPushButton(Previewer);
        pb_close->setObjectName(QString::fromUtf8("pb_close"));

        horizontalLayout->addWidget(pb_close);

        horizontalSpacer_2 = new QSpacerItem(0, 10, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout);


        retranslateUi(Previewer);

        QMetaObject::connectSlotsByName(Previewer);
    } // setupUi

    void retranslateUi(QDialog *Previewer)
    {
        Previewer->setWindowTitle(QCoreApplication::translate("Previewer", "Preview Skin", nullptr));
        lbl_preview->setText(QCoreApplication::translate("Previewer", "Preview unavailable", nullptr));
        label->setText(QCoreApplication::translate("Previewer", "Name: ", nullptr));
        lbl_name->setText(QString());
        label_2->setText(QCoreApplication::translate("Previewer", "Author: ", nullptr));
        lbl_author->setText(QString());
        label_3->setText(QCoreApplication::translate("Previewer", "Version: ", nullptr));
        lbl_version->setText(QString());
        pb_apply->setText(QCoreApplication::translate("Previewer", "Apply", nullptr));
        pb_close->setText(QCoreApplication::translate("Previewer", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Previewer: public Ui_Previewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREVIEWER_H
