/****************************************************************************
** Meta object code from reading C++ file 'psiotrplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/psiotrplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'psiotrplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_psiotr__PsiOtrPlugin_t {
    QByteArrayData data[3];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_psiotr__PsiOtrPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_psiotr__PsiOtrPlugin_t qt_meta_stringdata_psiotr__PsiOtrPlugin = {
    {
QT_MOC_LITERAL(0, 0, 20), // "psiotr::PsiOtrPlugin"
QT_MOC_LITERAL(1, 21, 14), // "eventActivated"
QT_MOC_LITERAL(2, 36, 0) // ""

    },
    "psiotr::PsiOtrPlugin\0eventActivated\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_psiotr__PsiOtrPlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void psiotr::PsiOtrPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PsiOtrPlugin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->eventActivated(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject psiotr::PsiOtrPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_psiotr__PsiOtrPlugin.data,
    qt_meta_data_psiotr__PsiOtrPlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *psiotr::PsiOtrPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *psiotr::PsiOtrPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_psiotr__PsiOtrPlugin.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PsiPlugin"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "PluginInfoProvider"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "EventFilter"))
        return static_cast< EventFilter*>(this);
    if (!strcmp(_clname, "EventCreator"))
        return static_cast< EventCreator*>(this);
    if (!strcmp(_clname, "OptionAccessor"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "StanzaSender"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "ApplicationInfoAccessor"))
        return static_cast< ApplicationInfoAccessor*>(this);
    if (!strcmp(_clname, "PsiAccountController"))
        return static_cast< PsiAccountController*>(this);
    if (!strcmp(_clname, "StanzaFilter"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "ToolbarIconAccessor"))
        return static_cast< ToolbarIconAccessor*>(this);
    if (!strcmp(_clname, "AccountInfoAccessor"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "ContactInfoAccessor"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "IconFactoryAccessor"))
        return static_cast< IconFactoryAccessor*>(this);
    if (!strcmp(_clname, "OtrCallback"))
        return static_cast< OtrCallback*>(this);
    if (!strcmp(_clname, "org.psi-im.PsiPlugin/0.4"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "org.psi-im.PluginInfoProvider/0.1"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "org.psi-im.EventFilter/0.1"))
        return static_cast< EventFilter*>(this);
    if (!strcmp(_clname, "org.psi-im.EventCreator/0.1"))
        return static_cast< EventCreator*>(this);
    if (!strcmp(_clname, "org.psi-im.OptionAccessor/0.1"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaSender/0.1"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "org.psi-im.ApplicationInfoAccessor/0.1"))
        return static_cast< ApplicationInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.PsiAccountController/0.1"))
        return static_cast< PsiAccountController*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaFilter/0.1"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "org.psi-im.ToolbarIconAccessor/0.1"))
        return static_cast< ToolbarIconAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.AccountInfoAccessor/0.1"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.ContactInfoAccessor/0.1"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.IconFactoryAccessor/0.1"))
        return static_cast< IconFactoryAccessor*>(this);
    return QObject::qt_metacast(_clname);
}

int psiotr::PsiOtrPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

QT_PLUGIN_METADATA_SECTION
static constexpr unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x19,  'c',  'o',  'm',  '.',  'p', 
    's',  'i',  '-',  'p',  'l',  'u',  's',  '.', 
    'P',  's',  'i',  'O',  't',  'r',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x6c,  'P',  's',  'i',  'O',  't',  'r', 
    'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
using namespace psiotr;
QT_MOC_EXPORT_PLUGIN(psiotr::PsiOtrPlugin, PsiOtrPlugin)

QT_WARNING_POP
QT_END_MOC_NAMESPACE
