/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QPushButton *pb_update;
    QPushButton *pb_clear_cache;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_check;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QSpinBox *sb_start;
    QLabel *label_3;
    QLabel *label_4;
    QSpinBox *sb_check_interval;
    QLabel *label_5;
    QLabel *label_6;
    QSpinBox *sb_update_interval;
    QLabel *label_7;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *cb_active_accounts;
    QCheckBox *cb_startupcheck;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_8;
    QLineEdit *le_sound;
    QToolButton *tb_get;
    QToolButton *tb_check;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;
    QLabel *wiki;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(528, 312);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(Options);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pb_update = new QPushButton(Options);
        pb_update->setObjectName(QString::fromUtf8("pb_update"));

        horizontalLayout->addWidget(pb_update);

        pb_clear_cache = new QPushButton(Options);
        pb_clear_cache->setObjectName(QString::fromUtf8("pb_clear_cache"));

        horizontalLayout->addWidget(pb_clear_cache);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pb_check = new QPushButton(Options);
        pb_check->setObjectName(QString::fromUtf8("pb_check"));

        horizontalLayout->addWidget(pb_check);


        verticalLayout->addLayout(horizontalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_2 = new QLabel(Options);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        sb_start = new QSpinBox(Options);
        sb_start->setObjectName(QString::fromUtf8("sb_start"));
        sb_start->setMinimum(2);
        sb_start->setMaximum(60);

        gridLayout->addWidget(sb_start, 0, 1, 1, 1);

        label_3 = new QLabel(Options);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 0, 2, 1, 1);

        label_4 = new QLabel(Options);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        sb_check_interval = new QSpinBox(Options);
        sb_check_interval->setObjectName(QString::fromUtf8("sb_check_interval"));
        sb_check_interval->setMaximum(24);

        gridLayout->addWidget(sb_check_interval, 1, 1, 1, 1);

        label_5 = new QLabel(Options);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 1, 2, 1, 1);

        label_6 = new QLabel(Options);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        sb_update_interval = new QSpinBox(Options);
        sb_update_interval->setObjectName(QString::fromUtf8("sb_update_interval"));

        gridLayout->addWidget(sb_update_interval, 2, 1, 1, 1);

        label_7 = new QLabel(Options);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 2, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        cb_active_accounts = new QCheckBox(Options);
        cb_active_accounts->setObjectName(QString::fromUtf8("cb_active_accounts"));

        verticalLayout->addWidget(cb_active_accounts);

        cb_startupcheck = new QCheckBox(Options);
        cb_startupcheck->setObjectName(QString::fromUtf8("cb_startupcheck"));

        verticalLayout->addWidget(cb_startupcheck);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_8 = new QLabel(Options);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        horizontalLayout_2->addWidget(label_8);

        le_sound = new QLineEdit(Options);
        le_sound->setObjectName(QString::fromUtf8("le_sound"));

        horizontalLayout_2->addWidget(le_sound);

        tb_get = new QToolButton(Options);
        tb_get->setObjectName(QString::fromUtf8("tb_get"));

        horizontalLayout_2->addWidget(tb_get);

        tb_check = new QToolButton(Options);
        tb_check->setObjectName(QString::fromUtf8("tb_check"));

        horizontalLayout_2->addWidget(tb_check);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        wiki = new QLabel(Options);
        wiki->setObjectName(QString::fromUtf8("wiki"));
        wiki->setOpenExternalLinks(true);

        verticalLayout->addWidget(wiki);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        label->setText(QCoreApplication::translate("Options", "If you use this plugin at first time, make sure that all your accounts\n"
"is online and then press \"Update Birthdays\" button. It takes some time.", nullptr));
        pb_update->setText(QCoreApplication::translate("Options", "Update Birthdays", nullptr));
        pb_clear_cache->setText(QCoreApplication::translate("Options", "Clear Birthdays Cache", nullptr));
        pb_check->setText(QCoreApplication::translate("Options", "Check Birthdays", nullptr));
        label_2->setText(QCoreApplication::translate("Options", "Start notifying", nullptr));
        label_3->setText(QCoreApplication::translate("Options", "days in advance", nullptr));
        label_4->setText(QCoreApplication::translate("Options", "Check birthdays every", nullptr));
        label_5->setText(QCoreApplication::translate("Options", "hours", nullptr));
        label_6->setText(QCoreApplication::translate("Options", "Update birthdays every", nullptr));
        label_7->setText(QCoreApplication::translate("Options", "days (0 - automatic update disabled)", nullptr));
        cb_active_accounts->setText(QCoreApplication::translate("Options", "Remind for contacts from active accounts only", nullptr));
        cb_startupcheck->setText(QCoreApplication::translate("Options", "Check birthdays on startup", nullptr));
        label_8->setText(QCoreApplication::translate("Options", "Play sound:", nullptr));
        tb_get->setText(QString());
        tb_check->setText(QString());
        wiki->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#birthday_reminder_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
