/********************************************************************************
** Form generated from reading UI file 'edititemdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITITEMDLG_H
#define UI_EDITITEMDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditItemDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QRadioButton *rb_jid;
    QLineEdit *le_jid;
    QRadioButton *rb_text;
    QTextEdit *te_text;
    QLabel *label_2;
    QLabel *label_3;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *rb_chat;
    QRadioButton *rb_groupchat;
    QCheckBox *cb_always_play;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *le_sound;
    QToolButton *tb_open;
    QToolButton *tb_test;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditItemDlg)
    {
        if (EditItemDlg->objectName().isEmpty())
            EditItemDlg->setObjectName(QString::fromUtf8("EditItemDlg"));
        EditItemDlg->resize(352, 467);
        EditItemDlg->setModal(true);
        verticalLayout = new QVBoxLayout(EditItemDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        rb_jid = new QRadioButton(EditItemDlg);
        rb_jid->setObjectName(QString::fromUtf8("rb_jid"));
        rb_jid->setChecked(true);

        gridLayout->addWidget(rb_jid, 0, 0, 1, 2);

        le_jid = new QLineEdit(EditItemDlg);
        le_jid->setObjectName(QString::fromUtf8("le_jid"));

        gridLayout->addWidget(le_jid, 0, 2, 1, 1);

        rb_text = new QRadioButton(EditItemDlg);
        rb_text->setObjectName(QString::fromUtf8("rb_text"));

        gridLayout->addWidget(rb_text, 1, 0, 1, 2);

        te_text = new QTextEdit(EditItemDlg);
        te_text->setObjectName(QString::fromUtf8("te_text"));
        te_text->setEnabled(false);

        gridLayout->addWidget(te_text, 1, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        label_2 = new QLabel(EditItemDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        QFont font;
        font.setFamily(QString::fromUtf8("Andale Mono"));
        font.setPointSize(8);
        label_2->setFont(font);

        verticalLayout->addWidget(label_2);

        label_3 = new QLabel(EditItemDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setFont(font);

        verticalLayout->addWidget(label_3);

        groupBox = new QGroupBox(EditItemDlg);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        horizontalLayout_2 = new QHBoxLayout(groupBox);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        rb_chat = new QRadioButton(groupBox);
        rb_chat->setObjectName(QString::fromUtf8("rb_chat"));
        rb_chat->setChecked(true);

        horizontalLayout_2->addWidget(rb_chat);

        rb_groupchat = new QRadioButton(groupBox);
        rb_groupchat->setObjectName(QString::fromUtf8("rb_groupchat"));

        horizontalLayout_2->addWidget(rb_groupchat);


        verticalLayout->addWidget(groupBox);

        cb_always_play = new QCheckBox(EditItemDlg);
        cb_always_play->setObjectName(QString::fromUtf8("cb_always_play"));

        verticalLayout->addWidget(cb_always_play);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(EditItemDlg);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        le_sound = new QLineEdit(EditItemDlg);
        le_sound->setObjectName(QString::fromUtf8("le_sound"));

        horizontalLayout->addWidget(le_sound);

        tb_open = new QToolButton(EditItemDlg);
        tb_open->setObjectName(QString::fromUtf8("tb_open"));

        horizontalLayout->addWidget(tb_open);

        tb_test = new QToolButton(EditItemDlg);
        tb_test->setObjectName(QString::fromUtf8("tb_test"));

        horizontalLayout->addWidget(tb_test);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(EditItemDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditItemDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), EditItemDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), EditItemDlg, SLOT(close()));
        QObject::connect(rb_jid, SIGNAL(toggled(bool)), le_jid, SLOT(setEnabled(bool)));
        QObject::connect(rb_text, SIGNAL(toggled(bool)), te_text, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(EditItemDlg);
    } // setupUi

    void retranslateUi(QDialog *EditItemDlg)
    {
        EditItemDlg->setWindowTitle(QCoreApplication::translate("EditItemDlg", "Watch For...", nullptr));
        rb_jid->setText(QCoreApplication::translate("EditItemDlg", "JID*", nullptr));
        rb_text->setText(QCoreApplication::translate("EditItemDlg", "Text**", nullptr));
        label_2->setText(QCoreApplication::translate("EditItemDlg", "*Regular expressions can be used", nullptr));
        label_3->setText(QCoreApplication::translate("EditItemDlg", "**List of words can be used.\n"
"  Each word can use regular expression", nullptr));
        groupBox->setTitle(QCoreApplication::translate("EditItemDlg", "Use for", nullptr));
        rb_chat->setText(QCoreApplication::translate("EditItemDlg", "Chats", nullptr));
        rb_groupchat->setText(QCoreApplication::translate("EditItemDlg", "Groupchats", nullptr));
        cb_always_play->setText(QCoreApplication::translate("EditItemDlg", "Always play sound", nullptr));
        label->setText(QCoreApplication::translate("EditItemDlg", "Sound:", nullptr));
        tb_open->setText(QString());
        tb_test->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class EditItemDlg: public Ui_EditItemDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITITEMDLG_H
