/********************************************************************************
** Form generated from reading UI file 'screenshotoptions.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCREENSHOTOPTIONS_H
#define UI_SCREENSHOTOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ScreenshotOptions
{
public:
    QVBoxLayout *verticalLayout;
    QRadioButton *rb_capture_desktop;
    QRadioButton *rb_capture_window;
    QRadioButton *rb_capture_area;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *sb_delay;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ScreenshotOptions)
    {
        if (ScreenshotOptions->objectName().isEmpty())
            ScreenshotOptions->setObjectName(QString::fromUtf8("ScreenshotOptions"));
        ScreenshotOptions->setWindowModality(Qt::WindowModal);
        ScreenshotOptions->resize(256, 173);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ScreenshotOptions->sizePolicy().hasHeightForWidth());
        ScreenshotOptions->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ScreenshotOptions);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        rb_capture_desktop = new QRadioButton(ScreenshotOptions);
        rb_capture_desktop->setObjectName(QString::fromUtf8("rb_capture_desktop"));
        rb_capture_desktop->setChecked(true);

        verticalLayout->addWidget(rb_capture_desktop);

        rb_capture_window = new QRadioButton(ScreenshotOptions);
        rb_capture_window->setObjectName(QString::fromUtf8("rb_capture_window"));

        verticalLayout->addWidget(rb_capture_window);

        rb_capture_area = new QRadioButton(ScreenshotOptions);
        rb_capture_area->setObjectName(QString::fromUtf8("rb_capture_area"));

        verticalLayout->addWidget(rb_capture_area);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(ScreenshotOptions);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        sb_delay = new QSpinBox(ScreenshotOptions);
        sb_delay->setObjectName(QString::fromUtf8("sb_delay"));

        horizontalLayout->addWidget(sb_delay);

        label_2 = new QLabel(ScreenshotOptions);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(ScreenshotOptions);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(ScreenshotOptions);

        QMetaObject::connectSlotsByName(ScreenshotOptions);
    } // setupUi

    void retranslateUi(QDialog *ScreenshotOptions)
    {
        ScreenshotOptions->setWindowTitle(QCoreApplication::translate("ScreenshotOptions", "New Screenshot", nullptr));
        rb_capture_desktop->setText(QCoreApplication::translate("ScreenshotOptions", "Capture the desktop", nullptr));
        rb_capture_window->setText(QCoreApplication::translate("ScreenshotOptions", "Capture current window", nullptr));
        rb_capture_area->setText(QCoreApplication::translate("ScreenshotOptions", "Select capture area", nullptr));
        label->setText(QCoreApplication::translate("ScreenshotOptions", "Capture after", nullptr));
        label_2->setText(QCoreApplication::translate("ScreenshotOptions", "seconds", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ScreenshotOptions: public Ui_ScreenshotOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SCREENSHOTOPTIONS_H
