/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *cb_fullScreen;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *cb_status;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QLineEdit *le_message;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *cb_online;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_4;
    QSpinBox *sb_setDelay;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    QSpinBox *sb_restoreDelay;
    QSpacerItem *horizontalSpacer_3;
    QLabel *lb_wiki;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OptionsWidget)
    {
        if (OptionsWidget->objectName().isEmpty())
            OptionsWidget->setObjectName(QString::fromUtf8("OptionsWidget"));
        OptionsWidget->resize(424, 351);
        verticalLayout = new QVBoxLayout(OptionsWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBox = new QGroupBox(OptionsWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));

        verticalLayout->addWidget(groupBox);

        cb_fullScreen = new QCheckBox(OptionsWidget);
        cb_fullScreen->setObjectName(QString::fromUtf8("cb_fullScreen"));

        verticalLayout->addWidget(cb_fullScreen);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(OptionsWidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        cb_status = new QComboBox(OptionsWidget);
        cb_status->setObjectName(QString::fromUtf8("cb_status"));

        horizontalLayout->addWidget(cb_status);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_2 = new QLabel(OptionsWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_2->addWidget(label_2);

        le_message = new QLineEdit(OptionsWidget);
        le_message->setObjectName(QString::fromUtf8("le_message"));

        horizontalLayout_2->addWidget(le_message);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        cb_online = new QCheckBox(OptionsWidget);
        cb_online->setObjectName(QString::fromUtf8("cb_online"));

        verticalLayout->addWidget(cb_online);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalLayout_4->setSizeConstraint(QLayout::SetDefaultConstraint);
        label_4 = new QLabel(OptionsWidget);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout_4->addWidget(label_4);

        sb_setDelay = new QSpinBox(OptionsWidget);
        sb_setDelay->setObjectName(QString::fromUtf8("sb_setDelay"));
        sb_setDelay->setMinimum(1);
        sb_setDelay->setMaximum(300);

        horizontalLayout_4->addWidget(sb_setDelay);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_3 = new QLabel(OptionsWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_3->addWidget(label_3);

        sb_restoreDelay = new QSpinBox(OptionsWidget);
        sb_restoreDelay->setObjectName(QString::fromUtf8("sb_restoreDelay"));
        sb_restoreDelay->setMinimum(1);
        sb_restoreDelay->setMaximum(300);

        horizontalLayout_3->addWidget(sb_restoreDelay);

        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_3);

        lb_wiki = new QLabel(OptionsWidget);
        lb_wiki->setObjectName(QString::fromUtf8("lb_wiki"));
        lb_wiki->setOpenExternalLinks(true);

        verticalLayout->addWidget(lb_wiki);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OptionsWidget);
        QObject::connect(cb_online, SIGNAL(toggled(bool)), sb_restoreDelay, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(OptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *OptionsWidget)
    {
        OptionsWidget->setWindowTitle(QCoreApplication::translate("OptionsWidget", "Form", nullptr));
        groupBox->setTitle(QCoreApplication::translate("OptionsWidget", "Enable for players:", nullptr));
        cb_fullScreen->setText(QCoreApplication::translate("OptionsWidget", "Detect full screen applications", nullptr));
        label->setText(QCoreApplication::translate("OptionsWidget", "Set status:", nullptr));
        label_2->setText(QCoreApplication::translate("OptionsWidget", "Status message:", nullptr));
        cb_online->setText(QCoreApplication::translate("OptionsWidget", "Restore old status if player stops", nullptr));
        label_4->setText(QCoreApplication::translate("OptionsWidget", "Delay before setting status, sec", nullptr));
        label_3->setText(QCoreApplication::translate("OptionsWidget", "Delay before restoring status, sec", nullptr));
        lb_wiki->setText(QCoreApplication::translate("OptionsWidget", "<a href=\"http://psi-plus.com/wiki/plugins#video_status_changer_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OptionsWidget: public Ui_OptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
