/********************************************************************************
** Form generated from reading UI file 'getskinname.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GETSKINNAME_H
#define UI_GETSKINNAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_GetSkinName
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QLineEdit *le_author;
    QLabel *label_3;
    QLineEdit *le_version;
    QLineEdit *le_name;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_ok;
    QPushButton *pb_cancel;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *GetSkinName)
    {
        if (GetSkinName->objectName().isEmpty())
            GetSkinName->setObjectName(QString::fromUtf8("GetSkinName"));
        GetSkinName->setWindowModality(Qt::WindowModal);
        GetSkinName->resize(231, 146);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GetSkinName->sizePolicy().hasHeightForWidth());
        GetSkinName->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(GetSkinName);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(GetSkinName);
        label->setObjectName(QString::fromUtf8("label"));
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(GetSkinName);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 3);

        le_author = new QLineEdit(GetSkinName);
        le_author->setObjectName(QString::fromUtf8("le_author"));

        gridLayout->addWidget(le_author, 1, 3, 1, 1);

        label_3 = new QLabel(GetSkinName);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 3);

        le_version = new QLineEdit(GetSkinName);
        le_version->setObjectName(QString::fromUtf8("le_version"));

        gridLayout->addWidget(le_version, 2, 3, 1, 1);

        le_name = new QLineEdit(GetSkinName);
        le_name->setObjectName(QString::fromUtf8("le_name"));

        gridLayout->addWidget(le_name, 0, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pb_ok = new QPushButton(GetSkinName);
        pb_ok->setObjectName(QString::fromUtf8("pb_ok"));

        horizontalLayout->addWidget(pb_ok);

        pb_cancel = new QPushButton(GetSkinName);
        pb_cancel->setObjectName(QString::fromUtf8("pb_cancel"));

        horizontalLayout->addWidget(pb_cancel);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        QWidget::setTabOrder(le_name, le_author);
        QWidget::setTabOrder(le_author, le_version);
        QWidget::setTabOrder(le_version, pb_ok);
        QWidget::setTabOrder(pb_ok, pb_cancel);

        retranslateUi(GetSkinName);

        QMetaObject::connectSlotsByName(GetSkinName);
    } // setupUi

    void retranslateUi(QDialog *GetSkinName)
    {
        GetSkinName->setWindowTitle(QCoreApplication::translate("GetSkinName", "Get Skin Name", nullptr));
        label->setText(QCoreApplication::translate("GetSkinName", "Name: ", nullptr));
        label_2->setText(QCoreApplication::translate("GetSkinName", "Author: ", nullptr));
        label_3->setText(QCoreApplication::translate("GetSkinName", "Version: ", nullptr));
        pb_ok->setText(QCoreApplication::translate("GetSkinName", "OK", nullptr));
        pb_cancel->setText(QCoreApplication::translate("GetSkinName", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GetSkinName: public Ui_GetSkinName {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GETSKINNAME_H
