/********************************************************************************
** Form generated from reading UI file 'editnote.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITNOTE_H
#define UI_EDITNOTE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditNote
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *le_title;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QLineEdit *le_tags;
    QPlainTextEdit *pte_text;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditNote)
    {
        if (EditNote->objectName().isEmpty())
            EditNote->setObjectName(QString::fromUtf8("EditNote"));
        EditNote->resize(261, 304);
        verticalLayout = new QVBoxLayout(EditNote);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(EditNote);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        le_title = new QLineEdit(EditNote);
        le_title->setObjectName(QString::fromUtf8("le_title"));

        horizontalLayout->addWidget(le_title);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_2 = new QLabel(EditNote);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_2->addWidget(label_2);

        le_tags = new QLineEdit(EditNote);
        le_tags->setObjectName(QString::fromUtf8("le_tags"));

        horizontalLayout_2->addWidget(le_tags);


        verticalLayout->addLayout(horizontalLayout_2);

        pte_text = new QPlainTextEdit(EditNote);
        pte_text->setObjectName(QString::fromUtf8("pte_text"));

        verticalLayout->addWidget(pte_text);

        buttonBox = new QDialogButtonBox(EditNote);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EditNote);

        QMetaObject::connectSlotsByName(EditNote);
    } // setupUi

    void retranslateUi(QDialog *EditNote)
    {
        EditNote->setWindowTitle(QCoreApplication::translate("EditNote", "Edit Note", nullptr));
        label->setText(QCoreApplication::translate("EditNote", "Title:", nullptr));
        label_2->setText(QCoreApplication::translate("EditNote", "Tags:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditNote: public Ui_EditNote {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITNOTE_H
