/****************************************************************************
** Meta object code from reading C++ file 'options.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../options.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'options.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Options_t {
    QByteArrayData data[17];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Options_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Options_t qt_meta_stringdata_Options = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Options"
QT_MOC_LITERAL(1, 8, 7), // "addRule"
QT_MOC_LITERAL(2, 16, 0), // ""
QT_MOC_LITERAL(3, 17, 10), // "removeRule"
QT_MOC_LITERAL(4, 28, 6), // "upRule"
QT_MOC_LITERAL(5, 35, 8), // "downRule"
QT_MOC_LITERAL(6, 44, 17), // "updateRuleButtons"
QT_MOC_LITERAL(7, 62, 12), // "addCondition"
QT_MOC_LITERAL(8, 75, 15), // "removeCondition"
QT_MOC_LITERAL(9, 91, 11), // "upCondition"
QT_MOC_LITERAL(10, 103, 13), // "downCondition"
QT_MOC_LITERAL(11, 117, 22), // "updateConditionButtons"
QT_MOC_LITERAL(12, 140, 14), // "updateRuleName"
QT_MOC_LITERAL(13, 155, 4), // "name"
QT_MOC_LITERAL(14, 160, 11), // "setRulePane"
QT_MOC_LITERAL(15, 172, 3), // "row"
QT_MOC_LITERAL(16, 176, 4) // "hack"

    },
    "Options\0addRule\0\0removeRule\0upRule\0"
    "downRule\0updateRuleButtons\0addCondition\0"
    "removeCondition\0upCondition\0downCondition\0"
    "updateConditionButtons\0updateRuleName\0"
    "name\0setRulePane\0row\0hack"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Options[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    0,   80,    2, 0x0a /* Public */,
       4,    0,   81,    2, 0x0a /* Public */,
       5,    0,   82,    2, 0x0a /* Public */,
       6,    0,   83,    2, 0x0a /* Public */,
       7,    0,   84,    2, 0x0a /* Public */,
       8,    0,   85,    2, 0x0a /* Public */,
       9,    0,   86,    2, 0x0a /* Public */,
      10,    0,   87,    2, 0x0a /* Public */,
      11,    0,   88,    2, 0x0a /* Public */,
      12,    1,   89,    2, 0x0a /* Public */,
      14,    1,   92,    2, 0x0a /* Public */,
      16,    0,   95,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void,

       0        // eod
};

void Options::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Options *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->addRule(); break;
        case 1: _t->removeRule(); break;
        case 2: _t->upRule(); break;
        case 3: _t->downRule(); break;
        case 4: _t->updateRuleButtons(); break;
        case 5: _t->addCondition(); break;
        case 6: _t->removeCondition(); break;
        case 7: _t->upCondition(); break;
        case 8: _t->downCondition(); break;
        case 9: _t->updateConditionButtons(); break;
        case 10: _t->updateRuleName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setRulePane((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->hack(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Options::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Options.data,
    qt_meta_data_Options,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Options::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Options::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Options.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Options::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
