/********************************************************************************
** Form generated from reading UI file 'editserverdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSERVERDLG_H
#define UI_EDITSERVERDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_EditServerDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *le_name;
    QLabel *label_2;
    QLineEdit *le_url;
    QLabel *label_3;
    QLineEdit *le_user;
    QLabel *label_4;
    QLineEdit *le_pass;
    QLabel *label_9;
    QLineEdit *le_post_data;
    QLabel *label_10;
    QLineEdit *le_file_input;
    QLabel *label_11;
    QLineEdit *le_regexp;
    QLabel *label_12;
    QLabel *label_13;
    QCheckBox *cb_proxy;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditServerDlg)
    {
        if (EditServerDlg->objectName().isEmpty())
            EditServerDlg->setObjectName(QString::fromUtf8("EditServerDlg"));
        EditServerDlg->resize(256, 359);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(EditServerDlg->sizePolicy().hasHeightForWidth());
        EditServerDlg->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(EditServerDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(EditServerDlg);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        le_name = new QLineEdit(EditServerDlg);
        le_name->setObjectName(QString::fromUtf8("le_name"));
        le_name->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_name, 0, 1, 1, 1);

        label_2 = new QLabel(EditServerDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        le_url = new QLineEdit(EditServerDlg);
        le_url->setObjectName(QString::fromUtf8("le_url"));
        le_url->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_url, 1, 1, 1, 1);

        label_3 = new QLabel(EditServerDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        le_user = new QLineEdit(EditServerDlg);
        le_user->setObjectName(QString::fromUtf8("le_user"));
        le_user->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_user, 2, 1, 1, 1);

        label_4 = new QLabel(EditServerDlg);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        le_pass = new QLineEdit(EditServerDlg);
        le_pass->setObjectName(QString::fromUtf8("le_pass"));
        le_pass->setMinimumSize(QSize(150, 0));
        le_pass->setEchoMode(QLineEdit::PasswordEchoOnEdit);

        gridLayout->addWidget(le_pass, 3, 1, 1, 1);

        label_9 = new QLabel(EditServerDlg);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout->addWidget(label_9, 4, 0, 1, 1);

        le_post_data = new QLineEdit(EditServerDlg);
        le_post_data->setObjectName(QString::fromUtf8("le_post_data"));
        le_post_data->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_post_data, 4, 1, 1, 1);

        label_10 = new QLabel(EditServerDlg);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout->addWidget(label_10, 5, 0, 1, 1);

        le_file_input = new QLineEdit(EditServerDlg);
        le_file_input->setObjectName(QString::fromUtf8("le_file_input"));
        le_file_input->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_file_input, 5, 1, 1, 1);

        label_11 = new QLabel(EditServerDlg);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        gridLayout->addWidget(label_11, 6, 0, 1, 1);

        le_regexp = new QLineEdit(EditServerDlg);
        le_regexp->setObjectName(QString::fromUtf8("le_regexp"));
        le_regexp->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(le_regexp, 6, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        label_12 = new QLabel(EditServerDlg);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        QFont font;
        font.setFamily(QString::fromUtf8("Andale Mono"));
        font.setPointSize(8);
        label_12->setFont(font);

        verticalLayout->addWidget(label_12);

        label_13 = new QLabel(EditServerDlg);
        label_13->setObjectName(QString::fromUtf8("label_13"));
        label_13->setFont(font);

        verticalLayout->addWidget(label_13);

        cb_proxy = new QCheckBox(EditServerDlg);
        cb_proxy->setObjectName(QString::fromUtf8("cb_proxy"));
        cb_proxy->setChecked(true);

        verticalLayout->addWidget(cb_proxy);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(EditServerDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(EditServerDlg);
        QObject::connect(buttonBox, SIGNAL(rejected()), EditServerDlg, SLOT(close()));

        QMetaObject::connectSlotsByName(EditServerDlg);
    } // setupUi

    void retranslateUi(QDialog *EditServerDlg)
    {
        EditServerDlg->setWindowTitle(QCoreApplication::translate("EditServerDlg", "Server Settings", nullptr));
        label->setText(QCoreApplication::translate("EditServerDlg", "Name:", nullptr));
        label_2->setText(QCoreApplication::translate("EditServerDlg", "Url:", nullptr));
        label_3->setText(QCoreApplication::translate("EditServerDlg", "User Name*:", nullptr));
        label_4->setText(QCoreApplication::translate("EditServerDlg", "Password*:", nullptr));
        label_9->setText(QCoreApplication::translate("EditServerDlg", "PostData**:", nullptr));
        label_10->setText(QCoreApplication::translate("EditServerDlg", "File Input**:", nullptr));
        label_11->setText(QCoreApplication::translate("EditServerDlg", "RegExp**:", nullptr));
        label_12->setText(QCoreApplication::translate("EditServerDlg", "*for FTP servers only", nullptr));
        label_13->setText(QCoreApplication::translate("EditServerDlg", "**for HTTP servers only", nullptr));
        cb_proxy->setText(QCoreApplication::translate("EditServerDlg", "Use proxy server", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditServerDlg: public Ui_EditServerDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITSERVERDLG_H
