/********************************************************************************
** Form generated from reading UI file 'invitedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INVITEDIALOG_H
#define UI_INVITEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_InviteDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *cb_resource;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *pb_white;
    QPushButton *pb_black;

    void setupUi(QDialog *InviteDialog)
    {
        if (InviteDialog->objectName().isEmpty())
            InviteDialog->setObjectName(QString::fromUtf8("InviteDialog"));
        InviteDialog->resize(221, 83);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InviteDialog->sizePolicy().hasHeightForWidth());
        InviteDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(InviteDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(InviteDialog);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        cb_resource = new QComboBox(InviteDialog);
        cb_resource->setObjectName(QString::fromUtf8("cb_resource"));
        sizePolicy.setHeightForWidth(cb_resource->sizePolicy().hasHeightForWidth());
        cb_resource->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(cb_resource);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        pb_white = new QPushButton(InviteDialog);
        pb_white->setObjectName(QString::fromUtf8("pb_white"));

        horizontalLayout_2->addWidget(pb_white);

        pb_black = new QPushButton(InviteDialog);
        pb_black->setObjectName(QString::fromUtf8("pb_black"));

        horizontalLayout_2->addWidget(pb_black);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(InviteDialog);

        QMetaObject::connectSlotsByName(InviteDialog);
    } // setupUi

    void retranslateUi(QDialog *InviteDialog)
    {
        InviteDialog->setWindowTitle(QCoreApplication::translate("InviteDialog", "Invitation", nullptr));
        label->setText(QCoreApplication::translate("InviteDialog", "Select resource:", nullptr));
        pb_white->setText(QCoreApplication::translate("InviteDialog", "Play White", nullptr));
        pb_black->setText(QCoreApplication::translate("InviteDialog", "Play Black", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InviteDialog: public Ui_InviteDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INVITEDIALOG_H
