/****************************************************************************
** Meta object code from reading C++ file 'gamesessions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../gamesessions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gamesessions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GameSessions_t {
    QByteArrayData data[27];
    char stringdata0[288];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GameSessions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GameSessions_t qt_meta_stringdata_GameSessions = {
    {
QT_MOC_LITERAL(0, 0, 12), // "GameSessions"
QT_MOC_LITERAL(1, 13, 10), // "sendStanza"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 13), // "doInviteEvent"
QT_MOC_LITERAL(4, 39, 11), // "const char*"
QT_MOC_LITERAL(5, 51, 7), // "doPopup"
QT_MOC_LITERAL(6, 59, 9), // "playSound"
QT_MOC_LITERAL(7, 69, 14), // "showInvitation"
QT_MOC_LITERAL(8, 84, 4), // "from"
QT_MOC_LITERAL(9, 89, 14), // "doInviteDialog"
QT_MOC_LITERAL(10, 104, 7), // "account"
QT_MOC_LITERAL(11, 112, 10), // "sendInvite"
QT_MOC_LITERAL(12, 123, 8), // "full_jid"
QT_MOC_LITERAL(13, 132, 7), // "element"
QT_MOC_LITERAL(14, 140, 12), // "cancelInvite"
QT_MOC_LITERAL(15, 153, 12), // "acceptInvite"
QT_MOC_LITERAL(16, 166, 12), // "rejectInvite"
QT_MOC_LITERAL(17, 179, 16), // "setSessionStatus"
QT_MOC_LITERAL(18, 196, 15), // "closeGameWindow"
QT_MOC_LITERAL(19, 212, 8), // "sendMove"
QT_MOC_LITERAL(20, 221, 11), // "switchColor"
QT_MOC_LITERAL(21, 233, 10), // "sendAccept"
QT_MOC_LITERAL(22, 244, 9), // "sendError"
QT_MOC_LITERAL(23, 254, 8), // "sendDraw"
QT_MOC_LITERAL(24, 263, 7), // "youLose"
QT_MOC_LITERAL(25, 271, 8), // "sendLoad"
QT_MOC_LITERAL(26, 280, 7) // "newGame"

    },
    "GameSessions\0sendStanza\0\0doInviteEvent\0"
    "const char*\0doPopup\0playSound\0"
    "showInvitation\0from\0doInviteDialog\0"
    "account\0sendInvite\0full_jid\0element\0"
    "cancelInvite\0acceptInvite\0rejectInvite\0"
    "setSessionStatus\0closeGameWindow\0"
    "sendMove\0switchColor\0sendAccept\0"
    "sendError\0sendDraw\0youLose\0sendLoad\0"
    "newGame"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GameSessions[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  114,    2, 0x06 /* Public */,
       3,    5,  119,    2, 0x06 /* Public */,
       5,    1,  130,    2, 0x06 /* Public */,
       6,    1,  133,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,  136,    2, 0x08 /* Private */,
       9,    2,  139,    2, 0x08 /* Private */,
      11,    3,  144,    2, 0x08 /* Private */,
      14,    2,  151,    2, 0x08 /* Private */,
      15,    2,  156,    2, 0x08 /* Private */,
      16,    2,  161,    2, 0x08 /* Private */,
      17,    1,  166,    2, 0x08 /* Private */,
      18,    5,  169,    2, 0x08 /* Private */,
      19,    2,  180,    2, 0x08 /* Private */,
      20,    0,  185,    2, 0x08 /* Private */,
      21,    0,  186,    2, 0x08 /* Private */,
      22,    0,  187,    2, 0x08 /* Private */,
      23,    0,  188,    2, 0x08 /* Private */,
      24,    0,  189,    2, 0x08 /* Private */,
      25,    1,  190,    2, 0x08 /* Private */,
      26,    0,  193,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QObjectStar, 0x80000000 | 4,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   10,    8,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QString,   10,   12,   13,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   10,   12,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

       0        // eod
};

void GameSessions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GameSessions *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sendStanza((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 1: _t->doInviteEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QObject*(*)>(_a[4])),(*reinterpret_cast< const char*(*)>(_a[5]))); break;
        case 2: _t->doPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->playSound((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->showInvitation((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->doInviteDialog((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 6: _t->sendInvite((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 7: _t->cancelInvite((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 8: _t->acceptInvite((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 9: _t->rejectInvite((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 10: _t->setSessionStatus((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->closeGameWindow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 12: _t->sendMove((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->switchColor(); break;
        case 14: _t->sendAccept(); break;
        case 15: _t->sendError(); break;
        case 16: _t->sendDraw(); break;
        case 17: _t->youLose(); break;
        case 18: _t->sendLoad((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 19: _t->newGame(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GameSessions::*)(int , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameSessions::sendStanza)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (GameSessions::*)(int , QString , QString , QObject * , const char * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameSessions::doInviteEvent)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (GameSessions::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameSessions::doPopup)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (GameSessions::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GameSessions::playSound)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject GameSessions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_GameSessions.data,
    qt_meta_data_GameSessions,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *GameSessions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameSessions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GameSessions.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GameSessions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void GameSessions::sendStanza(int _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void GameSessions::doInviteEvent(int _t1, QString _t2, QString _t3, QObject * _t4, const char * _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void GameSessions::doPopup(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void GameSessions::playSound(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
