/********************************************************************************
** Form generated from reading UI file 'screenshot.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCREENSHOT_H
#define UI_SCREENSHOT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "pixmapwidget.h"
#include "toolbar.h"

QT_BEGIN_NAMESPACE

class Ui_Screenshot
{
public:
    QAction *actionOpen_Image;
    QAction *actionSave;
    QAction *actionPrint;
    QAction *actionNew_Screenshot;
    QAction *actionExit;
    QAction *actionProxy_Settings;
    QAction *actionOptions;
    QAction *actionHistory;
    QAction *actionAbout_Qt;
    QAction *actionHome_page;
    QAction *actionUpload;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    PixmapWidget *lb_pixmap;
    QFrame *urlFrame;
    QHBoxLayout *horizontalLayout;
    QLabel *lb_url;
    QToolButton *tb_copyUrl;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *pb_cancel;
    QProgressBar *progressBar;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QComboBox *cb_servers;
    QToolButton *pb_upload;
    QToolButton *pb_save;
    QToolButton *pb_print;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *pb_open;
    QToolButton *pb_new_screenshot;
    ToolBar *tb_bar;
    QMenuBar *menuBar;
    QMenu *menuFile;
    QMenu *menuSettings;
    QMenu *menuAbout;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *Screenshot)
    {
        if (Screenshot->objectName().isEmpty())
            Screenshot->setObjectName(QString::fromUtf8("Screenshot"));
        Screenshot->resize(800, 600);
        Screenshot->setMinimumSize(QSize(0, 0));
        actionOpen_Image = new QAction(Screenshot);
        actionOpen_Image->setObjectName(QString::fromUtf8("actionOpen_Image"));
        actionSave = new QAction(Screenshot);
        actionSave->setObjectName(QString::fromUtf8("actionSave"));
        actionPrint = new QAction(Screenshot);
        actionPrint->setObjectName(QString::fromUtf8("actionPrint"));
        actionNew_Screenshot = new QAction(Screenshot);
        actionNew_Screenshot->setObjectName(QString::fromUtf8("actionNew_Screenshot"));
        actionExit = new QAction(Screenshot);
        actionExit->setObjectName(QString::fromUtf8("actionExit"));
        actionProxy_Settings = new QAction(Screenshot);
        actionProxy_Settings->setObjectName(QString::fromUtf8("actionProxy_Settings"));
        actionOptions = new QAction(Screenshot);
        actionOptions->setObjectName(QString::fromUtf8("actionOptions"));
        actionHistory = new QAction(Screenshot);
        actionHistory->setObjectName(QString::fromUtf8("actionHistory"));
        actionAbout_Qt = new QAction(Screenshot);
        actionAbout_Qt->setObjectName(QString::fromUtf8("actionAbout_Qt"));
        actionHome_page = new QAction(Screenshot);
        actionHome_page->setObjectName(QString::fromUtf8("actionHome_page"));
        actionUpload = new QAction(Screenshot);
        actionUpload->setObjectName(QString::fromUtf8("actionUpload"));
        centralwidget = new QWidget(Screenshot);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        scrollArea = new QScrollArea(centralwidget);
        scrollArea->setObjectName(QString::fromUtf8("scrollArea"));
        scrollArea->setWidgetResizable(true);
        scrollArea->setAlignment(Qt::AlignCenter);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QString::fromUtf8("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 780, 402));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        lb_pixmap = new PixmapWidget(scrollAreaWidgetContents);
        lb_pixmap->setObjectName(QString::fromUtf8("lb_pixmap"));
        sizePolicy.setHeightForWidth(lb_pixmap->sizePolicy().hasHeightForWidth());
        lb_pixmap->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(lb_pixmap);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        urlFrame = new QFrame(centralwidget);
        urlFrame->setObjectName(QString::fromUtf8("urlFrame"));
        urlFrame->setMinimumSize(QSize(0, 0));
        urlFrame->setFrameShape(QFrame::NoFrame);
        urlFrame->setFrameShadow(QFrame::Plain);
        urlFrame->setLineWidth(0);
        horizontalLayout = new QHBoxLayout(urlFrame);
#ifndef Q_OS_MAC
        horizontalLayout->setSpacing(6);
#endif
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        lb_url = new QLabel(urlFrame);
        lb_url->setObjectName(QString::fromUtf8("lb_url"));
        lb_url->setLineWidth(0);
        lb_url->setOpenExternalLinks(true);

        horizontalLayout->addWidget(lb_url);

        tb_copyUrl = new QToolButton(urlFrame);
        tb_copyUrl->setObjectName(QString::fromUtf8("tb_copyUrl"));

        horizontalLayout->addWidget(tb_copyUrl);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addWidget(urlFrame);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        pb_cancel = new QToolButton(centralwidget);
        pb_cancel->setObjectName(QString::fromUtf8("pb_cancel"));

        horizontalLayout_2->addWidget(pb_cancel);

        progressBar = new QProgressBar(centralwidget);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(24);

        horizontalLayout_2->addWidget(progressBar);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label = new QLabel(centralwidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_3->addWidget(label);

        cb_servers = new QComboBox(centralwidget);
        cb_servers->setObjectName(QString::fromUtf8("cb_servers"));

        horizontalLayout_3->addWidget(cb_servers);

        pb_upload = new QToolButton(centralwidget);
        pb_upload->setObjectName(QString::fromUtf8("pb_upload"));
        pb_upload->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_3->addWidget(pb_upload);

        pb_save = new QToolButton(centralwidget);
        pb_save->setObjectName(QString::fromUtf8("pb_save"));
        pb_save->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_3->addWidget(pb_save);

        pb_print = new QToolButton(centralwidget);
        pb_print->setObjectName(QString::fromUtf8("pb_print"));
        pb_print->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_3->addWidget(pb_print);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        pb_open = new QToolButton(centralwidget);
        pb_open->setObjectName(QString::fromUtf8("pb_open"));
        pb_open->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_3->addWidget(pb_open);

        pb_new_screenshot = new QToolButton(centralwidget);
        pb_new_screenshot->setObjectName(QString::fromUtf8("pb_new_screenshot"));
        pb_new_screenshot->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_3->addWidget(pb_new_screenshot);


        verticalLayout->addLayout(horizontalLayout_3);

        Screenshot->setCentralWidget(centralwidget);
        tb_bar = new ToolBar(Screenshot);
        tb_bar->setObjectName(QString::fromUtf8("tb_bar"));
        Screenshot->addToolBar(Qt::TopToolBarArea, tb_bar);
        menuBar = new QMenuBar(Screenshot);
        menuBar->setObjectName(QString::fromUtf8("menuBar"));
        menuBar->setEnabled(true);
        menuBar->setGeometry(QRect(0, 0, 800, 25));
        menuFile = new QMenu(menuBar);
        menuFile->setObjectName(QString::fromUtf8("menuFile"));
        menuSettings = new QMenu(menuBar);
        menuSettings->setObjectName(QString::fromUtf8("menuSettings"));
        menuAbout = new QMenu(menuBar);
        menuAbout->setObjectName(QString::fromUtf8("menuAbout"));
        Screenshot->setMenuBar(menuBar);
        statusBar = new QStatusBar(Screenshot);
        statusBar->setObjectName(QString::fromUtf8("statusBar"));
        Screenshot->setStatusBar(statusBar);

        menuBar->addAction(menuFile->menuAction());
        menuBar->addAction(menuSettings->menuAction());
        menuBar->addAction(menuAbout->menuAction());
        menuFile->addAction(actionNew_Screenshot);
        menuFile->addSeparator();
        menuFile->addAction(actionOpen_Image);
        menuFile->addAction(actionSave);
        menuFile->addAction(actionUpload);
        menuFile->addAction(actionPrint);
        menuFile->addSeparator();
        menuFile->addAction(actionHistory);
        menuFile->addSeparator();
        menuFile->addAction(actionExit);
        menuSettings->addAction(actionOptions);
        menuAbout->addAction(actionHome_page);
        menuAbout->addSeparator();
        menuAbout->addAction(actionAbout_Qt);

        retranslateUi(Screenshot);

        QMetaObject::connectSlotsByName(Screenshot);
    } // setupUi

    void retranslateUi(QMainWindow *Screenshot)
    {
        Screenshot->setWindowTitle(QCoreApplication::translate("Screenshot", "Screenshot", nullptr));
        actionOpen_Image->setText(QCoreApplication::translate("Screenshot", "Open", nullptr));
        actionSave->setText(QCoreApplication::translate("Screenshot", "Save", nullptr));
        actionPrint->setText(QCoreApplication::translate("Screenshot", "Print", nullptr));
        actionNew_Screenshot->setText(QCoreApplication::translate("Screenshot", "New Screenshot", nullptr));
        actionExit->setText(QCoreApplication::translate("Screenshot", "Exit", nullptr));
        actionProxy_Settings->setText(QCoreApplication::translate("Screenshot", "Proxy Settings", nullptr));
        actionOptions->setText(QCoreApplication::translate("Screenshot", "Options", nullptr));
        actionHistory->setText(QCoreApplication::translate("Screenshot", "History", nullptr));
        actionAbout_Qt->setText(QCoreApplication::translate("Screenshot", "About Qt", nullptr));
        actionHome_page->setText(QCoreApplication::translate("Screenshot", "Home page", nullptr));
        actionUpload->setText(QCoreApplication::translate("Screenshot", "Upload", nullptr));
        lb_url->setText(QString());
#if QT_CONFIG(tooltip)
        tb_copyUrl->setToolTip(QCoreApplication::translate("Screenshot", "Copy to clipboard", nullptr));
#endif // QT_CONFIG(tooltip)
        tb_copyUrl->setText(QString());
#if QT_CONFIG(tooltip)
        pb_cancel->setToolTip(QCoreApplication::translate("Screenshot", "Cancel uploading", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_cancel->setText(QString());
        label->setText(QCoreApplication::translate("Screenshot", "Upload to server:", nullptr));
#if QT_CONFIG(tooltip)
        pb_upload->setToolTip(QCoreApplication::translate("Screenshot", "Upload Screenshot to selected server", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_upload->setText(QString());
#if QT_CONFIG(tooltip)
        pb_save->setToolTip(QCoreApplication::translate("Screenshot", "Save Screenshot to Local Drive", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_save->setText(QString());
#if QT_CONFIG(tooltip)
        pb_print->setToolTip(QCoreApplication::translate("Screenshot", "Print Screenshot", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_print->setText(QString());
#if QT_CONFIG(tooltip)
        pb_open->setToolTip(QCoreApplication::translate("Screenshot", "Open image from Local Drive", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_open->setText(QString());
#if QT_CONFIG(tooltip)
        pb_new_screenshot->setToolTip(QCoreApplication::translate("Screenshot", "New Screenshot", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_new_screenshot->setText(QString());
        tb_bar->setWindowTitle(QCoreApplication::translate("Screenshot", "toolBar", nullptr));
        menuFile->setTitle(QCoreApplication::translate("Screenshot", "File", nullptr));
        menuSettings->setTitle(QCoreApplication::translate("Screenshot", "Settings", nullptr));
        menuAbout->setTitle(QCoreApplication::translate("Screenshot", "Help", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Screenshot: public Ui_Screenshot {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SCREENSHOT_H
