/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QHBoxLayout *horizontalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QHBoxLayout *horizontalLayout_2;
    QTreeView *keys;
    QVBoxLayout *verticalLayout;
    QPushButton *btnAdd;
    QPushButton *btnRemove;
    QPushButton *btnImport;
    QPushButton *btnExport;
    QSpacerItem *verticalSpacer;
    QPushButton *btnInfo;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *chkAutoImport;
    QCheckBox *chkHideKeyMessage;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(490, 451);
        horizontalLayout = new QHBoxLayout(Options);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        tabWidget = new QTabWidget(Options);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        horizontalLayout_2 = new QHBoxLayout(tab);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        keys = new QTreeView(tab);
        keys->setObjectName(QString::fromUtf8("keys"));
        keys->setEditTriggers(QAbstractItemView::NoEditTriggers);
        keys->setSelectionMode(QAbstractItemView::ExtendedSelection);
        keys->setAnimated(true);
        keys->setExpandsOnDoubleClick(false);

        horizontalLayout_2->addWidget(keys);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        btnAdd = new QPushButton(tab);
        btnAdd->setObjectName(QString::fromUtf8("btnAdd"));

        verticalLayout->addWidget(btnAdd);

        btnRemove = new QPushButton(tab);
        btnRemove->setObjectName(QString::fromUtf8("btnRemove"));

        verticalLayout->addWidget(btnRemove);

        btnImport = new QPushButton(tab);
        btnImport->setObjectName(QString::fromUtf8("btnImport"));

        verticalLayout->addWidget(btnImport);

        btnExport = new QPushButton(tab);
        btnExport->setObjectName(QString::fromUtf8("btnExport"));

        verticalLayout->addWidget(btnExport);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        btnInfo = new QPushButton(tab);
        btnInfo->setObjectName(QString::fromUtf8("btnInfo"));

        verticalLayout->addWidget(btnInfo);


        horizontalLayout_2->addLayout(verticalLayout);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QString::fromUtf8("tab_2"));
        verticalLayout_2 = new QVBoxLayout(tab_2);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        chkAutoImport = new QCheckBox(tab_2);
        chkAutoImport->setObjectName(QString::fromUtf8("chkAutoImport"));

        verticalLayout_2->addWidget(chkAutoImport);

        chkHideKeyMessage = new QCheckBox(tab_2);
        chkHideKeyMessage->setObjectName(QString::fromUtf8("chkHideKeyMessage"));

        verticalLayout_2->addWidget(chkHideKeyMessage);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tab_2, QString());

        horizontalLayout->addWidget(tabWidget);


        retranslateUi(Options);
        QObject::connect(btnAdd, SIGNAL(clicked()), Options, SLOT(addKey()));
        QObject::connect(btnRemove, SIGNAL(clicked()), Options, SLOT(removeKey()));
        QObject::connect(btnInfo, SIGNAL(clicked()), Options, SLOT(showInfo()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        btnAdd->setText(QCoreApplication::translate("Options", "Add", nullptr));
        btnRemove->setText(QCoreApplication::translate("Options", "Remove", nullptr));
        btnImport->setText(QCoreApplication::translate("Options", "Import", nullptr));
        btnExport->setText(QCoreApplication::translate("Options", "Export", nullptr));
        btnInfo->setText(QCoreApplication::translate("Options", "Info", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("Options", "Manager", nullptr));
        chkAutoImport->setText(QCoreApplication::translate("Options", "Auto import a key from the message body", nullptr));
        chkHideKeyMessage->setText(QCoreApplication::translate("Options", "Filter the message with a key", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("Options", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
