/****************************************************************************
** Meta object code from reading C++ file 'notes.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../notes.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Notes_t {
    QByteArrayData data[16];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Notes_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Notes_t qt_meta_stringdata_Notes = {
    {
QT_MOC_LITERAL(0, 0, 5), // "Notes"
QT_MOC_LITERAL(1, 6, 12), // "notesDeleted"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 4), // "load"
QT_MOC_LITERAL(4, 25, 4), // "save"
QT_MOC_LITERAL(5, 30, 3), // "add"
QT_MOC_LITERAL(6, 34, 3), // "del"
QT_MOC_LITERAL(7, 38, 4), // "edit"
QT_MOC_LITERAL(8, 43, 7), // "addNote"
QT_MOC_LITERAL(9, 51, 11), // "QDomElement"
QT_MOC_LITERAL(10, 63, 4), // "note"
QT_MOC_LITERAL(11, 68, 10), // "noteEdited"
QT_MOC_LITERAL(12, 79, 11), // "QModelIndex"
QT_MOC_LITERAL(13, 91, 5), // "index"
QT_MOC_LITERAL(14, 97, 9), // "selectTag"
QT_MOC_LITERAL(15, 107, 10) // "updateTags"

    },
    "Notes\0notesDeleted\0\0load\0save\0add\0del\0"
    "edit\0addNote\0QDomElement\0note\0noteEdited\0"
    "QModelIndex\0index\0selectTag\0updateTags"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Notes[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   67,    2, 0x0a /* Public */,
       4,    0,   68,    2, 0x08 /* Private */,
       5,    0,   69,    2, 0x08 /* Private */,
       6,    0,   70,    2, 0x08 /* Private */,
       7,    0,   71,    2, 0x08 /* Private */,
       8,    1,   72,    2, 0x08 /* Private */,
      11,    2,   75,    2, 0x08 /* Private */,
      14,    0,   80,    2, 0x08 /* Private */,
      15,    0,   81,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 12,   10,   13,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Notes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Notes *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->notesDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->load(); break;
        case 2: _t->save(); break;
        case 3: _t->add(); break;
        case 4: _t->del(); break;
        case 5: _t->edit(); break;
        case 6: _t->addNote((*reinterpret_cast< const QDomElement(*)>(_a[1]))); break;
        case 7: _t->noteEdited((*reinterpret_cast< const QDomElement(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 8: _t->selectTag(); break;
        case 9: _t->updateTags(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Notes::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notes::notesDeleted)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Notes::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_Notes.data,
    qt_meta_data_Notes,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Notes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Notes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Notes.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Notes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Notes::notesDeleted(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
