/********************************************************************************
** Form generated from reading UI file 'cleaner.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLEANER_H
#define UI_CLEANER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "common.h"

QT_BEGIN_NAMESPACE

class Ui_CleanerMainWindow
{
public:
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    QTabWidget *tw_tab;
    ClearingTab *tab_history;
    ClearingTab *tab_vcard;
    ClearingTab *tab_avatars;
    ClearingTab *tab_options;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *le_filter;
    QPushButton *pb_selectAll;
    QPushButton *pb_unselectAll;
    QSpacerItem *horizontalSpacer;
    QLabel *lbl_selected;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *pb_delete;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *pb_close;
    QMenuBar *menuBar;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *CleanerMainWindow)
    {
        if (CleanerMainWindow->objectName().isEmpty())
            CleanerMainWindow->setObjectName(QString::fromUtf8("CleanerMainWindow"));
        CleanerMainWindow->resize(800, 600);
        CleanerMainWindow->setMaximumSize(QSize(99999, 99999));
        centralwidget = new QWidget(CleanerMainWindow);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tw_tab = new QTabWidget(centralwidget);
        tw_tab->setObjectName(QString::fromUtf8("tw_tab"));
        tab_history = new ClearingTab();
        tab_history->setObjectName(QString::fromUtf8("tab_history"));
        tw_tab->addTab(tab_history, QString());
        tab_vcard = new ClearingTab();
        tab_vcard->setObjectName(QString::fromUtf8("tab_vcard"));
        tw_tab->addTab(tab_vcard, QString());
        tab_avatars = new ClearingTab();
        tab_avatars->setObjectName(QString::fromUtf8("tab_avatars"));
        tw_tab->addTab(tab_avatars, QString());
        tab_options = new ClearingTab();
        tab_options->setObjectName(QString::fromUtf8("tab_options"));
        tw_tab->addTab(tab_options, QString());

        verticalLayout->addWidget(tw_tab);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(centralwidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        le_filter = new QLineEdit(centralwidget);
        le_filter->setObjectName(QString::fromUtf8("le_filter"));

        horizontalLayout->addWidget(le_filter);

        pb_selectAll = new QPushButton(centralwidget);
        pb_selectAll->setObjectName(QString::fromUtf8("pb_selectAll"));
        pb_selectAll->setMaximumSize(QSize(25, 25));

        horizontalLayout->addWidget(pb_selectAll);

        pb_unselectAll = new QPushButton(centralwidget);
        pb_unselectAll->setObjectName(QString::fromUtf8("pb_unselectAll"));
        pb_unselectAll->setMaximumSize(QSize(25, 25));

        horizontalLayout->addWidget(pb_unselectAll);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        lbl_selected = new QLabel(centralwidget);
        lbl_selected->setObjectName(QString::fromUtf8("lbl_selected"));
        lbl_selected->setMinimumSize(QSize(50, 0));
        lbl_selected->setMaximumSize(QSize(50, 16777215));
        lbl_selected->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(lbl_selected);

        label_2 = new QLabel(centralwidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        pb_delete = new QPushButton(centralwidget);
        pb_delete->setObjectName(QString::fromUtf8("pb_delete"));

        horizontalLayout_2->addWidget(pb_delete);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        pb_close = new QPushButton(centralwidget);
        pb_close->setObjectName(QString::fromUtf8("pb_close"));

        horizontalLayout_2->addWidget(pb_close);


        verticalLayout->addLayout(horizontalLayout_2);

        CleanerMainWindow->setCentralWidget(centralwidget);
        menuBar = new QMenuBar(CleanerMainWindow);
        menuBar->setObjectName(QString::fromUtf8("menuBar"));
        menuBar->setGeometry(QRect(0, 0, 800, 25));
        CleanerMainWindow->setMenuBar(menuBar);
        statusBar = new QStatusBar(CleanerMainWindow);
        statusBar->setObjectName(QString::fromUtf8("statusBar"));
        CleanerMainWindow->setStatusBar(statusBar);

        retranslateUi(CleanerMainWindow);

        tw_tab->setCurrentIndex(3);


        QMetaObject::connectSlotsByName(CleanerMainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *CleanerMainWindow)
    {
        CleanerMainWindow->setWindowTitle(QCoreApplication::translate("CleanerMainWindow", "Psi+ Cleaner", nullptr));
        tw_tab->setTabText(tw_tab->indexOf(tab_history), QCoreApplication::translate("CleanerMainWindow", "History", nullptr));
        tw_tab->setTabText(tw_tab->indexOf(tab_vcard), QCoreApplication::translate("CleanerMainWindow", "vCards", nullptr));
        tw_tab->setTabText(tw_tab->indexOf(tab_avatars), QCoreApplication::translate("CleanerMainWindow", "Avatars", nullptr));
        tw_tab->setTabText(tw_tab->indexOf(tab_options), QCoreApplication::translate("CleanerMainWindow", "Options", nullptr));
        label->setText(QCoreApplication::translate("CleanerMainWindow", "Filter:", nullptr));
#if QT_CONFIG(tooltip)
        pb_selectAll->setToolTip(QCoreApplication::translate("CleanerMainWindow", "Select All Files", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_selectAll->setText(QString());
#if QT_CONFIG(tooltip)
        pb_unselectAll->setToolTip(QCoreApplication::translate("CleanerMainWindow", "Unselect All Files", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_unselectAll->setText(QString());
        lbl_selected->setText(QCoreApplication::translate("CleanerMainWindow", "0", nullptr));
        label_2->setText(QCoreApplication::translate("CleanerMainWindow", " files selected", nullptr));
#if QT_CONFIG(tooltip)
        pb_delete->setToolTip(QCoreApplication::translate("CleanerMainWindow", "Delete selected files", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_delete->setText(QCoreApplication::translate("CleanerMainWindow", "Delete selected", nullptr));
#if QT_CONFIG(tooltip)
        pb_close->setToolTip(QCoreApplication::translate("CleanerMainWindow", "Close Psi Cleaner", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_close->setText(QCoreApplication::translate("CleanerMainWindow", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CleanerMainWindow: public Ui_CleanerMainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLEANER_H
