/********************************************************************************
** Form generated from reading UI file 'jd_mainwin.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JD_MAINWIN_H
#define UI_JD_MAINWIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "jd_view.h"

QT_BEGIN_NAMESPACE

class Ui_JDMainWin
{
public:
    QVBoxLayout *verticalLayout_3;
    QSplitter *splitter;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    JDView *lv_disk;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *pb_refresh;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_clear;
    QWidget *widget_2;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *te_log;
    QHBoxLayout *horizontalLayout;
    QTextEdit *te_message;
    QPushButton *pb_send;

    void setupUi(QDialog *JDMainWin)
    {
        if (JDMainWin->objectName().isEmpty())
            JDMainWin->setObjectName(QString::fromUtf8("JDMainWin"));
        JDMainWin->resize(800, 600);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(JDMainWin->sizePolicy().hasHeightForWidth());
        JDMainWin->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(JDMainWin);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        splitter = new QSplitter(JDMainWin);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        splitter->setOrientation(Qt::Horizontal);
        widget = new QWidget(splitter);
        widget->setObjectName(QString::fromUtf8("widget"));
        verticalLayout = new QVBoxLayout(widget);
#ifndef Q_OS_MAC
        verticalLayout->setSpacing(6);
#endif
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        lv_disk = new JDView(widget);
        lv_disk->setObjectName(QString::fromUtf8("lv_disk"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lv_disk->sizePolicy().hasHeightForWidth());
        lv_disk->setSizePolicy(sizePolicy1);
        lv_disk->setContextMenuPolicy(Qt::CustomContextMenu);
        lv_disk->setDragDropMode(QAbstractItemView::DragDrop);
        lv_disk->setDefaultDropAction(Qt::MoveAction);
        lv_disk->setSortingEnabled(true);
        lv_disk->header()->setVisible(false);

        verticalLayout->addWidget(lv_disk);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        pb_refresh = new QPushButton(widget);
        pb_refresh->setObjectName(QString::fromUtf8("pb_refresh"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pb_refresh->sizePolicy().hasHeightForWidth());
        pb_refresh->setSizePolicy(sizePolicy2);
        pb_refresh->setFocusPolicy(Qt::ClickFocus);

        horizontalLayout_2->addWidget(pb_refresh);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pb_clear = new QPushButton(widget);
        pb_clear->setObjectName(QString::fromUtf8("pb_clear"));

        horizontalLayout_2->addWidget(pb_clear);


        verticalLayout->addLayout(horizontalLayout_2);

        splitter->addWidget(widget);
        widget_2 = new QWidget(splitter);
        widget_2->setObjectName(QString::fromUtf8("widget_2"));
        verticalLayout_2 = new QVBoxLayout(widget_2);
#ifndef Q_OS_MAC
        verticalLayout_2->setSpacing(6);
#endif
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        te_log = new QTextEdit(widget_2);
        te_log->setObjectName(QString::fromUtf8("te_log"));
        te_log->setReadOnly(true);

        verticalLayout_2->addWidget(te_log);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        te_message = new QTextEdit(widget_2);
        te_message->setObjectName(QString::fromUtf8("te_message"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Ignored);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(te_message->sizePolicy().hasHeightForWidth());
        te_message->setSizePolicy(sizePolicy3);
        te_message->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout->addWidget(te_message);

        pb_send = new QPushButton(widget_2);
        pb_send->setObjectName(QString::fromUtf8("pb_send"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(pb_send->sizePolicy().hasHeightForWidth());
        pb_send->setSizePolicy(sizePolicy4);

        horizontalLayout->addWidget(pb_send);


        verticalLayout_2->addLayout(horizontalLayout);

        splitter->addWidget(widget_2);

        verticalLayout_3->addWidget(splitter);


        retranslateUi(JDMainWin);

        QMetaObject::connectSlotsByName(JDMainWin);
    } // setupUi

    void retranslateUi(QDialog *JDMainWin)
    {
        JDMainWin->setWindowTitle(QString());
        pb_refresh->setText(QCoreApplication::translate("JDMainWin", "Refresh", nullptr));
        pb_clear->setText(QCoreApplication::translate("JDMainWin", "Clear log", nullptr));
        pb_send->setText(QCoreApplication::translate("JDMainWin", "Send", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JDMainWin: public Ui_JDMainWin {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_JD_MAINWIN_H
