/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QToolButton *tb_inColor;
    QLabel *label_2;
    QToolButton *tb_outColor;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *rb_disabled;
    QRadioButton *rb_enabled;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *hack;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(266, 194);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(Options);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        tb_inColor = new QToolButton(Options);
        tb_inColor->setObjectName(QString::fromUtf8("tb_inColor"));

        gridLayout->addWidget(tb_inColor, 0, 1, 1, 1);

        label_2 = new QLabel(Options);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        tb_outColor = new QToolButton(Options);
        tb_outColor->setObjectName(QString::fromUtf8("tb_outColor"));

        gridLayout->addWidget(tb_outColor, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        groupBox = new QGroupBox(Options);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        horizontalLayout_3 = new QHBoxLayout(groupBox);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        rb_disabled = new QRadioButton(groupBox);
        rb_disabled->setObjectName(QString::fromUtf8("rb_disabled"));

        horizontalLayout_3->addWidget(rb_disabled);

        rb_enabled = new QRadioButton(groupBox);
        rb_enabled->setObjectName(QString::fromUtf8("rb_enabled"));

        horizontalLayout_3->addWidget(rb_enabled);

        horizontalSpacer_3 = new QSpacerItem(89, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout->addWidget(groupBox);

        hack = new QCheckBox(Options);
        hack->setObjectName(QString::fromUtf8("hack"));

        verticalLayout->addWidget(hack);

        verticalSpacer = new QSpacerItem(20, 34, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        label->setText(QCoreApplication::translate("Options", "Color for incoming messages numbers", nullptr));
        tb_inColor->setText(QString());
        label_2->setText(QCoreApplication::translate("Options", "Color for outgoing messages numbers", nullptr));
        tb_outColor->setText(QString());
        groupBox->setTitle(QCoreApplication::translate("Options", "Default plugin action", nullptr));
        rb_disabled->setText(QCoreApplication::translate("Options", "Disabled", nullptr));
        rb_enabled->setText(QCoreApplication::translate("Options", "Enabled", nullptr));
        hack->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
