/****************************************************************************
** Meta object code from reading C++ file 'boardmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../boardmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'boardmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GomokuGame__BoardModel_t {
    QByteArrayData data[12];
    char stringdata0[120];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GomokuGame__BoardModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GomokuGame__BoardModel_t qt_meta_stringdata_GomokuGame__BoardModel = {
    {
QT_MOC_LITERAL(0, 0, 22), // "GomokuGame::BoardModel"
QT_MOC_LITERAL(1, 23, 16), // "changeGameStatus"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 21), // "GameModel::GameStatus"
QT_MOC_LITERAL(4, 63, 12), // "setupElement"
QT_MOC_LITERAL(5, 76, 1), // "x"
QT_MOC_LITERAL(6, 78, 1), // "y"
QT_MOC_LITERAL(7, 80, 4), // "lose"
QT_MOC_LITERAL(8, 85, 4), // "draw"
QT_MOC_LITERAL(9, 90, 11), // "switchColor"
QT_MOC_LITERAL(10, 102, 7), // "doPopup"
QT_MOC_LITERAL(11, 110, 9) // "playSound"

    },
    "GomokuGame::BoardModel\0changeGameStatus\0"
    "\0GameModel::GameStatus\0setupElement\0"
    "x\0y\0lose\0draw\0switchColor\0doPopup\0"
    "playSound"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GomokuGame__BoardModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    2,   52,    2, 0x06 /* Public */,
       7,    0,   57,    2, 0x06 /* Public */,
       8,    0,   58,    2, 0x06 /* Public */,
       9,    0,   59,    2, 0x06 /* Public */,
      10,    1,   60,    2, 0x06 /* Public */,
      11,    1,   63,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void GomokuGame::BoardModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BoardModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changeGameStatus((*reinterpret_cast< GameModel::GameStatus(*)>(_a[1]))); break;
        case 1: _t->setupElement((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->lose(); break;
        case 3: _t->draw(); break;
        case 4: _t->switchColor(); break;
        case 5: _t->doPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->playSound((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BoardModel::*)(GameModel::GameStatus );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::changeGameStatus)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::setupElement)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::lose)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::draw)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::switchColor)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::doPopup)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (BoardModel::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BoardModel::playSound)) {
                *result = 6;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject GomokuGame::BoardModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_meta_stringdata_GomokuGame__BoardModel.data,
    qt_meta_data_GomokuGame__BoardModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *GomokuGame::BoardModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GomokuGame::BoardModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GomokuGame__BoardModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int GomokuGame::BoardModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void GomokuGame::BoardModel::changeGameStatus(GameModel::GameStatus _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void GomokuGame::BoardModel::setupElement(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void GomokuGame::BoardModel::lose()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GomokuGame::BoardModel::draw()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GomokuGame::BoardModel::switchColor()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GomokuGame::BoardModel::doPopup(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void GomokuGame::BoardModel::playSound(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
