/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QListWidget *lw_jids;
    QLineEdit *le_addJid;
    QHBoxLayout *horizontalLayout;
    QPushButton *pb_add;
    QPushButton *pb_delete;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cb_hack;
    QSpacerItem *verticalSpacer;
    QLabel *wiki;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(319, 311);
        verticalLayout_2 = new QVBoxLayout(Options);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        lw_jids = new QListWidget(Options);
        lw_jids->setObjectName(QString::fromUtf8("lw_jids"));

        verticalLayout->addWidget(lw_jids);

        le_addJid = new QLineEdit(Options);
        le_addJid->setObjectName(QString::fromUtf8("le_addJid"));

        verticalLayout->addWidget(le_addJid);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pb_add = new QPushButton(Options);
        pb_add->setObjectName(QString::fromUtf8("pb_add"));

        horizontalLayout->addWidget(pb_add);

        pb_delete = new QPushButton(Options);
        pb_delete->setObjectName(QString::fromUtf8("pb_delete"));

        horizontalLayout->addWidget(pb_delete);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        cb_hack = new QCheckBox(Options);
        cb_hack->setObjectName(QString::fromUtf8("cb_hack"));

        horizontalLayout_2->addWidget(cb_hack);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        wiki = new QLabel(Options);
        wiki->setObjectName(QString::fromUtf8("wiki"));
        wiki->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(wiki);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        pb_add->setText(QCoreApplication::translate("Options", "Add", nullptr));
        pb_delete->setText(QCoreApplication::translate("Options", "Delete", nullptr));
        cb_hack->setText(QString());
        wiki->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#jabber_disk_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
