/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_options
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QGridLayout *gridLayout;
    QLineEdit *le_start;
    QPushButton *select_start;
    QPushButton *play_start;
    QLineEdit *le_finish;
    QPushButton *select_finish;
    QPushButton *play_finish;
    QLineEdit *le_move;
    QPushButton *select_move;
    QPushButton *play_move;
    QLineEdit *le_error;
    QPushButton *select_error;
    QPushButton *play_error;
    QCheckBox *cb_sound_override;
    QCheckBox *cb_disable_dnd;
    QLabel *wiki;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *options)
    {
        if (options->objectName().isEmpty())
            options->setObjectName(QString::fromUtf8("options"));
        options->resize(338, 254);
        verticalLayout_2 = new QVBoxLayout(options);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label_5 = new QLabel(options);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        verticalLayout_2->addWidget(label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(options);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout->addWidget(label);

        label_2 = new QLabel(options);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        verticalLayout->addWidget(label_2);

        label_3 = new QLabel(options);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        verticalLayout->addWidget(label_3);

        label_4 = new QLabel(options);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        verticalLayout->addWidget(label_4);


        horizontalLayout->addLayout(verticalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        le_start = new QLineEdit(options);
        le_start->setObjectName(QString::fromUtf8("le_start"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(le_start->sizePolicy().hasHeightForWidth());
        le_start->setSizePolicy(sizePolicy);

        gridLayout->addWidget(le_start, 0, 0, 1, 1);

        select_start = new QPushButton(options);
        select_start->setObjectName(QString::fromUtf8("select_start"));
        select_start->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(select_start, 0, 1, 1, 1);

        play_start = new QPushButton(options);
        play_start->setObjectName(QString::fromUtf8("play_start"));
        play_start->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(play_start, 0, 2, 1, 1);

        le_finish = new QLineEdit(options);
        le_finish->setObjectName(QString::fromUtf8("le_finish"));
        sizePolicy.setHeightForWidth(le_finish->sizePolicy().hasHeightForWidth());
        le_finish->setSizePolicy(sizePolicy);

        gridLayout->addWidget(le_finish, 1, 0, 1, 1);

        select_finish = new QPushButton(options);
        select_finish->setObjectName(QString::fromUtf8("select_finish"));
        select_finish->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(select_finish, 1, 1, 1, 1);

        play_finish = new QPushButton(options);
        play_finish->setObjectName(QString::fromUtf8("play_finish"));
        play_finish->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(play_finish, 1, 2, 1, 1);

        le_move = new QLineEdit(options);
        le_move->setObjectName(QString::fromUtf8("le_move"));
        sizePolicy.setHeightForWidth(le_move->sizePolicy().hasHeightForWidth());
        le_move->setSizePolicy(sizePolicy);

        gridLayout->addWidget(le_move, 2, 0, 1, 1);

        select_move = new QPushButton(options);
        select_move->setObjectName(QString::fromUtf8("select_move"));
        select_move->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(select_move, 2, 1, 1, 1);

        play_move = new QPushButton(options);
        play_move->setObjectName(QString::fromUtf8("play_move"));
        play_move->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(play_move, 2, 2, 1, 1);

        le_error = new QLineEdit(options);
        le_error->setObjectName(QString::fromUtf8("le_error"));
        sizePolicy.setHeightForWidth(le_error->sizePolicy().hasHeightForWidth());
        le_error->setSizePolicy(sizePolicy);

        gridLayout->addWidget(le_error, 3, 0, 1, 1);

        select_error = new QPushButton(options);
        select_error->setObjectName(QString::fromUtf8("select_error"));
        select_error->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(select_error, 3, 1, 1, 1);

        play_error = new QPushButton(options);
        play_error->setObjectName(QString::fromUtf8("play_error"));
        play_error->setMaximumSize(QSize(25, 25));

        gridLayout->addWidget(play_error, 3, 2, 1, 1);


        horizontalLayout->addLayout(gridLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        cb_sound_override = new QCheckBox(options);
        cb_sound_override->setObjectName(QString::fromUtf8("cb_sound_override"));

        verticalLayout_2->addWidget(cb_sound_override);

        cb_disable_dnd = new QCheckBox(options);
        cb_disable_dnd->setObjectName(QString::fromUtf8("cb_disable_dnd"));

        verticalLayout_2->addWidget(cb_disable_dnd);

        wiki = new QLabel(options);
        wiki->setObjectName(QString::fromUtf8("wiki"));

        verticalLayout_2->addWidget(wiki);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(options);

        QMetaObject::connectSlotsByName(options);
    } // setupUi

    void retranslateUi(QWidget *options)
    {
        options->setWindowTitle(QCoreApplication::translate("options", "Form", nullptr));
        label_5->setText(QCoreApplication::translate("options", "Select Sounds:", nullptr));
        label->setText(QCoreApplication::translate("options", "Game started:", nullptr));
        label_2->setText(QCoreApplication::translate("options", "Game finished:", nullptr));
        label_3->setText(QCoreApplication::translate("options", "Your turn:", nullptr));
        label_4->setText(QCoreApplication::translate("options", "Error message:", nullptr));
        select_start->setText(QString());
        play_start->setText(QString());
        select_finish->setText(QString());
        play_finish->setText(QString());
        select_move->setText(QString());
        play_move->setText(QString());
        select_error->setText(QString());
        play_error->setText(QString());
#if QT_CONFIG(tooltip)
        cb_sound_override->setToolTip(QCoreApplication::translate("options", "If checked, the sound will always enabled (or disabled)", nullptr));
#endif // QT_CONFIG(tooltip)
        cb_sound_override->setText(QCoreApplication::translate("options", "Override default sound settings", nullptr));
        cb_disable_dnd->setText(QCoreApplication::translate("options", "Disable invitations if status is DND", nullptr));
        wiki->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class options: public Ui_options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
