/****************************************************************************
** Meta object code from reading C++ file 'pixmapwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../pixmapwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pixmapwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PixmapWidget_t {
    QByteArrayData data[18];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PixmapWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PixmapWidget_t qt_meta_stringdata_PixmapWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "PixmapWidget"
QT_MOC_LITERAL(1, 13, 8), // "adjusted"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 15), // "settingsChanged"
QT_MOC_LITERAL(4, 39, 8), // "modified"
QT_MOC_LITERAL(5, 48, 20), // "checkedButtonChanged"
QT_MOC_LITERAL(6, 69, 19), // "ToolBar::ButtonType"
QT_MOC_LITERAL(7, 89, 4), // "type"
QT_MOC_LITERAL(8, 94, 13), // "paintToPixmap"
QT_MOC_LITERAL(9, 108, 4), // "text"
QT_MOC_LITERAL(10, 113, 8), // "newWidth"
QT_MOC_LITERAL(11, 122, 1), // "w"
QT_MOC_LITERAL(12, 124, 13), // "buttonClicked"
QT_MOC_LITERAL(13, 138, 3), // "cut"
QT_MOC_LITERAL(14, 142, 4), // "copy"
QT_MOC_LITERAL(15, 147, 10), // "selectFont"
QT_MOC_LITERAL(16, 158, 4), // "blur"
QT_MOC_LITERAL(17, 163, 6) // "insert"

    },
    "PixmapWidget\0adjusted\0\0settingsChanged\0"
    "modified\0checkedButtonChanged\0"
    "ToolBar::ButtonType\0type\0paintToPixmap\0"
    "text\0newWidth\0w\0buttonClicked\0cut\0"
    "copy\0selectFont\0blur\0insert"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PixmapWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    2,   80,    2, 0x06 /* Public */,
       4,    1,   85,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   88,    2, 0x08 /* Private */,
       8,    1,   91,    2, 0x08 /* Private */,
       8,    0,   94,    2, 0x28 /* Private | MethodCloned */,
      10,    1,   95,    2, 0x08 /* Private */,
      12,    1,   98,    2, 0x08 /* Private */,
      13,    0,  101,    2, 0x08 /* Private */,
      14,    0,  102,    2, 0x08 /* Private */,
      15,    0,  103,    2, 0x08 /* Private */,
      16,    0,  104,    2, 0x08 /* Private */,
      17,    0,  105,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void PixmapWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PixmapWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->adjusted(); break;
        case 1: _t->settingsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 2: _t->modified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->checkedButtonChanged((*reinterpret_cast< ToolBar::ButtonType(*)>(_a[1]))); break;
        case 4: _t->paintToPixmap((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->paintToPixmap(); break;
        case 6: _t->newWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->buttonClicked((*reinterpret_cast< ToolBar::ButtonType(*)>(_a[1]))); break;
        case 8: _t->cut(); break;
        case 9: _t->copy(); break;
        case 10: _t->selectFont(); break;
        case 11: _t->blur(); break;
        case 12: _t->insert(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PixmapWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PixmapWidget::adjusted)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PixmapWidget::*)(const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PixmapWidget::settingsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PixmapWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PixmapWidget::modified)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PixmapWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_PixmapWidget.data,
    qt_meta_data_PixmapWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PixmapWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PixmapWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PixmapWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PixmapWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PixmapWidget::adjusted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PixmapWidget::settingsChanged(const QString & _t1, const QVariant & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PixmapWidget::modified(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
