/********************************************************************************
** Form generated from reading UI file 'optionsdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONSDLG_H
#define UI_OPTIONSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "optionswidget.h"

QT_BEGIN_NAMESPACE

class Ui_OptionsDlg
{
public:
    QVBoxLayout *verticalLayout;
    OptionsWidget *options;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OptionsDlg)
    {
        if (OptionsDlg->objectName().isEmpty())
            OptionsDlg->setObjectName(QString::fromUtf8("OptionsDlg"));
        OptionsDlg->resize(500, 300);
        verticalLayout = new QVBoxLayout(OptionsDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        options = new OptionsWidget(OptionsDlg);
        options->setObjectName(QString::fromUtf8("options"));

        verticalLayout->addWidget(options);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(OptionsDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(OptionsDlg);
        QObject::connect(buttonBox, SIGNAL(rejected()), OptionsDlg, SLOT(reject()));
        QObject::connect(buttonBox, SIGNAL(accepted()), OptionsDlg, SLOT(accept()));

        QMetaObject::connectSlotsByName(OptionsDlg);
    } // setupUi

    void retranslateUi(QDialog *OptionsDlg)
    {
        OptionsDlg->setWindowTitle(QCoreApplication::translate("OptionsDlg", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OptionsDlg: public Ui_OptionsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONSDLG_H
