/****************************************************************************
** Meta object code from reading C++ file 'pluginwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../pluginwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_HintElementWidget_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HintElementWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HintElementWidget_t qt_meta_stringdata_HintElementWidget = {
    {
QT_MOC_LITERAL(0, 0, 17) // "HintElementWidget"

    },
    "HintElementWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HintElementWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void HintElementWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject HintElementWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_HintElementWidget.data,
    qt_meta_data_HintElementWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *HintElementWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HintElementWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HintElementWidget.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int HintElementWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_PluginWindow_t {
    QByteArrayData data[38];
    char stringdata0[375];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PluginWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PluginWindow_t qt_meta_stringdata_PluginWindow = {
    {
QT_MOC_LITERAL(0, 0, 12), // "PluginWindow"
QT_MOC_LITERAL(1, 13, 17), // "changeGameSession"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 10), // "closeBoard"
QT_MOC_LITERAL(4, 43, 10), // "setElement"
QT_MOC_LITERAL(5, 54, 8), // "accepted"
QT_MOC_LITERAL(6, 63, 5), // "error"
QT_MOC_LITERAL(7, 69, 4), // "lose"
QT_MOC_LITERAL(8, 74, 4), // "draw"
QT_MOC_LITERAL(9, 79, 11), // "switchColor"
QT_MOC_LITERAL(10, 91, 4), // "load"
QT_MOC_LITERAL(11, 96, 13), // "sendNewInvite"
QT_MOC_LITERAL(12, 110, 7), // "doPopup"
QT_MOC_LITERAL(13, 118, 9), // "playSound"
QT_MOC_LITERAL(14, 128, 16), // "changeGameStatus"
QT_MOC_LITERAL(15, 145, 21), // "GameModel::GameStatus"
QT_MOC_LITERAL(16, 167, 6), // "status"
QT_MOC_LITERAL(17, 174, 12), // "turnSelected"
QT_MOC_LITERAL(18, 187, 12), // "setupElement"
QT_MOC_LITERAL(19, 200, 1), // "x"
QT_MOC_LITERAL(20, 202, 1), // "y"
QT_MOC_LITERAL(21, 204, 10), // "acceptStep"
QT_MOC_LITERAL(22, 215, 9), // "setAccept"
QT_MOC_LITERAL(23, 225, 8), // "setError"
QT_MOC_LITERAL(24, 234, 7), // "setTurn"
QT_MOC_LITERAL(25, 242, 14), // "setSwitchColor"
QT_MOC_LITERAL(26, 257, 13), // "doSwitchColor"
QT_MOC_LITERAL(27, 271, 7), // "setLose"
QT_MOC_LITERAL(28, 279, 7), // "setDraw"
QT_MOC_LITERAL(29, 287, 9), // "setResign"
QT_MOC_LITERAL(30, 297, 6), // "setWin"
QT_MOC_LITERAL(31, 304, 8), // "setClose"
QT_MOC_LITERAL(32, 313, 7), // "newGame"
QT_MOC_LITERAL(33, 321, 8), // "saveGame"
QT_MOC_LITERAL(34, 330, 8), // "loadGame"
QT_MOC_LITERAL(35, 339, 14), // "loadRemoteGame"
QT_MOC_LITERAL(36, 354, 12), // "opponentDraw"
QT_MOC_LITERAL(37, 367, 7) // "setSkin"

    },
    "PluginWindow\0changeGameSession\0\0"
    "closeBoard\0setElement\0accepted\0error\0"
    "lose\0draw\0switchColor\0load\0sendNewInvite\0"
    "doPopup\0playSound\0changeGameStatus\0"
    "GameModel::GameStatus\0status\0turnSelected\0"
    "setupElement\0x\0y\0acceptStep\0setAccept\0"
    "setError\0setTurn\0setSwitchColor\0"
    "doSwitchColor\0setLose\0setDraw\0setResign\0"
    "setWin\0setClose\0newGame\0saveGame\0"
    "loadGame\0loadRemoteGame\0opponentDraw\0"
    "setSkin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PluginWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  174,    2, 0x06 /* Public */,
       3,    5,  177,    2, 0x06 /* Public */,
       4,    2,  188,    2, 0x06 /* Public */,
       5,    0,  193,    2, 0x06 /* Public */,
       6,    0,  194,    2, 0x06 /* Public */,
       7,    0,  195,    2, 0x06 /* Public */,
       8,    0,  196,    2, 0x06 /* Public */,
       9,    0,  197,    2, 0x06 /* Public */,
      10,    1,  198,    2, 0x06 /* Public */,
      11,    0,  201,    2, 0x06 /* Public */,
      12,    1,  202,    2, 0x06 /* Public */,
      13,    1,  205,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,  208,    2, 0x08 /* Private */,
      17,    0,  211,    2, 0x08 /* Private */,
      18,    2,  212,    2, 0x08 /* Private */,
      21,    0,  217,    2, 0x08 /* Private */,
      22,    0,  218,    2, 0x08 /* Private */,
      23,    0,  219,    2, 0x08 /* Private */,
      24,    2,  220,    2, 0x08 /* Private */,
      25,    0,  225,    2, 0x08 /* Private */,
      26,    0,  226,    2, 0x08 /* Private */,
      27,    0,  227,    2, 0x08 /* Private */,
      28,    0,  228,    2, 0x08 /* Private */,
      29,    0,  229,    2, 0x08 /* Private */,
      30,    0,  230,    2, 0x08 /* Private */,
      31,    0,  231,    2, 0x08 /* Private */,
      32,    0,  232,    2, 0x08 /* Private */,
      33,    0,  233,    2, 0x08 /* Private */,
      34,    0,  234,    2, 0x08 /* Private */,
      35,    1,  235,    2, 0x08 /* Private */,
      36,    0,  238,    2, 0x08 /* Private */,
      37,    0,  239,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   19,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void PluginWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PluginWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changeGameSession((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->closeBoard((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 2: _t->setElement((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->accepted(); break;
        case 4: _t->error(); break;
        case 5: _t->lose(); break;
        case 6: _t->draw(); break;
        case 7: _t->switchColor(); break;
        case 8: _t->load((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 9: _t->sendNewInvite(); break;
        case 10: _t->doPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->playSound((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->changeGameStatus((*reinterpret_cast< GameModel::GameStatus(*)>(_a[1]))); break;
        case 13: _t->turnSelected(); break;
        case 14: _t->setupElement((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 15: _t->acceptStep(); break;
        case 16: _t->setAccept(); break;
        case 17: _t->setError(); break;
        case 18: _t->setTurn((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 19: _t->setSwitchColor(); break;
        case 20: _t->doSwitchColor(); break;
        case 21: _t->setLose(); break;
        case 22: _t->setDraw(); break;
        case 23: _t->setResign(); break;
        case 24: _t->setWin(); break;
        case 25: _t->setClose(); break;
        case 26: _t->newGame(); break;
        case 27: _t->saveGame(); break;
        case 28: _t->loadGame(); break;
        case 29: _t->loadRemoteGame((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 30: _t->opponentDraw(); break;
        case 31: _t->setSkin(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PluginWindow::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::changeGameSession)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)(bool , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::closeBoard)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::setElement)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::accepted)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::error)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::lose)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::draw)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::switchColor)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::load)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::sendNewInvite)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::doPopup)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (PluginWindow::*)(const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PluginWindow::playSound)) {
                *result = 11;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PluginWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_PluginWindow.data,
    qt_meta_data_PluginWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PluginWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PluginWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int PluginWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void PluginWindow::changeGameSession(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void PluginWindow::closeBoard(bool _t1, int _t2, int _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PluginWindow::setElement(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void PluginWindow::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PluginWindow::error()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PluginWindow::lose()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PluginWindow::draw()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PluginWindow::switchColor()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PluginWindow::load(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void PluginWindow::sendNewInvite()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PluginWindow::doPopup(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void PluginWindow::playSound(const QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
