/********************************************************************************
** Form generated from reading UI file 'pluginwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLUGINWINDOW_H
#define UI_PLUGINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "boardview.h"
#include "pluginwindow.h"

QT_BEGIN_NAMESPACE

class Ui_PluginWindow
{
public:
    QAction *actionNewGame;
    QAction *actionLoadGame;
    QAction *actionSaveGame;
    QAction *actionQuit;
    QAction *actionResign;
    QAction *actionSwitchColor;
    QAction *actionSkin0;
    QAction *actionSkin1;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QLabel *lbOpponent;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QLabel *lbStatus;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_4;
    BoardView *board;
    QVBoxLayout *verticalLayout;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_3;
    HintElementWidget *hintElement;
    QSpacerItem *horizontalSpacer_4;
    QFrame *line;
    QListWidget *lsTurnsList;
    QMenuBar *menubar;
    QMenu *menuGame;
    QMenu *menuSkin;
    QMenu *menuFile;

    void setupUi(QMainWindow *PluginWindow)
    {
        if (PluginWindow->objectName().isEmpty())
            PluginWindow->setObjectName(QString::fromUtf8("PluginWindow"));
        PluginWindow->resize(535, 488);
        actionNewGame = new QAction(PluginWindow);
        actionNewGame->setObjectName(QString::fromUtf8("actionNewGame"));
        actionLoadGame = new QAction(PluginWindow);
        actionLoadGame->setObjectName(QString::fromUtf8("actionLoadGame"));
        actionSaveGame = new QAction(PluginWindow);
        actionSaveGame->setObjectName(QString::fromUtf8("actionSaveGame"));
        actionQuit = new QAction(PluginWindow);
        actionQuit->setObjectName(QString::fromUtf8("actionQuit"));
        actionResign = new QAction(PluginWindow);
        actionResign->setObjectName(QString::fromUtf8("actionResign"));
        actionSwitchColor = new QAction(PluginWindow);
        actionSwitchColor->setObjectName(QString::fromUtf8("actionSwitchColor"));
        actionSkin0 = new QAction(PluginWindow);
        actionSkin0->setObjectName(QString::fromUtf8("actionSkin0"));
        actionSkin0->setCheckable(true);
        actionSkin0->setChecked(true);
        actionSkin1 = new QAction(PluginWindow);
        actionSkin1->setObjectName(QString::fromUtf8("actionSkin1"));
        actionSkin1->setCheckable(true);
        centralwidget = new QWidget(PluginWindow);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        verticalLayout_2 = new QVBoxLayout(centralwidget);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(centralwidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        lbOpponent = new QLabel(centralwidget);
        lbOpponent->setObjectName(QString::fromUtf8("lbOpponent"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lbOpponent->sizePolicy().hasHeightForWidth());
        lbOpponent->setSizePolicy(sizePolicy);
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        lbOpponent->setFont(font);

        horizontalLayout_2->addWidget(lbOpponent);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_2 = new QLabel(centralwidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_3->addWidget(label_2);

        lbStatus = new QLabel(centralwidget);
        lbStatus->setObjectName(QString::fromUtf8("lbStatus"));
        sizePolicy.setHeightForWidth(lbStatus->sizePolicy().hasHeightForWidth());
        lbStatus->setSizePolicy(sizePolicy);
        lbStatus->setFont(font);

        horizontalLayout_3->addWidget(lbStatus);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        board = new BoardView(centralwidget);
        board->setObjectName(QString::fromUtf8("board"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(board->sizePolicy().hasHeightForWidth());
        board->setSizePolicy(sizePolicy1);
        board->setMouseTracking(true);
        board->setSelectionMode(QAbstractItemView::SingleSelection);
        board->setShowGrid(false);
        board->horizontalHeader()->setVisible(false);
        board->verticalHeader()->setVisible(false);

        horizontalLayout_4->addWidget(board);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        line_2 = new QFrame(centralwidget);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::HLine);
        line_2->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        hintElement = new HintElementWidget(centralwidget);
        hintElement->setObjectName(QString::fromUtf8("hintElement"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(110);
        sizePolicy2.setVerticalStretch(110);
        sizePolicy2.setHeightForWidth(hintElement->sizePolicy().hasHeightForWidth());
        hintElement->setSizePolicy(sizePolicy2);
        hintElement->setMinimumSize(QSize(110, 110));
        hintElement->setMaximumSize(QSize(110, 110));
        hintElement->setFrameShape(QFrame::StyledPanel);
        hintElement->setFrameShadow(QFrame::Raised);

        horizontalLayout->addWidget(hintElement);

        horizontalSpacer_4 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(centralwidget);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        lsTurnsList = new QListWidget(centralwidget);
        lsTurnsList->setObjectName(QString::fromUtf8("lsTurnsList"));
        lsTurnsList->setMinimumSize(QSize(135, 0));
        lsTurnsList->setMaximumSize(QSize(135, 16777215));
        lsTurnsList->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        lsTurnsList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        verticalLayout->addWidget(lsTurnsList);


        horizontalLayout_4->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_4);

        PluginWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(PluginWindow);
        menubar->setObjectName(QString::fromUtf8("menubar"));
        menubar->setGeometry(QRect(0, 0, 535, 21));
        menuGame = new QMenu(menubar);
        menuGame->setObjectName(QString::fromUtf8("menuGame"));
        menuSkin = new QMenu(menuGame);
        menuSkin->setObjectName(QString::fromUtf8("menuSkin"));
        menuFile = new QMenu(menubar);
        menuFile->setObjectName(QString::fromUtf8("menuFile"));
        PluginWindow->setMenuBar(menubar);

        menubar->addAction(menuFile->menuAction());
        menubar->addAction(menuGame->menuAction());
        menuGame->addAction(actionResign);
        menuGame->addAction(actionSwitchColor);
        menuGame->addAction(menuSkin->menuAction());
        menuSkin->addAction(actionSkin0);
        menuSkin->addAction(actionSkin1);
        menuFile->addAction(actionNewGame);
        menuFile->addSeparator();
        menuFile->addAction(actionLoadGame);
        menuFile->addAction(actionSaveGame);
        menuFile->addSeparator();
        menuFile->addAction(actionQuit);

        retranslateUi(PluginWindow);
        QObject::connect(actionQuit, SIGNAL(triggered()), PluginWindow, SLOT(close()));
        QObject::connect(actionSwitchColor, SIGNAL(triggered()), PluginWindow, SLOT(doSwitchColor()));
        QObject::connect(actionSaveGame, SIGNAL(triggered()), PluginWindow, SLOT(saveGame()));
        QObject::connect(actionLoadGame, SIGNAL(triggered()), PluginWindow, SLOT(loadGame()));
        QObject::connect(actionResign, SIGNAL(triggered()), PluginWindow, SLOT(setResign()));
        QObject::connect(lsTurnsList, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), PluginWindow, SLOT(turnSelected()));
        QObject::connect(actionNewGame, SIGNAL(triggered()), PluginWindow, SLOT(newGame()));
        QObject::connect(actionSkin0, SIGNAL(triggered()), PluginWindow, SLOT(setSkin()));
        QObject::connect(actionSkin1, SIGNAL(triggered()), PluginWindow, SLOT(setSkin()));

        QMetaObject::connectSlotsByName(PluginWindow);
    } // setupUi

    void retranslateUi(QMainWindow *PluginWindow)
    {
        PluginWindow->setWindowTitle(QCoreApplication::translate("PluginWindow", "Gomoku Game", nullptr));
        actionNewGame->setText(QCoreApplication::translate("PluginWindow", "New game", nullptr));
        actionLoadGame->setText(QCoreApplication::translate("PluginWindow", "Load game", nullptr));
        actionSaveGame->setText(QCoreApplication::translate("PluginWindow", "Save game", nullptr));
        actionQuit->setText(QCoreApplication::translate("PluginWindow", "Quit", nullptr));
        actionResign->setText(QCoreApplication::translate("PluginWindow", "Resign", nullptr));
        actionSwitchColor->setText(QCoreApplication::translate("PluginWindow", "Switch color", nullptr));
        actionSkin0->setText(QCoreApplication::translate("PluginWindow", "Standard", nullptr));
        actionSkin1->setText(QCoreApplication::translate("PluginWindow", "Yellow wood", nullptr));
        label->setText(QCoreApplication::translate("PluginWindow", "Opponent:", nullptr));
        lbOpponent->setText(QString());
        label_2->setText(QCoreApplication::translate("PluginWindow", "Status:", nullptr));
        lbStatus->setText(QString());
        menuGame->setTitle(QCoreApplication::translate("PluginWindow", "Game", nullptr));
        menuSkin->setTitle(QCoreApplication::translate("PluginWindow", "Skin", nullptr));
        menuFile->setTitle(QCoreApplication::translate("PluginWindow", "File", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PluginWindow: public Ui_PluginWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLUGINWINDOW_H
