/********************************************************************************
** Form generated from reading UI file 'optionswidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONSWIDGET_H
#define UI_OPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OptionsWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *le_shortcut;
    QLabel *label_7;
    QLabel *label_8;
    QLineEdit *le_filename;
    QComboBox *cb_format;
    QPushButton *pb_modify;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *rb_desktop;
    QRadioButton *rb_window;
    QRadioButton *rb_area;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_5;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *cb_hack;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QListWidget *lw_servers;
    QLabel *label_2;
    QVBoxLayout *verticalLayout_2;
    QPushButton *pb_add;
    QPushButton *pb_del;
    QPushButton *pb_edit;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer_4;
    QLabel *lb_wiki;

    void setupUi(QWidget *OptionsWidget)
    {
        if (OptionsWidget->objectName().isEmpty())
            OptionsWidget->setObjectName(QString::fromUtf8("OptionsWidget"));
        OptionsWidget->resize(549, 394);
        verticalLayout_3 = new QVBoxLayout(OptionsWidget);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(OptionsWidget);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        le_shortcut = new QLineEdit(OptionsWidget);
        le_shortcut->setObjectName(QString::fromUtf8("le_shortcut"));
        le_shortcut->setReadOnly(true);

        gridLayout->addWidget(le_shortcut, 0, 1, 1, 1);

        label_7 = new QLabel(OptionsWidget);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 1, 0, 1, 1);

        label_8 = new QLabel(OptionsWidget);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout->addWidget(label_8, 2, 0, 1, 1);

        le_filename = new QLineEdit(OptionsWidget);
        le_filename->setObjectName(QString::fromUtf8("le_filename"));

        gridLayout->addWidget(le_filename, 2, 1, 1, 1);

        cb_format = new QComboBox(OptionsWidget);
        cb_format->setObjectName(QString::fromUtf8("cb_format"));

        gridLayout->addWidget(cb_format, 1, 1, 1, 1);

        pb_modify = new QPushButton(OptionsWidget);
        pb_modify->setObjectName(QString::fromUtf8("pb_modify"));

        gridLayout->addWidget(pb_modify, 0, 2, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        groupBox = new QGroupBox(OptionsWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        horizontalLayout_3 = new QHBoxLayout(groupBox);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        rb_desktop = new QRadioButton(groupBox);
        rb_desktop->setObjectName(QString::fromUtf8("rb_desktop"));

        horizontalLayout_3->addWidget(rb_desktop);

        rb_window = new QRadioButton(groupBox);
        rb_window->setObjectName(QString::fromUtf8("rb_window"));

        horizontalLayout_3->addWidget(rb_window);

        rb_area = new QRadioButton(groupBox);
        rb_area->setObjectName(QString::fromUtf8("rb_area"));

        horizontalLayout_3->addWidget(rb_area);


        verticalLayout_3->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_5 = new QLabel(OptionsWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_2->addWidget(label_5);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        cb_hack = new QCheckBox(OptionsWidget);
        cb_hack->setObjectName(QString::fromUtf8("cb_hack"));

        horizontalLayout_2->addWidget(cb_hack);


        verticalLayout_3->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        lw_servers = new QListWidget(OptionsWidget);
        lw_servers->setObjectName(QString::fromUtf8("lw_servers"));
        lw_servers->setDragEnabled(true);
        lw_servers->setDragDropOverwriteMode(true);
        lw_servers->setDragDropMode(QAbstractItemView::DragDrop);
        lw_servers->setDefaultDropAction(Qt::MoveAction);

        verticalLayout->addWidget(lw_servers);

        label_2 = new QLabel(OptionsWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        QFont font;
        font.setFamily(QString::fromUtf8("Sans Serif"));
        font.setPointSize(8);
        label_2->setFont(font);

        verticalLayout->addWidget(label_2);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        pb_add = new QPushButton(OptionsWidget);
        pb_add->setObjectName(QString::fromUtf8("pb_add"));

        verticalLayout_2->addWidget(pb_add);

        pb_del = new QPushButton(OptionsWidget);
        pb_del->setObjectName(QString::fromUtf8("pb_del"));

        verticalLayout_2->addWidget(pb_del);

        pb_edit = new QPushButton(OptionsWidget);
        pb_edit->setObjectName(QString::fromUtf8("pb_edit"));

        verticalLayout_2->addWidget(pb_edit);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);

        horizontalSpacer_4 = new QSpacerItem(13, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        verticalLayout_3->addLayout(horizontalLayout);

        lb_wiki = new QLabel(OptionsWidget);
        lb_wiki->setObjectName(QString::fromUtf8("lb_wiki"));
        lb_wiki->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(lb_wiki);


        retranslateUi(OptionsWidget);

        QMetaObject::connectSlotsByName(OptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *OptionsWidget)
    {
        OptionsWidget->setWindowTitle(QCoreApplication::translate("OptionsWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("OptionsWidget", "Shortcut:", nullptr));
        label_7->setText(QCoreApplication::translate("OptionsWidget", "Format:", nullptr));
        label_8->setText(QCoreApplication::translate("OptionsWidget", "File Name:", nullptr));
#if QT_CONFIG(tooltip)
        pb_modify->setToolTip(QCoreApplication::translate("OptionsWidget", "Modify hotkey", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_modify->setText(QCoreApplication::translate("OptionsWidget", "Modify", nullptr));
        groupBox->setTitle(QCoreApplication::translate("OptionsWidget", "Default action", nullptr));
        rb_desktop->setText(QCoreApplication::translate("OptionsWidget", "Capture the desktop", nullptr));
        rb_window->setText(QCoreApplication::translate("OptionsWidget", "Capture active window", nullptr));
        rb_area->setText(QCoreApplication::translate("OptionsWidget", "Select capture area", nullptr));
        label_5->setText(QCoreApplication::translate("OptionsWidget", "Servers:", nullptr));
        cb_hack->setText(QString());
        label_2->setText(QCoreApplication::translate("OptionsWidget", "*to specify the order of servers, use the drag-n-drop ", nullptr));
#if QT_CONFIG(tooltip)
        pb_add->setToolTip(QCoreApplication::translate("OptionsWidget", "Add new server", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_add->setText(QCoreApplication::translate("OptionsWidget", "Add", nullptr));
#if QT_CONFIG(tooltip)
        pb_del->setToolTip(QCoreApplication::translate("OptionsWidget", "Delete current server", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_del->setText(QCoreApplication::translate("OptionsWidget", "Delete", nullptr));
#if QT_CONFIG(tooltip)
        pb_edit->setToolTip(QCoreApplication::translate("OptionsWidget", "Edit current server", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_edit->setText(QCoreApplication::translate("OptionsWidget", "Edit", nullptr));
        lb_wiki->setText(QCoreApplication::translate("OptionsWidget", "<a href=\"http://psi-plus.com/wiki/plugins#screenshot_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OptionsWidget: public Ui_OptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONSWIDGET_H
