/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QSpinBox *sb_delay;
    QLabel *label_5;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cb_disable_dnd;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *cb_tune;
    QCheckBox *cb_mood;
    QCheckBox *cb_activity;
    QCheckBox *cb_geoloc;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *le_sound;
    QToolButton *pb_get;
    QToolButton *pb_check;
    QSpacerItem *verticalSpacer;
    QLabel *wiki;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(339, 367);
        verticalLayout_2 = new QVBoxLayout(Options);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_4 = new QLabel(Options);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout->addWidget(label_4);

        sb_delay = new QSpinBox(Options);
        sb_delay->setObjectName(QString::fromUtf8("sb_delay"));
        sb_delay->setMinimum(3);
        sb_delay->setMaximum(999);

        horizontalLayout->addWidget(sb_delay);

        label_5 = new QLabel(Options);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout->addWidget(label_5);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        cb_disable_dnd = new QCheckBox(Options);
        cb_disable_dnd->setObjectName(QString::fromUtf8("cb_disable_dnd"));

        verticalLayout_2->addWidget(cb_disable_dnd);

        groupBox = new QGroupBox(Options);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        cb_tune = new QCheckBox(groupBox);
        cb_tune->setObjectName(QString::fromUtf8("cb_tune"));

        verticalLayout->addWidget(cb_tune);

        cb_mood = new QCheckBox(groupBox);
        cb_mood->setObjectName(QString::fromUtf8("cb_mood"));

        verticalLayout->addWidget(cb_mood);

        cb_activity = new QCheckBox(groupBox);
        cb_activity->setObjectName(QString::fromUtf8("cb_activity"));

        verticalLayout->addWidget(cb_activity);

        cb_geoloc = new QCheckBox(groupBox);
        cb_geoloc->setObjectName(QString::fromUtf8("cb_geoloc"));

        verticalLayout->addWidget(cb_geoloc);


        verticalLayout_2->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_3 = new QLabel(Options);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_2->addWidget(label_3);

        le_sound = new QLineEdit(Options);
        le_sound->setObjectName(QString::fromUtf8("le_sound"));

        horizontalLayout_2->addWidget(le_sound);

        pb_get = new QToolButton(Options);
        pb_get->setObjectName(QString::fromUtf8("pb_get"));

        horizontalLayout_2->addWidget(pb_get);

        pb_check = new QToolButton(Options);
        pb_check->setObjectName(QString::fromUtf8("pb_check"));

        horizontalLayout_2->addWidget(pb_check);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        wiki = new QLabel(Options);
        wiki->setObjectName(QString::fromUtf8("wiki"));
        wiki->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(wiki);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
#if QT_CONFIG(whatsthis)
        label_4->setWhatsThis(QCoreApplication::translate("Options", "Per contact delay between the popup notifications of the same events", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_4->setText(QCoreApplication::translate("Options", "Delay between popups", nullptr));
#if QT_CONFIG(whatsthis)
        sb_delay->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        label_5->setText(QCoreApplication::translate("Options", "seconds", nullptr));
        cb_disable_dnd->setText(QCoreApplication::translate("Options", "Disable popups if status is DND", nullptr));
        groupBox->setTitle(QCoreApplication::translate("Options", "Enable notifications for:", nullptr));
        cb_tune->setText(QCoreApplication::translate("Options", "Tune", nullptr));
        cb_mood->setText(QCoreApplication::translate("Options", "Mood", nullptr));
        cb_activity->setText(QCoreApplication::translate("Options", "Activity", nullptr));
        cb_geoloc->setText(QCoreApplication::translate("Options", "Geolocation", nullptr));
        label_3->setText(QCoreApplication::translate("Options", "Sound:", nullptr));
        pb_get->setText(QString());
        pb_check->setText(QString());
        wiki->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#pep_change_notify_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
