/****************************************************************************
** Meta object code from reading C++ file 'psiotrclosure.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../src/psiotrclosure.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'psiotrclosure.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_psiotr__AuthenticationDialog_t {
    QByteArrayData data[7];
    char stringdata0[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_psiotr__AuthenticationDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_psiotr__AuthenticationDialog_t qt_meta_stringdata_psiotr__AuthenticationDialog = {
    {
QT_MOC_LITERAL(0, 0, 28), // "psiotr::AuthenticationDialog"
QT_MOC_LITERAL(1, 29, 6), // "reject"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 12), // "changeMethod"
QT_MOC_LITERAL(4, 50, 5), // "index"
QT_MOC_LITERAL(5, 56, 17), // "checkRequirements"
QT_MOC_LITERAL(6, 74, 19) // "startAuthentication"

    },
    "psiotr::AuthenticationDialog\0reject\0"
    "\0changeMethod\0index\0checkRequirements\0"
    "startAuthentication"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_psiotr__AuthenticationDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x0a /* Public */,
       3,    1,   35,    2, 0x08 /* Private */,
       5,    0,   38,    2, 0x08 /* Private */,
       6,    0,   39,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void psiotr::AuthenticationDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AuthenticationDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->reject(); break;
        case 1: _t->changeMethod((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->checkRequirements(); break;
        case 3: _t->startAuthentication(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject psiotr::AuthenticationDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_psiotr__AuthenticationDialog.data,
    qt_meta_data_psiotr__AuthenticationDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *psiotr::AuthenticationDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *psiotr::AuthenticationDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_psiotr__AuthenticationDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int psiotr::AuthenticationDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_psiotr__PsiOtrClosure_t {
    QByteArrayData data[10];
    char stringdata0[114];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_psiotr__PsiOtrClosure_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_psiotr__PsiOtrClosure_t qt_meta_stringdata_psiotr__PsiOtrClosure = {
    {
QT_MOC_LITERAL(0, 0, 21), // "psiotr::PsiOtrClosure"
QT_MOC_LITERAL(1, 22, 15), // "initiateSession"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 1), // "b"
QT_MOC_LITERAL(4, 41, 10), // "endSession"
QT_MOC_LITERAL(5, 52, 19), // "authenticateContact"
QT_MOC_LITERAL(6, 72, 9), // "sessionID"
QT_MOC_LITERAL(7, 82, 11), // "fingerprint"
QT_MOC_LITERAL(8, 94, 8), // "showMenu"
QT_MOC_LITERAL(9, 103, 10) // "finishAuth"

    },
    "psiotr::PsiOtrClosure\0initiateSession\0"
    "\0b\0endSession\0authenticateContact\0"
    "sessionID\0fingerprint\0showMenu\0"
    "finishAuth"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_psiotr__PsiOtrClosure[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x0a /* Public */,
       4,    1,   52,    2, 0x0a /* Public */,
       5,    1,   55,    2, 0x0a /* Public */,
       6,    1,   58,    2, 0x0a /* Public */,
       7,    1,   61,    2, 0x0a /* Public */,
       8,    0,   64,    2, 0x0a /* Public */,
       9,    0,   65,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void psiotr::PsiOtrClosure::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PsiOtrClosure *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->initiateSession((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->endSession((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->authenticateContact((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->sessionID((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->fingerprint((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->showMenu(); break;
        case 6: _t->finishAuth(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject psiotr::PsiOtrClosure::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_psiotr__PsiOtrClosure.data,
    qt_meta_data_psiotr__PsiOtrClosure,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *psiotr::PsiOtrClosure::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *psiotr::PsiOtrClosure::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_psiotr__PsiOtrClosure.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int psiotr::PsiOtrClosure::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
