/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "boardview.h"

QT_BEGIN_NAMESPACE

class Ui_ChessWindow
{
public:
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QTextEdit *te_moves;
    BoardView *tv_board;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *white_layout;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *black_layout;
    QSpacerItem *horizontalSpacer_2;
    QMenuBar *menubar;

    void setupUi(QMainWindow *ChessWindow)
    {
        if (ChessWindow->objectName().isEmpty())
            ChessWindow->setObjectName(QString::fromUtf8("ChessWindow"));
        ChessWindow->resize(612, 554);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ChessWindow->sizePolicy().hasHeightForWidth());
        ChessWindow->setSizePolicy(sizePolicy);
        ChessWindow->setMaximumSize(QSize(5000, 5000));
        centralwidget = new QWidget(ChessWindow);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        verticalLayout_3 = new QVBoxLayout(centralwidget);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label = new QLabel(centralwidget);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout_2->addWidget(label);

        te_moves = new QTextEdit(centralwidget);
        te_moves->setObjectName(QString::fromUtf8("te_moves"));
        te_moves->setEnabled(true);
        te_moves->setMaximumSize(QSize(170, 16777215));
        te_moves->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        te_moves->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        te_moves->setReadOnly(true);

        verticalLayout_2->addWidget(te_moves);


        horizontalLayout->addLayout(verticalLayout_2);

        tv_board = new BoardView(centralwidget);
        tv_board->setObjectName(QString::fromUtf8("tv_board"));
        sizePolicy.setHeightForWidth(tv_board->sizePolicy().hasHeightForWidth());
        tv_board->setSizePolicy(sizePolicy);
        tv_board->setMinimumSize(QSize(414, 423));
        tv_board->setMaximumSize(QSize(414, 423));
        tv_board->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        tv_board->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        tv_board->setCornerButtonEnabled(false);
        tv_board->horizontalHeader()->setMinimumSectionSize(50);
        tv_board->horizontalHeader()->setDefaultSectionSize(50);
        tv_board->verticalHeader()->setMinimumSectionSize(50);
        tv_board->verticalHeader()->setDefaultSectionSize(50);

        horizontalLayout->addWidget(tv_board);


        verticalLayout_3->addLayout(horizontalLayout);

        widget = new QWidget(centralwidget);
        widget->setObjectName(QString::fromUtf8("widget"));
        widget->setMinimumSize(QSize(0, 80));
        widget->setMaximumSize(QSize(16777215, 80));
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        white_layout = new QHBoxLayout();
        white_layout->setObjectName(QString::fromUtf8("white_layout"));
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        white_layout->addItem(horizontalSpacer);


        verticalLayout->addLayout(white_layout);

        black_layout = new QHBoxLayout();
        black_layout->setObjectName(QString::fromUtf8("black_layout"));
        horizontalSpacer_2 = new QSpacerItem(380, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        black_layout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(black_layout);


        verticalLayout_3->addWidget(widget);

        ChessWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(ChessWindow);
        menubar->setObjectName(QString::fromUtf8("menubar"));
        menubar->setGeometry(QRect(0, 0, 612, 25));
        ChessWindow->setMenuBar(menubar);

        retranslateUi(ChessWindow);

        QMetaObject::connectSlotsByName(ChessWindow);
    } // setupUi

    void retranslateUi(QMainWindow *ChessWindow)
    {
        ChessWindow->setWindowTitle(QCoreApplication::translate("ChessWindow", "Chess Board", nullptr));
        label->setText(QCoreApplication::translate("ChessWindow", "Moves:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChessWindow: public Ui_ChessWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
