/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *sb_count;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cb_dontHide;
    QCheckBox *cb_disableDND;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *le_sound;
    QToolButton *tb_open;
    QToolButton *tb_test;
    QSpacerItem *verticalSpacer;
    QLabel *wiki;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(502, 172);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(Options);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        sb_count = new QSpinBox(Options);
        sb_count->setObjectName(QString::fromUtf8("sb_count"));

        horizontalLayout->addWidget(sb_count);

        label_2 = new QLabel(Options);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        cb_dontHide = new QCheckBox(Options);
        cb_dontHide->setObjectName(QString::fromUtf8("cb_dontHide"));

        verticalLayout->addWidget(cb_dontHide);

        cb_disableDND = new QCheckBox(Options);
        cb_disableDND->setObjectName(QString::fromUtf8("cb_disableDND"));

        verticalLayout->addWidget(cb_disableDND);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_3 = new QLabel(Options);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_2->addWidget(label_3);

        le_sound = new QLineEdit(Options);
        le_sound->setObjectName(QString::fromUtf8("le_sound"));

        horizontalLayout_2->addWidget(le_sound);

        tb_open = new QToolButton(Options);
        tb_open->setObjectName(QString::fromUtf8("tb_open"));

        horizontalLayout_2->addWidget(tb_open);

        tb_test = new QToolButton(Options);
        tb_test->setObjectName(QString::fromUtf8("tb_test"));

        horizontalLayout_2->addWidget(tb_test);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        wiki = new QLabel(Options);
        wiki->setObjectName(QString::fromUtf8("wiki"));
        wiki->setOpenExternalLinks(true);

        verticalLayout->addWidget(wiki);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        label->setText(QCoreApplication::translate("Options", "Allow receiving one Attention from the same contact every", nullptr));
        label_2->setText(QCoreApplication::translate("Options", "sec", nullptr));
        cb_dontHide->setText(QCoreApplication::translate("Options", "Don't hide popup if status is Away or XA", nullptr));
        cb_disableDND->setText(QCoreApplication::translate("Options", "Disable notifications if status is DND", nullptr));
        label_3->setText(QCoreApplication::translate("Options", "Play sound:", nullptr));
        tb_open->setText(QString());
        tb_test->setText(QString());
        wiki->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#attention_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
