/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QHBoxLayout *horizontalLayout_4;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    QToolButton *btAddRule;
    QToolButton *btRemoveRule;
    QToolButton *btUpRule;
    QToolButton *btDownRule;
    QSpacerItem *horizontalSpacer;
    QListWidget *lwRules;
    QWidget *wRulePane;
    QVBoxLayout *verticalLayout_3;
    QWidget *widget_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QLineEdit *lneRuleName;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QWidget *widget_3;
    QHBoxLayout *horizontalLayout_3;
    QToolButton *btAddCondition;
    QToolButton *btRemoveCondition;
    QToolButton *btUpCondition;
    QToolButton *btDownCondition;
    QSpacerItem *horizontalSpacer_2;
    QTableWidget *twConditions;
    QCheckBox *chkShowMessage;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(993, 558);
        horizontalLayout_4 = new QHBoxLayout(Options);
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        groupBox = new QGroupBox(Options);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        widget = new QWidget(groupBox);
        widget->setObjectName(QString::fromUtf8("widget"));
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        btAddRule = new QToolButton(widget);
        btAddRule->setObjectName(QString::fromUtf8("btAddRule"));

        horizontalLayout->addWidget(btAddRule);

        btRemoveRule = new QToolButton(widget);
        btRemoveRule->setObjectName(QString::fromUtf8("btRemoveRule"));

        horizontalLayout->addWidget(btRemoveRule);

        btUpRule = new QToolButton(widget);
        btUpRule->setObjectName(QString::fromUtf8("btUpRule"));

        horizontalLayout->addWidget(btUpRule);

        btDownRule = new QToolButton(widget);
        btDownRule->setObjectName(QString::fromUtf8("btDownRule"));

        horizontalLayout->addWidget(btDownRule);

        horizontalSpacer = new QSpacerItem(69, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addWidget(widget);

        lwRules = new QListWidget(groupBox);
        lwRules->setObjectName(QString::fromUtf8("lwRules"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lwRules->sizePolicy().hasHeightForWidth());
        lwRules->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(lwRules);


        horizontalLayout_4->addWidget(groupBox);

        wRulePane = new QWidget(Options);
        wRulePane->setObjectName(QString::fromUtf8("wRulePane"));
        verticalLayout_3 = new QVBoxLayout(wRulePane);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        widget_2 = new QWidget(wRulePane);
        widget_2->setObjectName(QString::fromUtf8("widget_2"));
        horizontalLayout_2 = new QHBoxLayout(widget_2);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(widget_2);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        lneRuleName = new QLineEdit(widget_2);
        lneRuleName->setObjectName(QString::fromUtf8("lneRuleName"));

        horizontalLayout_2->addWidget(lneRuleName);


        verticalLayout_3->addWidget(widget_2);

        groupBox_2 = new QGroupBox(wRulePane);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        widget_3 = new QWidget(groupBox_2);
        widget_3->setObjectName(QString::fromUtf8("widget_3"));
        horizontalLayout_3 = new QHBoxLayout(widget_3);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        btAddCondition = new QToolButton(widget_3);
        btAddCondition->setObjectName(QString::fromUtf8("btAddCondition"));

        horizontalLayout_3->addWidget(btAddCondition);

        btRemoveCondition = new QToolButton(widget_3);
        btRemoveCondition->setObjectName(QString::fromUtf8("btRemoveCondition"));

        horizontalLayout_3->addWidget(btRemoveCondition);

        btUpCondition = new QToolButton(widget_3);
        btUpCondition->setObjectName(QString::fromUtf8("btUpCondition"));

        horizontalLayout_3->addWidget(btUpCondition);

        btDownCondition = new QToolButton(widget_3);
        btDownCondition->setObjectName(QString::fromUtf8("btDownCondition"));

        horizontalLayout_3->addWidget(btDownCondition);

        horizontalSpacer_2 = new QSpacerItem(42, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout_2->addWidget(widget_3);

        twConditions = new QTableWidget(groupBox_2);
        if (twConditions->columnCount() < 3)
            twConditions->setColumnCount(3);
        twConditions->setObjectName(QString::fromUtf8("twConditions"));
        twConditions->setShowGrid(false);
        twConditions->setColumnCount(3);
        twConditions->horizontalHeader()->setVisible(false);
        twConditions->horizontalHeader()->setStretchLastSection(true);

        verticalLayout_2->addWidget(twConditions);


        verticalLayout_3->addWidget(groupBox_2);

        chkShowMessage = new QCheckBox(wRulePane);
        chkShowMessage->setObjectName(QString::fromUtf8("chkShowMessage"));

        verticalLayout_3->addWidget(chkShowMessage);


        horizontalLayout_4->addWidget(wRulePane);


        retranslateUi(Options);
        QObject::connect(lneRuleName, SIGNAL(textEdited(QString)), Options, SLOT(updateRuleName(QString)));
        QObject::connect(btAddRule, SIGNAL(clicked()), Options, SLOT(addRule()));
        QObject::connect(btRemoveRule, SIGNAL(clicked()), Options, SLOT(removeRule()));
        QObject::connect(btUpRule, SIGNAL(clicked()), Options, SLOT(upRule()));
        QObject::connect(btDownRule, SIGNAL(clicked()), Options, SLOT(downRule()));
        QObject::connect(btAddCondition, SIGNAL(clicked()), Options, SLOT(addCondition()));
        QObject::connect(btRemoveCondition, SIGNAL(clicked()), Options, SLOT(removeCondition()));
        QObject::connect(btUpCondition, SIGNAL(clicked()), Options, SLOT(upCondition()));
        QObject::connect(btDownCondition, SIGNAL(clicked()), Options, SLOT(downCondition()));
        QObject::connect(lwRules, SIGNAL(currentRowChanged(int)), Options, SLOT(setRulePane(int)));
        QObject::connect(lwRules, SIGNAL(currentRowChanged(int)), Options, SLOT(updateRuleButtons()));
        QObject::connect(twConditions, SIGNAL(currentCellChanged(int,int,int,int)), Options, SLOT(updateConditionButtons()));
        QObject::connect(btAddRule, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btRemoveRule, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btUpRule, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btDownRule, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btAddCondition, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btRemoveCondition, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btUpCondition, SIGNAL(clicked()), Options, SLOT(hack()));
        QObject::connect(btDownCondition, SIGNAL(clicked()), Options, SLOT(hack()));

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        groupBox->setTitle(QCoreApplication::translate("Options", "Rules", nullptr));
        btAddRule->setText(QCoreApplication::translate("Options", "...", nullptr));
        btRemoveRule->setText(QCoreApplication::translate("Options", "...", nullptr));
        btUpRule->setText(QCoreApplication::translate("Options", "...", nullptr));
        btDownRule->setText(QCoreApplication::translate("Options", "...", nullptr));
        label->setText(QCoreApplication::translate("Options", "Name", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("Options", "Conditions", nullptr));
        btAddCondition->setText(QCoreApplication::translate("Options", "...", nullptr));
        btRemoveCondition->setText(QCoreApplication::translate("Options", "...", nullptr));
        btUpCondition->setText(QCoreApplication::translate("Options", "...", nullptr));
        btDownCondition->setText(QCoreApplication::translate("Options", "...", nullptr));
        chkShowMessage->setText(QCoreApplication::translate("Options", "Show message if it satisfies the rule", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
