/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OptionsWidget
{
public:
    QVBoxLayout *verticalLayout_5;
    QTabWidget *tabWidget;
    QWidget *tab1;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QComboBox *cb_accounts;
    QCheckBox *cb_allaccounts;
    QSpacerItem *horizontalSpacer;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_4;
    QComboBox *cmb_lockrequ;
    QCheckBox *cb_locktimerequ;
    QSpacerItem *spacer_2;
    QGroupBox *gb_os;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout;
    QLabel *lb_ospreset;
    QComboBox *cb_ospreset;
    QLabel *lb_osname;
    QLineEdit *le_osname;
    QGroupBox *gb_client;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout_2;
    QLabel *lb_clientpreset;
    QComboBox *cb_clientpreset;
    QLabel *lb_clientname;
    QLineEdit *le_clientname;
    QLabel *lb_clientversion;
    QLineEdit *le_clientversion;
    QLabel *lb_capsnode;
    QLineEdit *le_capsnode;
    QLabel *lb_capsversion;
    QLineEdit *le_capsversion;
    QGroupBox *gb_enablefor;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *cb_contactsenable;
    QSpacerItem *spacer_3;
    QCheckBox *cb_conferencesenable;
    QSpacerItem *spacer_4;
    QGridLayout *gridLayout_3;
    QLabel *label_2;
    QComboBox *cmb_showrequ;
    QLabel *label_3;
    QComboBox *cmb_savetolog;
    QWidget *tab2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_7;
    QComboBox *cb_logslist;
    QPushButton *bt_viewlog;
    QSpacerItem *verticalSpacer_3;
    QLabel *lb_link;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OptionsWidget)
    {
        if (OptionsWidget->objectName().isEmpty())
            OptionsWidget->setObjectName(QString::fromUtf8("OptionsWidget"));
        OptionsWidget->resize(494, 515);
        verticalLayout_5 = new QVBoxLayout(OptionsWidget);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        tabWidget = new QTabWidget(OptionsWidget);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tab1 = new QWidget();
        tab1->setObjectName(QString::fromUtf8("tab1"));
        verticalLayout_4 = new QVBoxLayout(tab1);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label = new QLabel(tab1);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_3->addWidget(label);

        cb_accounts = new QComboBox(tab1);
        cb_accounts->setObjectName(QString::fromUtf8("cb_accounts"));
        cb_accounts->setMinimumSize(QSize(141, 0));

        horizontalLayout_3->addWidget(cb_accounts);

        cb_allaccounts = new QCheckBox(tab1);
        cb_allaccounts->setObjectName(QString::fromUtf8("cb_allaccounts"));

        horizontalLayout_3->addWidget(cb_allaccounts);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout_4->addLayout(horizontalLayout_3);

        scrollArea = new QScrollArea(tab1);
        scrollArea->setObjectName(QString::fromUtf8("scrollArea"));
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QString::fromUtf8("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 434, 437));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_4 = new QLabel(scrollAreaWidgetContents);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout_4->addWidget(label_4);

        cmb_lockrequ = new QComboBox(scrollAreaWidgetContents);
        cmb_lockrequ->addItem(QString());
        cmb_lockrequ->addItem(QString());
        cmb_lockrequ->addItem(QString());
        cmb_lockrequ->setObjectName(QString::fromUtf8("cmb_lockrequ"));

        horizontalLayout_4->addWidget(cmb_lockrequ);

        cb_locktimerequ = new QCheckBox(scrollAreaWidgetContents);
        cb_locktimerequ->setObjectName(QString::fromUtf8("cb_locktimerequ"));

        horizontalLayout_4->addWidget(cb_locktimerequ);

        spacer_2 = new QSpacerItem(18, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(spacer_2);


        verticalLayout_2->addLayout(horizontalLayout_4);

        gb_os = new QGroupBox(scrollAreaWidgetContents);
        gb_os->setObjectName(QString::fromUtf8("gb_os"));
        gb_os->setEnabled(true);
        horizontalLayout_2 = new QHBoxLayout(gb_os);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        lb_ospreset = new QLabel(gb_os);
        lb_ospreset->setObjectName(QString::fromUtf8("lb_ospreset"));

        gridLayout->addWidget(lb_ospreset, 0, 0, 1, 1);

        cb_ospreset = new QComboBox(gb_os);
        cb_ospreset->setObjectName(QString::fromUtf8("cb_ospreset"));

        gridLayout->addWidget(cb_ospreset, 0, 1, 1, 1);

        lb_osname = new QLabel(gb_os);
        lb_osname->setObjectName(QString::fromUtf8("lb_osname"));

        gridLayout->addWidget(lb_osname, 1, 0, 1, 1);

        le_osname = new QLineEdit(gb_os);
        le_osname->setObjectName(QString::fromUtf8("le_osname"));

        gridLayout->addWidget(le_osname, 1, 1, 1, 1);


        horizontalLayout_2->addLayout(gridLayout);


        verticalLayout_2->addWidget(gb_os);

        gb_client = new QGroupBox(scrollAreaWidgetContents);
        gb_client->setObjectName(QString::fromUtf8("gb_client"));
        horizontalLayout = new QHBoxLayout(gb_client);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        lb_clientpreset = new QLabel(gb_client);
        lb_clientpreset->setObjectName(QString::fromUtf8("lb_clientpreset"));

        gridLayout_2->addWidget(lb_clientpreset, 0, 0, 1, 1);

        cb_clientpreset = new QComboBox(gb_client);
        cb_clientpreset->setObjectName(QString::fromUtf8("cb_clientpreset"));

        gridLayout_2->addWidget(cb_clientpreset, 0, 1, 1, 1);

        lb_clientname = new QLabel(gb_client);
        lb_clientname->setObjectName(QString::fromUtf8("lb_clientname"));

        gridLayout_2->addWidget(lb_clientname, 1, 0, 1, 1);

        le_clientname = new QLineEdit(gb_client);
        le_clientname->setObjectName(QString::fromUtf8("le_clientname"));

        gridLayout_2->addWidget(le_clientname, 1, 1, 1, 1);

        lb_clientversion = new QLabel(gb_client);
        lb_clientversion->setObjectName(QString::fromUtf8("lb_clientversion"));

        gridLayout_2->addWidget(lb_clientversion, 2, 0, 1, 1);

        le_clientversion = new QLineEdit(gb_client);
        le_clientversion->setObjectName(QString::fromUtf8("le_clientversion"));

        gridLayout_2->addWidget(le_clientversion, 2, 1, 1, 1);

        lb_capsnode = new QLabel(gb_client);
        lb_capsnode->setObjectName(QString::fromUtf8("lb_capsnode"));

        gridLayout_2->addWidget(lb_capsnode, 3, 0, 1, 1);

        le_capsnode = new QLineEdit(gb_client);
        le_capsnode->setObjectName(QString::fromUtf8("le_capsnode"));

        gridLayout_2->addWidget(le_capsnode, 3, 1, 1, 1);

        lb_capsversion = new QLabel(gb_client);
        lb_capsversion->setObjectName(QString::fromUtf8("lb_capsversion"));

        gridLayout_2->addWidget(lb_capsversion, 4, 0, 1, 1);

        le_capsversion = new QLineEdit(gb_client);
        le_capsversion->setObjectName(QString::fromUtf8("le_capsversion"));

        gridLayout_2->addWidget(le_capsversion, 4, 1, 1, 1);


        horizontalLayout->addLayout(gridLayout_2);


        verticalLayout_2->addWidget(gb_client);

        gb_enablefor = new QGroupBox(scrollAreaWidgetContents);
        gb_enablefor->setObjectName(QString::fromUtf8("gb_enablefor"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gb_enablefor->sizePolicy().hasHeightForWidth());
        gb_enablefor->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(gb_enablefor);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        cb_contactsenable = new QCheckBox(gb_enablefor);
        cb_contactsenable->setObjectName(QString::fromUtf8("cb_contactsenable"));

        horizontalLayout_5->addWidget(cb_contactsenable);

        spacer_3 = new QSpacerItem(30, 20, QSizePolicy::Maximum, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(spacer_3);

        cb_conferencesenable = new QCheckBox(gb_enablefor);
        cb_conferencesenable->setObjectName(QString::fromUtf8("cb_conferencesenable"));

        horizontalLayout_5->addWidget(cb_conferencesenable);

        spacer_4 = new QSpacerItem(18, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(spacer_4);


        verticalLayout->addLayout(horizontalLayout_5);


        verticalLayout_2->addWidget(gb_enablefor);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label_2 = new QLabel(scrollAreaWidgetContents);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_3->addWidget(label_2, 0, 1, 1, 1);

        cmb_showrequ = new QComboBox(scrollAreaWidgetContents);
        cmb_showrequ->addItem(QString());
        cmb_showrequ->addItem(QString());
        cmb_showrequ->addItem(QString());
        cmb_showrequ->setObjectName(QString::fromUtf8("cmb_showrequ"));

        gridLayout_3->addWidget(cmb_showrequ, 0, 2, 1, 1);

        label_3 = new QLabel(scrollAreaWidgetContents);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout_3->addWidget(label_3, 1, 1, 1, 1);

        cmb_savetolog = new QComboBox(scrollAreaWidgetContents);
        cmb_savetolog->addItem(QString());
        cmb_savetolog->addItem(QString());
        cmb_savetolog->addItem(QString());
        cmb_savetolog->setObjectName(QString::fromUtf8("cmb_savetolog"));

        gridLayout_3->addWidget(cmb_savetolog, 1, 2, 1, 1);


        verticalLayout_2->addLayout(gridLayout_3);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_4->addWidget(scrollArea);

        tabWidget->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName(QString::fromUtf8("tab2"));
        verticalLayout_3 = new QVBoxLayout(tab2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        cb_logslist = new QComboBox(tab2);
        cb_logslist->setObjectName(QString::fromUtf8("cb_logslist"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cb_logslist->sizePolicy().hasHeightForWidth());
        cb_logslist->setSizePolicy(sizePolicy2);

        horizontalLayout_7->addWidget(cb_logslist);

        bt_viewlog = new QPushButton(tab2);
        bt_viewlog->setObjectName(QString::fromUtf8("bt_viewlog"));

        horizontalLayout_7->addWidget(bt_viewlog);


        verticalLayout_3->addLayout(horizontalLayout_7);

        verticalSpacer_3 = new QSpacerItem(20, 471, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tab2, QString());

        verticalLayout_5->addWidget(tabWidget);

        lb_link = new QLabel(OptionsWidget);
        lb_link->setObjectName(QString::fromUtf8("lb_link"));
        lb_link->setOpenExternalLinks(true);

        verticalLayout_5->addWidget(lb_link);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        QWidget::setTabOrder(tabWidget, cb_accounts);
        QWidget::setTabOrder(cb_accounts, cb_allaccounts);
        QWidget::setTabOrder(cb_allaccounts, scrollArea);
        QWidget::setTabOrder(scrollArea, cmb_lockrequ);
        QWidget::setTabOrder(cmb_lockrequ, cb_locktimerequ);
        QWidget::setTabOrder(cb_locktimerequ, cb_ospreset);
        QWidget::setTabOrder(cb_ospreset, le_osname);
        QWidget::setTabOrder(le_osname, cb_clientpreset);
        QWidget::setTabOrder(cb_clientpreset, le_clientname);
        QWidget::setTabOrder(le_clientname, le_clientversion);
        QWidget::setTabOrder(le_clientversion, le_capsnode);
        QWidget::setTabOrder(le_capsnode, le_capsversion);
        QWidget::setTabOrder(le_capsversion, cb_contactsenable);
        QWidget::setTabOrder(cb_contactsenable, cb_conferencesenable);
        QWidget::setTabOrder(cb_conferencesenable, cmb_showrequ);
        QWidget::setTabOrder(cmb_showrequ, cmb_savetolog);
        QWidget::setTabOrder(cmb_savetolog, cb_logslist);
        QWidget::setTabOrder(cb_logslist, bt_viewlog);

        retranslateUi(OptionsWidget);

        QMetaObject::connectSlotsByName(OptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *OptionsWidget)
    {
        OptionsWidget->setWindowTitle(QCoreApplication::translate("OptionsWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("OptionsWidget", "Account:", nullptr));
        cb_allaccounts->setText(QCoreApplication::translate("OptionsWidget", "For all accounts", nullptr));
        label_4->setText(QCoreApplication::translate("OptionsWidget", "Response mode", nullptr));
        cmb_lockrequ->setItemText(0, QCoreApplication::translate("OptionsWidget", "allow", nullptr));
        cmb_lockrequ->setItemText(1, QCoreApplication::translate("OptionsWidget", "not implemented", nullptr));
        cmb_lockrequ->setItemText(2, QCoreApplication::translate("OptionsWidget", "ignore", nullptr));

        cb_locktimerequ->setText(QCoreApplication::translate("OptionsWidget", "Deny iq time request", nullptr));
        gb_os->setTitle(QCoreApplication::translate("OptionsWidget", "OS", nullptr));
        lb_ospreset->setText(QCoreApplication::translate("OptionsWidget", "Template", nullptr));
        lb_osname->setText(QCoreApplication::translate("OptionsWidget", "OS name", nullptr));
        gb_client->setTitle(QCoreApplication::translate("OptionsWidget", "Client", nullptr));
        lb_clientpreset->setText(QCoreApplication::translate("OptionsWidget", "Template", nullptr));
        lb_clientname->setText(QCoreApplication::translate("OptionsWidget", "Client name", nullptr));
        lb_clientversion->setText(QCoreApplication::translate("OptionsWidget", "Client version", nullptr));
        lb_capsnode->setText(QCoreApplication::translate("OptionsWidget", "Caps node", nullptr));
        lb_capsversion->setText(QCoreApplication::translate("OptionsWidget", "Caps version", nullptr));
        gb_enablefor->setTitle(QCoreApplication::translate("OptionsWidget", "Enable for:", nullptr));
        cb_contactsenable->setText(QCoreApplication::translate("OptionsWidget", "Contacts", nullptr));
        cb_conferencesenable->setText(QCoreApplication::translate("OptionsWidget", "Groupchats", nullptr));
        label_2->setText(QCoreApplication::translate("OptionsWidget", "Show popup at version iq", nullptr));
        cmb_showrequ->setItemText(0, QCoreApplication::translate("OptionsWidget", "never", nullptr));
        cmb_showrequ->setItemText(1, QCoreApplication::translate("OptionsWidget", "if iq replaced", nullptr));
        cmb_showrequ->setItemText(2, QCoreApplication::translate("OptionsWidget", "always", nullptr));

        label_3->setText(QCoreApplication::translate("OptionsWidget", "Save queries to log", nullptr));
        cmb_savetolog->setItemText(0, QCoreApplication::translate("OptionsWidget", "never", nullptr));
        cmb_savetolog->setItemText(1, QCoreApplication::translate("OptionsWidget", "if iq replaced", nullptr));
        cmb_savetolog->setItemText(2, QCoreApplication::translate("OptionsWidget", "always", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tab1), QCoreApplication::translate("OptionsWidget", "General", nullptr));
        bt_viewlog->setText(QCoreApplication::translate("OptionsWidget", "View log", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab2), QCoreApplication::translate("OptionsWidget", "Logs", nullptr));
        lb_link->setText(QCoreApplication::translate("OptionsWidget", "<a href=\"http://psi-plus.com/wiki/plugins#client_switcher_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OptionsWidget: public Ui_OptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
