/********************************************************************************
** Form generated from reading UI file 'proxysettingsdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROXYSETTINGSDLG_H
#define UI_PROXYSETTINGSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ProxySettingsDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_5;
    QComboBox *cb_type;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QLineEdit *le_host;
    QLabel *label_2;
    QLineEdit *le_port;
    QLabel *label_3;
    QLineEdit *le_user;
    QLabel *label_4;
    QLineEdit *le_pass;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ProxySettingsDlg)
    {
        if (ProxySettingsDlg->objectName().isEmpty())
            ProxySettingsDlg->setObjectName(QString::fromUtf8("ProxySettingsDlg"));
        ProxySettingsDlg->resize(400, 200);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ProxySettingsDlg->sizePolicy().hasHeightForWidth());
        ProxySettingsDlg->setSizePolicy(sizePolicy);
        ProxySettingsDlg->setMinimumSize(QSize(400, 200));
        ProxySettingsDlg->setMaximumSize(QSize(400, 200));
        verticalLayout = new QVBoxLayout(ProxySettingsDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_5 = new QLabel(ProxySettingsDlg);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 0, 0, 1, 1);

        cb_type = new QComboBox(ProxySettingsDlg);
        cb_type->setObjectName(QString::fromUtf8("cb_type"));

        gridLayout->addWidget(cb_type, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        label = new QLabel(ProxySettingsDlg);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        le_host = new QLineEdit(ProxySettingsDlg);
        le_host->setObjectName(QString::fromUtf8("le_host"));

        gridLayout->addWidget(le_host, 1, 1, 1, 1);

        label_2 = new QLabel(ProxySettingsDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 2, 1, 1);

        le_port = new QLineEdit(ProxySettingsDlg);
        le_port->setObjectName(QString::fromUtf8("le_port"));

        gridLayout->addWidget(le_port, 1, 3, 1, 1);

        label_3 = new QLabel(ProxySettingsDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        le_user = new QLineEdit(ProxySettingsDlg);
        le_user->setObjectName(QString::fromUtf8("le_user"));

        gridLayout->addWidget(le_user, 2, 1, 1, 1);

        label_4 = new QLabel(ProxySettingsDlg);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 2, 2, 1, 1);

        le_pass = new QLineEdit(ProxySettingsDlg);
        le_pass->setObjectName(QString::fromUtf8("le_pass"));
        le_pass->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(le_pass, 2, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 38, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ProxySettingsDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ProxySettingsDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), ProxySettingsDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ProxySettingsDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(ProxySettingsDlg);
    } // setupUi

    void retranslateUi(QDialog *ProxySettingsDlg)
    {
        ProxySettingsDlg->setWindowTitle(QCoreApplication::translate("ProxySettingsDlg", "Proxy Server Settings", nullptr));
        label_5->setText(QCoreApplication::translate("ProxySettingsDlg", "Type:", nullptr));
        label->setText(QCoreApplication::translate("ProxySettingsDlg", "Host:", nullptr));
        label_2->setText(QCoreApplication::translate("ProxySettingsDlg", "Port:", nullptr));
        le_port->setInputMask(QCoreApplication::translate("ProxySettingsDlg", "99999; ", nullptr));
        label_3->setText(QCoreApplication::translate("ProxySettingsDlg", "User:", nullptr));
        label_4->setText(QCoreApplication::translate("ProxySettingsDlg", "Password:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProxySettingsDlg: public Ui_ProxySettingsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROXYSETTINGSDLG_H
