/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "view.h"

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_watchForStatus;
    QVBoxLayout *verticalLayout_2;
    Viewer *tableView;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *pb_del;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *pb_add;
    QCheckBox *cb_disableDnd;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QLineEdit *le_sound;
    QToolButton *tb_open;
    QToolButton *tb_test;
    QWidget *tab_watchForMessages;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_4;
    QListWidget *listWidget;
    QVBoxLayout *verticalLayout_3;
    QPushButton *pb_add_item;
    QPushButton *pb_delete_item;
    QPushButton *pb_edit_item;
    QSpacerItem *verticalSpacer;
    QCheckBox *cb_disable_snd;
    QWidget *tab;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *cb_showInContext;
    QSpacerItem *verticalSpacer_2;
    QLabel *label;
    QCheckBox *cb_hack;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(379, 339);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tabWidget = new QTabWidget(Options);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tab_watchForStatus = new QWidget();
        tab_watchForStatus->setObjectName(QString::fromUtf8("tab_watchForStatus"));
        verticalLayout_2 = new QVBoxLayout(tab_watchForStatus);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        tableView = new Viewer(tab_watchForStatus);
        tableView->setObjectName(QString::fromUtf8("tableView"));

        verticalLayout_2->addWidget(tableView);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        pb_del = new QPushButton(tab_watchForStatus);
        pb_del->setObjectName(QString::fromUtf8("pb_del"));

        horizontalLayout_3->addWidget(pb_del);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        pb_add = new QPushButton(tab_watchForStatus);
        pb_add->setObjectName(QString::fromUtf8("pb_add"));

        horizontalLayout_3->addWidget(pb_add);


        verticalLayout_2->addLayout(horizontalLayout_3);

        cb_disableDnd = new QCheckBox(tab_watchForStatus);
        cb_disableDnd->setObjectName(QString::fromUtf8("cb_disableDnd"));

        verticalLayout_2->addWidget(cb_disableDnd);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_2 = new QLabel(tab_watchForStatus);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        le_sound = new QLineEdit(tab_watchForStatus);
        le_sound->setObjectName(QString::fromUtf8("le_sound"));

        horizontalLayout->addWidget(le_sound);

        tb_open = new QToolButton(tab_watchForStatus);
        tb_open->setObjectName(QString::fromUtf8("tb_open"));

        horizontalLayout->addWidget(tb_open);

        tb_test = new QToolButton(tab_watchForStatus);
        tb_test->setObjectName(QString::fromUtf8("tb_test"));

        horizontalLayout->addWidget(tb_test);


        verticalLayout_2->addLayout(horizontalLayout);

        tabWidget->addTab(tab_watchForStatus, QString());
        tab_watchForMessages = new QWidget();
        tab_watchForMessages->setObjectName(QString::fromUtf8("tab_watchForMessages"));
        verticalLayout_4 = new QVBoxLayout(tab_watchForMessages);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        listWidget = new QListWidget(tab_watchForMessages);
        listWidget->setObjectName(QString::fromUtf8("listWidget"));
        listWidget->setDragEnabled(true);
        listWidget->setDragDropMode(QAbstractItemView::DragDrop);
        listWidget->setDefaultDropAction(Qt::MoveAction);

        horizontalLayout_4->addWidget(listWidget);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        pb_add_item = new QPushButton(tab_watchForMessages);
        pb_add_item->setObjectName(QString::fromUtf8("pb_add_item"));

        verticalLayout_3->addWidget(pb_add_item);

        pb_delete_item = new QPushButton(tab_watchForMessages);
        pb_delete_item->setObjectName(QString::fromUtf8("pb_delete_item"));

        verticalLayout_3->addWidget(pb_delete_item);

        pb_edit_item = new QPushButton(tab_watchForMessages);
        pb_edit_item->setObjectName(QString::fromUtf8("pb_edit_item"));

        verticalLayout_3->addWidget(pb_edit_item);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        horizontalLayout_4->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout_4);

        cb_disable_snd = new QCheckBox(tab_watchForMessages);
        cb_disable_snd->setObjectName(QString::fromUtf8("cb_disable_snd"));

        verticalLayout_4->addWidget(cb_disable_snd);

        tabWidget->addTab(tab_watchForMessages, QString());
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        verticalLayout_5 = new QVBoxLayout(tab);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        cb_showInContext = new QCheckBox(tab);
        cb_showInContext->setObjectName(QString::fromUtf8("cb_showInContext"));

        verticalLayout_5->addWidget(cb_showInContext);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(tabWidget);

        label = new QLabel(Options);
        label->setObjectName(QString::fromUtf8("label"));
        label->setOpenExternalLinks(true);

        verticalLayout->addWidget(label);

        cb_hack = new QCheckBox(Options);
        cb_hack->setObjectName(QString::fromUtf8("cb_hack"));

        verticalLayout->addWidget(cb_hack);


        retranslateUi(Options);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Options", nullptr));
        pb_del->setText(QCoreApplication::translate("Options", "Delete selected", nullptr));
        pb_add->setText(QCoreApplication::translate("Options", "Add row", nullptr));
        cb_disableDnd->setText(QCoreApplication::translate("Options", "Disable popups if status is DND", nullptr));
        label_2->setText(QCoreApplication::translate("Options", "Default sound: ", nullptr));
        tb_open->setText(QString());
        tb_test->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_watchForStatus), QCoreApplication::translate("Options", "Status", nullptr));
        pb_add_item->setText(QCoreApplication::translate("Options", "Add", nullptr));
        pb_delete_item->setText(QCoreApplication::translate("Options", "Delete", nullptr));
        pb_edit_item->setText(QCoreApplication::translate("Options", "Edit", nullptr));
        cb_disable_snd->setText(QCoreApplication::translate("Options", "Disable sound if chat window is active", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_watchForMessages), QCoreApplication::translate("Options", "Messages", nullptr));
        cb_showInContext->setText(QCoreApplication::translate("Options", "Show Watch for JID button in contact context menu", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("Options", "Misc", nullptr));
        label->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#watcher_plugin\">Wiki (Online)</a>", nullptr));
        cb_hack->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
