/********************************************************************************
** Form generated from reading UI file 'invitationdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INVITATIONDIALOG_H
#define UI_INVITATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_InvitationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lbl_text;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_accept;
    QPushButton *pb_reject;

    void setupUi(QDialog *InvitationDialog)
    {
        if (InvitationDialog->objectName().isEmpty())
            InvitationDialog->setObjectName(QString::fromUtf8("InvitationDialog"));
        InvitationDialog->resize(202, 72);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InvitationDialog->sizePolicy().hasHeightForWidth());
        InvitationDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(InvitationDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        lbl_text = new QLabel(InvitationDialog);
        lbl_text->setObjectName(QString::fromUtf8("lbl_text"));

        verticalLayout->addWidget(lbl_text);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pb_accept = new QPushButton(InvitationDialog);
        pb_accept->setObjectName(QString::fromUtf8("pb_accept"));

        horizontalLayout->addWidget(pb_accept);

        pb_reject = new QPushButton(InvitationDialog);
        pb_reject->setObjectName(QString::fromUtf8("pb_reject"));

        horizontalLayout->addWidget(pb_reject);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(InvitationDialog);

        QMetaObject::connectSlotsByName(InvitationDialog);
    } // setupUi

    void retranslateUi(QDialog *InvitationDialog)
    {
        InvitationDialog->setWindowTitle(QCoreApplication::translate("InvitationDialog", "Chess Plugin - Invitation", nullptr));
        lbl_text->setText(QString());
        pb_accept->setText(QCoreApplication::translate("InvitationDialog", "Accept", nullptr));
        pb_reject->setText(QCoreApplication::translate("InvitationDialog", "Reject", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InvitationDialog: public Ui_InvitationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INVITATIONDIALOG_H
