/********************************************************************************
** Form generated from reading UI file 'notes.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTES_H
#define UI_NOTES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_Notes
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QListView *lv_notes;
    QTreeView *tv_tags;
    QHBoxLayout *horizontalLayout;
    QPushButton *pb_add;
    QPushButton *pb_edit;
    QPushButton *pb_delete;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_load;
    QPushButton *pb_save;
    QPushButton *pb_close;

    void setupUi(QDialog *Notes)
    {
        if (Notes->objectName().isEmpty())
            Notes->setObjectName(QString::fromUtf8("Notes"));
        Notes->resize(700, 500);
        verticalLayout = new QVBoxLayout(Notes);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        lv_notes = new QListView(Notes);
        lv_notes->setObjectName(QString::fromUtf8("lv_notes"));
        lv_notes->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout_3->addWidget(lv_notes);

        tv_tags = new QTreeView(Notes);
        tv_tags->setObjectName(QString::fromUtf8("tv_tags"));
        tv_tags->setMaximumSize(QSize(150, 16777215));
        tv_tags->setIndentation(0);
        tv_tags->setRootIsDecorated(false);
        tv_tags->setItemsExpandable(false);
        tv_tags->setExpandsOnDoubleClick(false);
        tv_tags->header()->setVisible(false);

        horizontalLayout_3->addWidget(tv_tags);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pb_add = new QPushButton(Notes);
        pb_add->setObjectName(QString::fromUtf8("pb_add"));
        pb_add->setMaximumSize(QSize(24, 24));

        horizontalLayout->addWidget(pb_add);

        pb_edit = new QPushButton(Notes);
        pb_edit->setObjectName(QString::fromUtf8("pb_edit"));
        pb_edit->setMaximumSize(QSize(24, 24));

        horizontalLayout->addWidget(pb_edit);

        pb_delete = new QPushButton(Notes);
        pb_delete->setObjectName(QString::fromUtf8("pb_delete"));
        pb_delete->setMaximumSize(QSize(24, 24));

        horizontalLayout->addWidget(pb_delete);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pb_load = new QPushButton(Notes);
        pb_load->setObjectName(QString::fromUtf8("pb_load"));

        horizontalLayout_2->addWidget(pb_load);

        pb_save = new QPushButton(Notes);
        pb_save->setObjectName(QString::fromUtf8("pb_save"));

        horizontalLayout_2->addWidget(pb_save);

        pb_close = new QPushButton(Notes);
        pb_close->setObjectName(QString::fromUtf8("pb_close"));

        horizontalLayout_2->addWidget(pb_close);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(Notes);

        QMetaObject::connectSlotsByName(Notes);
    } // setupUi

    void retranslateUi(QDialog *Notes)
    {
        Notes->setWindowTitle(QCoreApplication::translate("Notes", "Notebook", nullptr));
#if QT_CONFIG(tooltip)
        pb_add->setToolTip(QCoreApplication::translate("Notes", "Add note", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_add->setText(QString());
#if QT_CONFIG(tooltip)
        pb_edit->setToolTip(QCoreApplication::translate("Notes", "Edit note", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_edit->setText(QString());
#if QT_CONFIG(tooltip)
        pb_delete->setToolTip(QCoreApplication::translate("Notes", "Delete note", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_delete->setText(QString());
#if QT_CONFIG(tooltip)
        pb_load->setToolTip(QCoreApplication::translate("Notes", "Load notes", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_load->setText(QCoreApplication::translate("Notes", "Reload", nullptr));
#if QT_CONFIG(tooltip)
        pb_save->setToolTip(QCoreApplication::translate("Notes", "Save notes", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_save->setText(QCoreApplication::translate("Notes", "Save", nullptr));
#if QT_CONFIG(tooltip)
        pb_close->setToolTip(QCoreApplication::translate("Notes", "Close window", nullptr));
#endif // QT_CONFIG(tooltip)
        pb_close->setText(QCoreApplication::translate("Notes", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Notes: public Ui_Notes {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NOTES_H
