/****************************************************************************
** Meta object code from reading C++ file 'models.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../models.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'models.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BaseModel_t {
    QByteArrayData data[3];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BaseModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BaseModel_t qt_meta_stringdata_BaseModel = {
    {
QT_MOC_LITERAL(0, 0, 9), // "BaseModel"
QT_MOC_LITERAL(1, 10, 11), // "updateLabel"
QT_MOC_LITERAL(2, 22, 0) // ""

    },
    "BaseModel\0updateLabel\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BaseModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void BaseModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BaseModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateLabel((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BaseModel::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BaseModel::updateLabel)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BaseModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_meta_stringdata_BaseModel.data,
    qt_meta_data_BaseModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BaseModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BaseModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BaseModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int BaseModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void BaseModel::updateLabel(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_BaseFileModel_t {
    QByteArrayData data[1];
    char stringdata0[14];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BaseFileModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BaseFileModel_t qt_meta_stringdata_BaseFileModel = {
    {
QT_MOC_LITERAL(0, 0, 13) // "BaseFileModel"

    },
    "BaseFileModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BaseFileModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void BaseFileModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject BaseFileModel::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseModel::staticMetaObject>(),
    qt_meta_stringdata_BaseFileModel.data,
    qt_meta_data_BaseFileModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BaseFileModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BaseFileModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BaseFileModel.stringdata0))
        return static_cast<void*>(this);
    return BaseModel::qt_metacast(_clname);
}

int BaseFileModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingModel_t {
    QByteArrayData data[1];
    char stringdata0[14];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingModel_t qt_meta_stringdata_ClearingModel = {
    {
QT_MOC_LITERAL(0, 0, 13) // "ClearingModel"

    },
    "ClearingModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingModel::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseFileModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingModel.data,
    qt_meta_data_ClearingModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingModel.stringdata0))
        return static_cast<void*>(this);
    return BaseFileModel::qt_metacast(_clname);
}

int ClearingModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseFileModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingVcardModel_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingVcardModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingVcardModel_t qt_meta_stringdata_ClearingVcardModel = {
    {
QT_MOC_LITERAL(0, 0, 18) // "ClearingVcardModel"

    },
    "ClearingVcardModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingVcardModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingVcardModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingVcardModel::staticMetaObject = { {
    QMetaObject::SuperData::link<ClearingModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingVcardModel.data,
    qt_meta_data_ClearingVcardModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingVcardModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingVcardModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingVcardModel.stringdata0))
        return static_cast<void*>(this);
    return ClearingModel::qt_metacast(_clname);
}

int ClearingVcardModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ClearingModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingHistoryModel_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingHistoryModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingHistoryModel_t qt_meta_stringdata_ClearingHistoryModel = {
    {
QT_MOC_LITERAL(0, 0, 20) // "ClearingHistoryModel"

    },
    "ClearingHistoryModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingHistoryModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingHistoryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingHistoryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<ClearingModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingHistoryModel.data,
    qt_meta_data_ClearingHistoryModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingHistoryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingHistoryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingHistoryModel.stringdata0))
        return static_cast<void*>(this);
    return ClearingModel::qt_metacast(_clname);
}

int ClearingHistoryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ClearingModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingAvatarModel_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingAvatarModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingAvatarModel_t qt_meta_stringdata_ClearingAvatarModel = {
    {
QT_MOC_LITERAL(0, 0, 19) // "ClearingAvatarModel"

    },
    "ClearingAvatarModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingAvatarModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingAvatarModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingAvatarModel::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseFileModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingAvatarModel.data,
    qt_meta_data_ClearingAvatarModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingAvatarModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingAvatarModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingAvatarModel.stringdata0))
        return static_cast<void*>(this);
    return BaseFileModel::qt_metacast(_clname);
}

int ClearingAvatarModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseFileModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingOptionsModel_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingOptionsModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingOptionsModel_t qt_meta_stringdata_ClearingOptionsModel = {
    {
QT_MOC_LITERAL(0, 0, 20) // "ClearingOptionsModel"

    },
    "ClearingOptionsModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingOptionsModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingOptionsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingOptionsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingOptionsModel.data,
    qt_meta_data_ClearingOptionsModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingOptionsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingOptionsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingOptionsModel.stringdata0))
        return static_cast<void*>(this);
    return BaseModel::qt_metacast(_clname);
}

int ClearingOptionsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ClearingProxyModel_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClearingProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClearingProxyModel_t qt_meta_stringdata_ClearingProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 18) // "ClearingProxyModel"

    },
    "ClearingProxyModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClearingProxyModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ClearingProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ClearingProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_meta_stringdata_ClearingProxyModel.data,
    qt_meta_data_ClearingProxyModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClearingProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClearingProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClearingProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int ClearingProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
