/********************************************************************************
** Form generated from reading UI file 'options.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONS_H
#define UI_OPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *cb_menu;
    QCheckBox *cb_action;
    QSpacerItem *verticalSpacer;
    QLabel *wiki;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QString::fromUtf8("Options"));
        Options->resize(352, 119);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        cb_menu = new QCheckBox(Options);
        cb_menu->setObjectName(QString::fromUtf8("cb_menu"));

        verticalLayout->addWidget(cb_menu);

        cb_action = new QCheckBox(Options);
        cb_action->setObjectName(QString::fromUtf8("cb_action"));

        verticalLayout->addWidget(cb_action);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        wiki = new QLabel(Options);
        wiki->setObjectName(QString::fromUtf8("wiki"));
        wiki->setOpenExternalLinks(true);

        verticalLayout->addWidget(wiki);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        Options->setWindowTitle(QCoreApplication::translate("Options", "Form", nullptr));
        cb_menu->setText(QCoreApplication::translate("Options", "Contact menu", nullptr));
        cb_action->setText(QCoreApplication::translate("Options", "Toolbar action", nullptr));
        wiki->setText(QCoreApplication::translate("Options", "<a href=\"http://psi-plus.com/wiki/plugins#extended_menu_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPTIONS_H
