/****************************************************************************
** Meta object code from reading C++ file 'cleaner.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../cleaner.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cleaner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CleanerMainWindow_t {
    QByteArrayData data[20];
    char stringdata0[242];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CleanerMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CleanerMainWindow_t qt_meta_stringdata_CleanerMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 17), // "CleanerMainWindow"
QT_MOC_LITERAL(1, 18, 19), // "deleteButtonPressed"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 12), // "deleteVcards"
QT_MOC_LITERAL(4, 52, 13), // "deleteHistory"
QT_MOC_LITERAL(5, 66, 13), // "deleteAvatars"
QT_MOC_LITERAL(6, 80, 13), // "deleteOptions"
QT_MOC_LITERAL(7, 94, 11), // "filterEvent"
QT_MOC_LITERAL(8, 106, 9), // "viewVcard"
QT_MOC_LITERAL(9, 116, 11), // "QModelIndex"
QT_MOC_LITERAL(10, 128, 5), // "index"
QT_MOC_LITERAL(11, 134, 11), // "viewHistory"
QT_MOC_LITERAL(12, 146, 10), // "viewAvatar"
QT_MOC_LITERAL(13, 157, 16), // "chooseProfileAct"
QT_MOC_LITERAL(14, 174, 10), // "clearJuick"
QT_MOC_LITERAL(15, 185, 12), // "clearBirhday"
QT_MOC_LITERAL(16, 198, 17), // "currentTabChanged"
QT_MOC_LITERAL(17, 216, 3), // "tab"
QT_MOC_LITERAL(18, 220, 9), // "selectAll"
QT_MOC_LITERAL(19, 230, 11) // "unselectAll"

    },
    "CleanerMainWindow\0deleteButtonPressed\0"
    "\0deleteVcards\0deleteHistory\0deleteAvatars\0"
    "deleteOptions\0filterEvent\0viewVcard\0"
    "QModelIndex\0index\0viewHistory\0viewAvatar\0"
    "chooseProfileAct\0clearJuick\0clearBirhday\0"
    "currentTabChanged\0tab\0selectAll\0"
    "unselectAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CleanerMainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x08 /* Private */,
       3,    0,   90,    2, 0x08 /* Private */,
       4,    0,   91,    2, 0x08 /* Private */,
       5,    0,   92,    2, 0x08 /* Private */,
       6,    0,   93,    2, 0x08 /* Private */,
       7,    0,   94,    2, 0x08 /* Private */,
       8,    1,   95,    2, 0x08 /* Private */,
      11,    1,   98,    2, 0x08 /* Private */,
      12,    1,  101,    2, 0x08 /* Private */,
      13,    0,  104,    2, 0x08 /* Private */,
      14,    0,  105,    2, 0x08 /* Private */,
      15,    0,  106,    2, 0x08 /* Private */,
      16,    1,  107,    2, 0x08 /* Private */,
      18,    0,  110,    2, 0x08 /* Private */,
      19,    0,  111,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CleanerMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CleanerMainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->deleteButtonPressed(); break;
        case 1: _t->deleteVcards(); break;
        case 2: _t->deleteHistory(); break;
        case 3: _t->deleteAvatars(); break;
        case 4: _t->deleteOptions(); break;
        case 5: _t->filterEvent(); break;
        case 6: _t->viewVcard((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->viewHistory((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 8: _t->viewAvatar((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 9: _t->chooseProfileAct(); break;
        case 10: _t->clearJuick(); break;
        case 11: _t->clearBirhday(); break;
        case 12: _t->currentTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->selectAll(); break;
        case 14: _t->unselectAll(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CleanerMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_CleanerMainWindow.data,
    qt_meta_data_CleanerMainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CleanerMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CleanerMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CleanerMainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int CleanerMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
