/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_settings
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pb_editJids;
    QSpacerItem *horizontalSpacer_2;
    QGridLayout *gridLayout;
    QLabel *label_6;
    QLabel *label_7;
    QLabel *label_8;
    QLabel *label_9;
    QLabel *label;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *cb_nameBold;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_13;
    QCheckBox *cb_nameItalic;
    QSpacerItem *horizontalSpacer_14;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_23;
    QCheckBox *cb_nameUnderline;
    QSpacerItem *horizontalSpacer_28;
    QToolButton *tb_name;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *cb_tagBold;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_9;
    QSpacerItem *horizontalSpacer_15;
    QCheckBox *cb_tagItalic;
    QSpacerItem *horizontalSpacer_16;
    QHBoxLayout *horizontalLayout_14;
    QSpacerItem *horizontalSpacer_24;
    QCheckBox *cb_tagUnderline;
    QSpacerItem *horizontalSpacer_29;
    QToolButton *tb_tag;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_7;
    QCheckBox *cb_messageBold;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_10;
    QSpacerItem *horizontalSpacer_17;
    QCheckBox *cb_messageItalic;
    QSpacerItem *horizontalSpacer_18;
    QHBoxLayout *horizontalLayout_15;
    QSpacerItem *horizontalSpacer_25;
    QCheckBox *cb_messageUnderline;
    QSpacerItem *horizontalSpacer_30;
    QToolButton *tb_message;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_9;
    QCheckBox *cb_quoteBold;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayout_11;
    QSpacerItem *horizontalSpacer_19;
    QCheckBox *cb_quoteItalic;
    QSpacerItem *horizontalSpacer_20;
    QHBoxLayout *horizontalLayout_16;
    QSpacerItem *horizontalSpacer_26;
    QCheckBox *cb_quoteUnderline;
    QSpacerItem *horizontalSpacer_31;
    QToolButton *tb_quote;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer_11;
    QCheckBox *cb_linkBold;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *horizontalLayout_12;
    QSpacerItem *horizontalSpacer_21;
    QCheckBox *cb_linkItalic;
    QSpacerItem *horizontalSpacer_22;
    QHBoxLayout *horizontalLayout_17;
    QSpacerItem *horizontalSpacer_27;
    QCheckBox *cb_linkUnderline;
    QSpacerItem *horizontalSpacer_32;
    QToolButton *tb_link;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *cb_idAsResource;
    QCheckBox *cb_showPhoto;
    QCheckBox *cb_showAvatar;
    QCheckBox *cb_conference;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer;
    QPushButton *pb_clearCache;
    QLabel *label_10;

    void setupUi(QWidget *settings)
    {
        if (settings->objectName().isEmpty())
            settings->setObjectName(QString::fromUtf8("settings"));
        settings->resize(501, 417);
        verticalLayout_3 = new QVBoxLayout(settings);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pb_editJids = new QPushButton(settings);
        pb_editJids->setObjectName(QString::fromUtf8("pb_editJids"));

        horizontalLayout->addWidget(pb_editJids);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_6 = new QLabel(settings);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label_6->setFont(font);
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_6, 0, 1, 1, 1);

        label_7 = new QLabel(settings);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        QFont font1;
        font1.setItalic(true);
        label_7->setFont(font1);
        label_7->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_7, 0, 2, 1, 1);

        label_8 = new QLabel(settings);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        QFont font2;
        font2.setUnderline(true);
        label_8->setFont(font2);
        label_8->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_8, 0, 3, 1, 1);

        label_9 = new QLabel(settings);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_9, 0, 4, 1, 1);

        label = new QLabel(settings);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);

        cb_nameBold = new QCheckBox(settings);
        cb_nameBold->setObjectName(QString::fromUtf8("cb_nameBold"));
        cb_nameBold->setText(QString::fromUtf8(""));

        horizontalLayout_3->addWidget(cb_nameBold);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_3, 1, 1, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_13);

        cb_nameItalic = new QCheckBox(settings);
        cb_nameItalic->setObjectName(QString::fromUtf8("cb_nameItalic"));
        cb_nameItalic->setText(QString::fromUtf8(""));

        horizontalLayout_8->addWidget(cb_nameItalic);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_14);


        gridLayout->addLayout(horizontalLayout_8, 1, 2, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName(QString::fromUtf8("horizontalLayout_13"));
        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_23);

        cb_nameUnderline = new QCheckBox(settings);
        cb_nameUnderline->setObjectName(QString::fromUtf8("cb_nameUnderline"));
        cb_nameUnderline->setText(QString::fromUtf8(""));

        horizontalLayout_13->addWidget(cb_nameUnderline);

        horizontalSpacer_28 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_28);


        gridLayout->addLayout(horizontalLayout_13, 1, 3, 1, 1);

        tb_name = new QToolButton(settings);
        tb_name->setObjectName(QString::fromUtf8("tb_name"));

        gridLayout->addWidget(tb_name, 1, 4, 1, 1);

        label_2 = new QLabel(settings);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);

        cb_tagBold = new QCheckBox(settings);
        cb_tagBold->setObjectName(QString::fromUtf8("cb_tagBold"));
        cb_tagBold->setText(QString::fromUtf8(""));

        horizontalLayout_4->addWidget(cb_tagBold);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_6);


        gridLayout->addLayout(horizontalLayout_4, 2, 1, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName(QString::fromUtf8("horizontalLayout_9"));
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_15);

        cb_tagItalic = new QCheckBox(settings);
        cb_tagItalic->setObjectName(QString::fromUtf8("cb_tagItalic"));
        cb_tagItalic->setText(QString::fromUtf8(""));

        horizontalLayout_9->addWidget(cb_tagItalic);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_16);


        gridLayout->addLayout(horizontalLayout_9, 2, 2, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName(QString::fromUtf8("horizontalLayout_14"));
        horizontalSpacer_24 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_24);

        cb_tagUnderline = new QCheckBox(settings);
        cb_tagUnderline->setObjectName(QString::fromUtf8("cb_tagUnderline"));
        cb_tagUnderline->setText(QString::fromUtf8(""));

        horizontalLayout_14->addWidget(cb_tagUnderline);

        horizontalSpacer_29 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_29);


        gridLayout->addLayout(horizontalLayout_14, 2, 3, 1, 1);

        tb_tag = new QToolButton(settings);
        tb_tag->setObjectName(QString::fromUtf8("tb_tag"));

        gridLayout->addWidget(tb_tag, 2, 4, 1, 1);

        label_3 = new QLabel(settings);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_7);

        cb_messageBold = new QCheckBox(settings);
        cb_messageBold->setObjectName(QString::fromUtf8("cb_messageBold"));
        cb_messageBold->setText(QString::fromUtf8(""));

        horizontalLayout_5->addWidget(cb_messageBold);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_8);


        gridLayout->addLayout(horizontalLayout_5, 3, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName(QString::fromUtf8("horizontalLayout_10"));
        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_17);

        cb_messageItalic = new QCheckBox(settings);
        cb_messageItalic->setObjectName(QString::fromUtf8("cb_messageItalic"));
        cb_messageItalic->setText(QString::fromUtf8(""));

        horizontalLayout_10->addWidget(cb_messageItalic);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_18);


        gridLayout->addLayout(horizontalLayout_10, 3, 2, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName(QString::fromUtf8("horizontalLayout_15"));
        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_25);

        cb_messageUnderline = new QCheckBox(settings);
        cb_messageUnderline->setObjectName(QString::fromUtf8("cb_messageUnderline"));
        cb_messageUnderline->setText(QString::fromUtf8(""));

        horizontalLayout_15->addWidget(cb_messageUnderline);

        horizontalSpacer_30 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_30);


        gridLayout->addLayout(horizontalLayout_15, 3, 3, 1, 1);

        tb_message = new QToolButton(settings);
        tb_message->setObjectName(QString::fromUtf8("tb_message"));

        gridLayout->addWidget(tb_message, 3, 4, 1, 1);

        label_4 = new QLabel(settings);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_4, 4, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_9);

        cb_quoteBold = new QCheckBox(settings);
        cb_quoteBold->setObjectName(QString::fromUtf8("cb_quoteBold"));
        cb_quoteBold->setText(QString::fromUtf8(""));

        horizontalLayout_6->addWidget(cb_quoteBold);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_10);


        gridLayout->addLayout(horizontalLayout_6, 4, 1, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName(QString::fromUtf8("horizontalLayout_11"));
        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_19);

        cb_quoteItalic = new QCheckBox(settings);
        cb_quoteItalic->setObjectName(QString::fromUtf8("cb_quoteItalic"));
        cb_quoteItalic->setText(QString::fromUtf8(""));

        horizontalLayout_11->addWidget(cb_quoteItalic);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_20);


        gridLayout->addLayout(horizontalLayout_11, 4, 2, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName(QString::fromUtf8("horizontalLayout_16"));
        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_26);

        cb_quoteUnderline = new QCheckBox(settings);
        cb_quoteUnderline->setObjectName(QString::fromUtf8("cb_quoteUnderline"));
        cb_quoteUnderline->setText(QString::fromUtf8(""));

        horizontalLayout_16->addWidget(cb_quoteUnderline);

        horizontalSpacer_31 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_31);


        gridLayout->addLayout(horizontalLayout_16, 4, 3, 1, 1);

        tb_quote = new QToolButton(settings);
        tb_quote->setObjectName(QString::fromUtf8("tb_quote"));

        gridLayout->addWidget(tb_quote, 4, 4, 1, 1);

        label_5 = new QLabel(settings);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_11);

        cb_linkBold = new QCheckBox(settings);
        cb_linkBold->setObjectName(QString::fromUtf8("cb_linkBold"));
        cb_linkBold->setText(QString::fromUtf8(""));

        horizontalLayout_7->addWidget(cb_linkBold);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_12);


        gridLayout->addLayout(horizontalLayout_7, 5, 1, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName(QString::fromUtf8("horizontalLayout_12"));
        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_21);

        cb_linkItalic = new QCheckBox(settings);
        cb_linkItalic->setObjectName(QString::fromUtf8("cb_linkItalic"));
        cb_linkItalic->setText(QString::fromUtf8(""));

        horizontalLayout_12->addWidget(cb_linkItalic);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_22);


        gridLayout->addLayout(horizontalLayout_12, 5, 2, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName(QString::fromUtf8("horizontalLayout_17"));
        horizontalSpacer_27 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_27);

        cb_linkUnderline = new QCheckBox(settings);
        cb_linkUnderline->setObjectName(QString::fromUtf8("cb_linkUnderline"));
        cb_linkUnderline->setText(QString::fromUtf8(""));

        horizontalLayout_17->addWidget(cb_linkUnderline);

        horizontalSpacer_32 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_32);


        gridLayout->addLayout(horizontalLayout_17, 5, 3, 1, 1);

        tb_link = new QToolButton(settings);
        tb_link->setObjectName(QString::fromUtf8("tb_link"));

        gridLayout->addWidget(tb_link, 5, 4, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        cb_idAsResource = new QCheckBox(settings);
        cb_idAsResource->setObjectName(QString::fromUtf8("cb_idAsResource"));

        verticalLayout->addWidget(cb_idAsResource);

        cb_showPhoto = new QCheckBox(settings);
        cb_showPhoto->setObjectName(QString::fromUtf8("cb_showPhoto"));

        verticalLayout->addWidget(cb_showPhoto);

        cb_showAvatar = new QCheckBox(settings);
        cb_showAvatar->setObjectName(QString::fromUtf8("cb_showAvatar"));

        verticalLayout->addWidget(cb_showAvatar);

        cb_conference = new QCheckBox(settings);
        cb_conference->setObjectName(QString::fromUtf8("cb_conference"));

        verticalLayout->addWidget(cb_conference);


        horizontalLayout_2->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        pb_clearCache = new QPushButton(settings);
        pb_clearCache->setObjectName(QString::fromUtf8("pb_clearCache"));

        verticalLayout_2->addWidget(pb_clearCache);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        label_10 = new QLabel(settings);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_10);


        retranslateUi(settings);

        QMetaObject::connectSlotsByName(settings);
    } // setupUi

    void retranslateUi(QWidget *settings)
    {
        settings->setWindowTitle(QCoreApplication::translate("settings", "settings", nullptr));
        pb_editJids->setText(QCoreApplication::translate("settings", "Edit JIDs", nullptr));
        label_6->setText(QCoreApplication::translate("settings", "bold", nullptr));
        label_7->setText(QCoreApplication::translate("settings", "italic", nullptr));
        label_8->setText(QCoreApplication::translate("settings", "underline", nullptr));
        label_9->setText(QCoreApplication::translate("settings", "color", nullptr));
        label->setText(QCoreApplication::translate("settings", "@username", nullptr));
        tb_name->setText(QString());
        label_2->setText(QCoreApplication::translate("settings", "*tag", nullptr));
        tb_tag->setText(QString());
        label_3->setText(QCoreApplication::translate("settings", "#message id", nullptr));
        tb_message->setText(QString());
        label_4->setText(QCoreApplication::translate("settings", ">quote", nullptr));
        tb_quote->setText(QString());
        label_5->setText(QCoreApplication::translate("settings", "http://link", nullptr));
        tb_link->setText(QString());
        cb_idAsResource->setText(QCoreApplication::translate("settings", "Use message Id as resource", nullptr));
        cb_showPhoto->setText(QCoreApplication::translate("settings", "Show Photo", nullptr));
        cb_showAvatar->setText(QCoreApplication::translate("settings", "Show Avatars", nullptr));
        cb_conference->setText(QCoreApplication::translate("settings", "Replaces message id with a link\n"
"to this message in juick@conference.jabber.ru", nullptr));
        pb_clearCache->setText(QCoreApplication::translate("settings", "Clear avatar cache", nullptr));
        label_10->setText(QCoreApplication::translate("settings", "<a href=\"http://psi-plus.com/wiki/plugins#juick_plugin\">Wiki (Online)</a>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class settings: public Ui_settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGS_H
