/****************************************************************************
** Meta object code from reading C++ file 'screenshot.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../screenshot.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screenshot.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Screenshot_t {
    QByteArrayData data[33];
    char stringdata0[387];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Screenshot_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Screenshot_t qt_meta_stringdata_Screenshot = {
    {
QT_MOC_LITERAL(0, 0, 10), // "Screenshot"
QT_MOC_LITERAL(1, 11, 11), // "shootScreen"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 9), // "openImage"
QT_MOC_LITERAL(4, 34, 13), // "newScreenshot"
QT_MOC_LITERAL(5, 48, 14), // "saveScreenshot"
QT_MOC_LITERAL(6, 63, 16), // "uploadScreenshot"
QT_MOC_LITERAL(7, 80, 15), // "printScreenshot"
QT_MOC_LITERAL(8, 96, 12), // "cancelUpload"
QT_MOC_LITERAL(9, 109, 20), // "dataTransferProgress"
QT_MOC_LITERAL(10, 130, 4), // "done"
QT_MOC_LITERAL(11, 135, 5), // "total"
QT_MOC_LITERAL(12, 141, 16), // "ftpReplyFinished"
QT_MOC_LITERAL(13, 158, 17), // "httpReplyFinished"
QT_MOC_LITERAL(14, 176, 14), // "QNetworkReply*"
QT_MOC_LITERAL(15, 191, 14), // "captureDesktop"
QT_MOC_LITERAL(16, 206, 13), // "captureWindow"
QT_MOC_LITERAL(17, 220, 11), // "captureArea"
QT_MOC_LITERAL(18, 232, 11), // "shootWindow"
QT_MOC_LITERAL(19, 244, 9), // "shootArea"
QT_MOC_LITERAL(20, 254, 18), // "screenshotCanceled"
QT_MOC_LITERAL(21, 273, 14), // "pixmapAdjusted"
QT_MOC_LITERAL(22, 288, 8), // "fixSizes"
QT_MOC_LITERAL(23, 297, 11), // "setModified"
QT_MOC_LITERAL(24, 309, 1), // "m"
QT_MOC_LITERAL(25, 311, 7), // "aboutQt"
QT_MOC_LITERAL(26, 319, 10), // "doHomePage"
QT_MOC_LITERAL(27, 330, 9), // "doHistory"
QT_MOC_LITERAL(28, 340, 9), // "doOptions"
QT_MOC_LITERAL(29, 350, 15), // "settingsChanged"
QT_MOC_LITERAL(30, 366, 6), // "option"
QT_MOC_LITERAL(31, 373, 5), // "value"
QT_MOC_LITERAL(32, 379, 7) // "copyUrl"

    },
    "Screenshot\0shootScreen\0\0openImage\0"
    "newScreenshot\0saveScreenshot\0"
    "uploadScreenshot\0printScreenshot\0"
    "cancelUpload\0dataTransferProgress\0"
    "done\0total\0ftpReplyFinished\0"
    "httpReplyFinished\0QNetworkReply*\0"
    "captureDesktop\0captureWindow\0captureArea\0"
    "shootWindow\0shootArea\0screenshotCanceled\0"
    "pixmapAdjusted\0fixSizes\0setModified\0"
    "m\0aboutQt\0doHomePage\0doHistory\0doOptions\0"
    "settingsChanged\0option\0value\0copyUrl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Screenshot[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x0a /* Public */,
       3,    0,  140,    2, 0x0a /* Public */,
       4,    0,  141,    2, 0x0a /* Public */,
       5,    0,  142,    2, 0x08 /* Private */,
       6,    0,  143,    2, 0x08 /* Private */,
       7,    0,  144,    2, 0x08 /* Private */,
       8,    0,  145,    2, 0x08 /* Private */,
       9,    2,  146,    2, 0x08 /* Private */,
      12,    0,  151,    2, 0x08 /* Private */,
      13,    1,  152,    2, 0x08 /* Private */,
      15,    1,  155,    2, 0x08 /* Private */,
      16,    1,  158,    2, 0x08 /* Private */,
      17,    1,  161,    2, 0x08 /* Private */,
      18,    0,  164,    2, 0x08 /* Private */,
      19,    0,  165,    2, 0x08 /* Private */,
      20,    0,  166,    2, 0x08 /* Private */,
      21,    0,  167,    2, 0x08 /* Private */,
      22,    0,  168,    2, 0x08 /* Private */,
      23,    1,  169,    2, 0x08 /* Private */,
      25,    0,  172,    2, 0x08 /* Private */,
      26,    0,  173,    2, 0x08 /* Private */,
      27,    0,  174,    2, 0x08 /* Private */,
      28,    0,  175,    2, 0x08 /* Private */,
      29,    2,  176,    2, 0x08 /* Private */,
      32,    0,  181,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong, QMetaType::LongLong,   10,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   30,   31,
    QMetaType::Void,

       0        // eod
};

void Screenshot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Screenshot *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->shootScreen(); break;
        case 1: _t->openImage(); break;
        case 2: _t->newScreenshot(); break;
        case 3: _t->saveScreenshot(); break;
        case 4: _t->uploadScreenshot(); break;
        case 5: _t->printScreenshot(); break;
        case 6: _t->cancelUpload(); break;
        case 7: _t->dataTransferProgress((*reinterpret_cast< qint64(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 8: _t->ftpReplyFinished(); break;
        case 9: _t->httpReplyFinished((*reinterpret_cast< QNetworkReply*(*)>(_a[1]))); break;
        case 10: _t->captureDesktop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->captureWindow((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->captureArea((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->shootWindow(); break;
        case 14: _t->shootArea(); break;
        case 15: _t->screenshotCanceled(); break;
        case 16: _t->pixmapAdjusted(); break;
        case 17: _t->fixSizes(); break;
        case 18: _t->setModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->aboutQt(); break;
        case 20: _t->doHomePage(); break;
        case 21: _t->doHistory(); break;
        case 22: _t->doOptions(); break;
        case 23: _t->settingsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 24: _t->copyUrl(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Screenshot::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_Screenshot.data,
    qt_meta_data_Screenshot,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Screenshot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Screenshot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Screenshot.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int Screenshot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
