/****************************************************************************
** Meta object code from reading C++ file 'gomokugameplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../gomokugameplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gomokugameplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GomokuGamePlugin_t {
    QByteArrayData data[14];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GomokuGamePlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GomokuGamePlugin_t qt_meta_stringdata_GomokuGamePlugin = {
    {
QT_MOC_LITERAL(0, 0, 16), // "GomokuGamePlugin"
QT_MOC_LITERAL(1, 17, 17), // "toolButtonPressed"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 13), // "menuActivated"
QT_MOC_LITERAL(4, 50, 10), // "doPsiEvent"
QT_MOC_LITERAL(5, 61, 11), // "const char*"
QT_MOC_LITERAL(6, 73, 14), // "sendGameStanza"
QT_MOC_LITERAL(7, 88, 7), // "account"
QT_MOC_LITERAL(8, 96, 6), // "stanza"
QT_MOC_LITERAL(9, 103, 9), // "testSound"
QT_MOC_LITERAL(10, 113, 8), // "getSound"
QT_MOC_LITERAL(11, 122, 7), // "doPopup"
QT_MOC_LITERAL(12, 130, 4), // "text"
QT_MOC_LITERAL(13, 135, 9) // "playSound"

    },
    "GomokuGamePlugin\0toolButtonPressed\0\0"
    "menuActivated\0doPsiEvent\0const char*\0"
    "sendGameStanza\0account\0stanza\0testSound\0"
    "getSound\0doPopup\0text\0playSound"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GomokuGamePlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x08 /* Private */,
       3,    0,   55,    2, 0x08 /* Private */,
       4,    5,   56,    2, 0x08 /* Private */,
       6,    2,   67,    2, 0x08 /* Private */,
       9,    0,   72,    2, 0x08 /* Private */,
      10,    0,   73,    2, 0x08 /* Private */,
      11,    1,   74,    2, 0x08 /* Private */,
      13,    1,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QObjectStar, 0x80000000 | 5,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void GomokuGamePlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GomokuGamePlugin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->toolButtonPressed(); break;
        case 1: _t->menuActivated(); break;
        case 2: _t->doPsiEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QObject*(*)>(_a[4])),(*reinterpret_cast< const char*(*)>(_a[5]))); break;
        case 3: _t->sendGameStanza((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->testSound(); break;
        case 5: _t->getSound(); break;
        case 6: _t->doPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->playSound((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject GomokuGamePlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_GomokuGamePlugin.data,
    qt_meta_data_GomokuGamePlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *GomokuGamePlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GomokuGamePlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GomokuGamePlugin.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PsiPlugin"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "PluginInfoProvider"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "OptionAccessor"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "IconFactoryAccessor"))
        return static_cast< IconFactoryAccessor*>(this);
    if (!strcmp(_clname, "ToolbarIconAccessor"))
        return static_cast< ToolbarIconAccessor*>(this);
    if (!strcmp(_clname, "ActiveTabAccessor"))
        return static_cast< ActiveTabAccessor*>(this);
    if (!strcmp(_clname, "AccountInfoAccessor"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "ContactInfoAccessor"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "StanzaSender"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "StanzaFilter"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "EventCreator"))
        return static_cast< EventCreator*>(this);
    if (!strcmp(_clname, "SoundAccessor"))
        return static_cast< SoundAccessor*>(this);
    if (!strcmp(_clname, "MenuAccessor"))
        return static_cast< MenuAccessor*>(this);
    if (!strcmp(_clname, "PopupAccessor"))
        return static_cast< PopupAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.PsiPlugin/0.4"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "org.psi-im.PluginInfoProvider/0.1"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "org.psi-im.OptionAccessor/0.1"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.IconFactoryAccessor/0.1"))
        return static_cast< IconFactoryAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.ToolbarIconAccessor/0.1"))
        return static_cast< ToolbarIconAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.ActiveTabAccessor/0.1"))
        return static_cast< ActiveTabAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.AccountInfoAccessor/0.1"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.ContactInfoAccessor/0.1"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaSender/0.1"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaFilter/0.1"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "org.psi-im.EventCreator/0.1"))
        return static_cast< EventCreator*>(this);
    if (!strcmp(_clname, "org.psi-im.SoundAccessor/0.1"))
        return static_cast< SoundAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.MenuAccessor/0.1"))
        return static_cast< MenuAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.PopupAccessor/0.1"))
        return static_cast< PopupAccessor*>(this);
    return QObject::qt_metacast(_clname);
}

int GomokuGamePlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

QT_PLUGIN_METADATA_SECTION
static constexpr unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1d,  'c',  'o',  'm',  '.',  'p', 
    's',  'i',  '-',  'p',  'l',  'u',  's',  '.', 
    'G',  'o',  'm',  'o',  'k',  'u',  'G',  'a', 
    'm',  'e',  'P',  'l',  'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x70,  'G',  'o',  'm',  'o',  'k',  'u', 
    'G',  'a',  'm',  'e',  'P',  'l',  'u',  'g', 
    'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(GomokuGamePlugin, GomokuGamePlugin)

QT_WARNING_POP
QT_END_MOC_NAMESPACE
