/********************************************************************************
** Form generated from reading UI file 'clearingtab.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLEARINGTAB_H
#define UI_CLEARINGTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "viewers.h"

QT_BEGIN_NAMESPACE

class Ui_ClearingTab
{
public:
    QVBoxLayout *verticalLayout;
    ClearingViewer *tv_table;

    void setupUi(QWidget *ClearingTab)
    {
        if (ClearingTab->objectName().isEmpty())
            ClearingTab->setObjectName(QString::fromUtf8("ClearingTab"));
        ClearingTab->resize(591, 429);
        verticalLayout = new QVBoxLayout(ClearingTab);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tv_table = new ClearingViewer(ClearingTab);
        tv_table->setObjectName(QString::fromUtf8("tv_table"));
        tv_table->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout->addWidget(tv_table);


        retranslateUi(ClearingTab);

        QMetaObject::connectSlotsByName(ClearingTab);
    } // setupUi

    void retranslateUi(QWidget *ClearingTab)
    {
        ClearingTab->setWindowTitle(QCoreApplication::translate("ClearingTab", "Form", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClearingTab: public Ui_ClearingTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLEARINGTAB_H
