/********************************************************************************
** Form generated from reading UI file 'juickjidlist.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JUICKJIDLIST_H
#define UI_JUICKJIDLIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_JuickJidDialog
{
public:
    QHBoxLayout *horizontalLayout;
    QListWidget *listWidget;
    QVBoxLayout *verticalLayout;
    QPushButton *pb_add;
    QPushButton *pb_del;
    QSpacerItem *verticalSpacer;
    QPushButton *pb_ok;

    void setupUi(QDialog *JuickJidDialog)
    {
        if (JuickJidDialog->objectName().isEmpty())
            JuickJidDialog->setObjectName(QString::fromUtf8("JuickJidDialog"));
        JuickJidDialog->setWindowModality(Qt::WindowModal);
        JuickJidDialog->resize(367, 210);
        horizontalLayout = new QHBoxLayout(JuickJidDialog);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        listWidget = new QListWidget(JuickJidDialog);
        listWidget->setObjectName(QString::fromUtf8("listWidget"));

        horizontalLayout->addWidget(listWidget);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        pb_add = new QPushButton(JuickJidDialog);
        pb_add->setObjectName(QString::fromUtf8("pb_add"));

        verticalLayout->addWidget(pb_add);

        pb_del = new QPushButton(JuickJidDialog);
        pb_del->setObjectName(QString::fromUtf8("pb_del"));

        verticalLayout->addWidget(pb_del);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        pb_ok = new QPushButton(JuickJidDialog);
        pb_ok->setObjectName(QString::fromUtf8("pb_ok"));

        verticalLayout->addWidget(pb_ok);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(JuickJidDialog);

        QMetaObject::connectSlotsByName(JuickJidDialog);
    } // setupUi

    void retranslateUi(QDialog *JuickJidDialog)
    {
        JuickJidDialog->setWindowTitle(QCoreApplication::translate("JuickJidDialog", "Set JIDs of Juick Bot", nullptr));
        pb_add->setText(QCoreApplication::translate("JuickJidDialog", "Add", nullptr));
        pb_del->setText(QCoreApplication::translate("JuickJidDialog", "Delete", nullptr));
        pb_ok->setText(QCoreApplication::translate("JuickJidDialog", "OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JuickJidDialog: public Ui_JuickJidDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_JUICKJIDLIST_H
