/********************************************************************************
** Form generated from reading UI file 'addkeydlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.14
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDKEYDLG_H
#define UI_ADDKEYDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include "datewidget.h"

QT_BEGIN_NAMESPACE

class Ui_AddKeyDlg
{
public:
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *label_5;
    QLabel *lblExpiration;
    QLineEdit *linePass2;
    QDialogButtonBox *btnBox;
    QLineEdit *lineName;
    QSpacerItem *verticalSpacer;
    QComboBox *cmbLength;
    QLineEdit *linePass;
    QLineEdit *lineComment;
    QComboBox *cmbType;
    QLabel *label_3;
    QLabel *label_7;
    QLabel *label_4;
    QLabel *label;
    QLineEdit *lineEmail;
    QLabel *label_8;
    DateWidget *dateExpiration;

    void setupUi(QDialog *AddKeyDlg)
    {
        if (AddKeyDlg->objectName().isEmpty())
            AddKeyDlg->setObjectName(QString::fromUtf8("AddKeyDlg"));
        AddKeyDlg->resize(390, 341);
        gridLayout = new QGridLayout(AddKeyDlg);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_2 = new QLabel(AddKeyDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        label_5 = new QLabel(AddKeyDlg);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        lblExpiration = new QLabel(AddKeyDlg);
        lblExpiration->setObjectName(QString::fromUtf8("lblExpiration"));

        gridLayout->addWidget(lblExpiration, 6, 0, 1, 1);

        linePass2 = new QLineEdit(AddKeyDlg);
        linePass2->setObjectName(QString::fromUtf8("linePass2"));
        linePass2->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(linePass2, 8, 1, 1, 1);

        btnBox = new QDialogButtonBox(AddKeyDlg);
        btnBox->setObjectName(QString::fromUtf8("btnBox"));
        btnBox->setOrientation(Qt::Horizontal);
        btnBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        btnBox->setCenterButtons(false);

        gridLayout->addWidget(btnBox, 10, 0, 1, 2);

        lineName = new QLineEdit(AddKeyDlg);
        lineName->setObjectName(QString::fromUtf8("lineName"));

        gridLayout->addWidget(lineName, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 9, 0, 1, 1);

        cmbLength = new QComboBox(AddKeyDlg);
        cmbLength->setObjectName(QString::fromUtf8("cmbLength"));
        cmbLength->setEditable(true);

        gridLayout->addWidget(cmbLength, 4, 1, 1, 1);

        linePass = new QLineEdit(AddKeyDlg);
        linePass->setObjectName(QString::fromUtf8("linePass"));
        linePass->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(linePass, 7, 1, 1, 1);

        lineComment = new QLineEdit(AddKeyDlg);
        lineComment->setObjectName(QString::fromUtf8("lineComment"));

        gridLayout->addWidget(lineComment, 2, 1, 1, 1);

        cmbType = new QComboBox(AddKeyDlg);
        cmbType->addItem(QString());
        cmbType->addItem(QString());
        cmbType->addItem(QString());
        cmbType->addItem(QString());
        cmbType->setObjectName(QString::fromUtf8("cmbType"));

        gridLayout->addWidget(cmbType, 3, 1, 1, 1);

        label_3 = new QLabel(AddKeyDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        label_7 = new QLabel(AddKeyDlg);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 7, 0, 1, 1);

        label_4 = new QLabel(AddKeyDlg);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        label = new QLabel(AddKeyDlg);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 3, 0, 1, 1);

        lineEmail = new QLineEdit(AddKeyDlg);
        lineEmail->setObjectName(QString::fromUtf8("lineEmail"));

        gridLayout->addWidget(lineEmail, 1, 1, 1, 1);

        label_8 = new QLabel(AddKeyDlg);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout->addWidget(label_8, 8, 0, 1, 1);

        dateExpiration = new DateWidget(AddKeyDlg);
        dateExpiration->setObjectName(QString::fromUtf8("dateExpiration"));

        gridLayout->addWidget(dateExpiration, 6, 1, 1, 1);

        QWidget::setTabOrder(lineName, lineEmail);
        QWidget::setTabOrder(lineEmail, lineComment);
        QWidget::setTabOrder(lineComment, cmbType);
        QWidget::setTabOrder(cmbType, cmbLength);
        QWidget::setTabOrder(cmbLength, dateExpiration);
        QWidget::setTabOrder(dateExpiration, linePass);
        QWidget::setTabOrder(linePass, linePass2);
        QWidget::setTabOrder(linePass2, btnBox);

        retranslateUi(AddKeyDlg);
        QObject::connect(btnBox, SIGNAL(accepted()), AddKeyDlg, SLOT(accept()));
        QObject::connect(btnBox, SIGNAL(rejected()), AddKeyDlg, SLOT(reject()));
        QObject::connect(linePass, SIGNAL(textEdited(QString)), AddKeyDlg, SLOT(checkPass()));
        QObject::connect(linePass2, SIGNAL(textEdited(QString)), AddKeyDlg, SLOT(checkPass()));
        QObject::connect(cmbType, SIGNAL(currentIndexChanged(QString)), AddKeyDlg, SLOT(fillLenght(QString)));

        cmbLength->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(AddKeyDlg);
    } // setupUi

    void retranslateUi(QDialog *AddKeyDlg)
    {
        AddKeyDlg->setWindowTitle(QCoreApplication::translate("AddKeyDlg", "Generate a new key pair", nullptr));
        label_2->setText(QCoreApplication::translate("AddKeyDlg", "Length: ", nullptr));
        label_5->setText(QCoreApplication::translate("AddKeyDlg", "Comment: ", nullptr));
        lblExpiration->setText(QCoreApplication::translate("AddKeyDlg", "Expiration date: ", nullptr));
        cmbType->setItemText(0, QCoreApplication::translate("AddKeyDlg", "RSA and RSA (default)", nullptr));
        cmbType->setItemText(1, QCoreApplication::translate("AddKeyDlg", "DSA and Elgamal", nullptr));
        cmbType->setItemText(2, QCoreApplication::translate("AddKeyDlg", "DSA (sign only)", nullptr));
        cmbType->setItemText(3, QCoreApplication::translate("AddKeyDlg", "RSA (sign only)", nullptr));

        label_3->setText(QCoreApplication::translate("AddKeyDlg", "Full name: ", nullptr));
        label_7->setText(QCoreApplication::translate("AddKeyDlg", "Passphrase: ", nullptr));
        label_4->setText(QCoreApplication::translate("AddKeyDlg", "E-mail address: ", nullptr));
        label->setText(QCoreApplication::translate("AddKeyDlg", "Key type: ", nullptr));
        label_8->setText(QCoreApplication::translate("AddKeyDlg", "Repeat: ", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddKeyDlg: public Ui_AddKeyDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDKEYDLG_H
