/****************************************************************************
** Meta object code from reading C++ file 'clientswitcherplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.14)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../clientswitcherplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clientswitcherplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.14. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ClientSwitcherPlugin_t {
    QByteArrayData data[10];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClientSwitcherPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClientSwitcherPlugin_t qt_meta_stringdata_ClientSwitcherPlugin = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ClientSwitcherPlugin"
QT_MOC_LITERAL(1, 21, 18), // "enableAccountsList"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 17), // "restoreOptionsAcc"
QT_MOC_LITERAL(4, 59, 16), // "enableMainParams"
QT_MOC_LITERAL(5, 76, 14), // "enableOsParams"
QT_MOC_LITERAL(6, 91, 18), // "enableClientParams"
QT_MOC_LITERAL(7, 110, 10), // "setNewCaps"
QT_MOC_LITERAL(8, 121, 11), // "viewFromOpt"
QT_MOC_LITERAL(9, 133, 11) // "onCloseView"

    },
    "ClientSwitcherPlugin\0enableAccountsList\0"
    "\0restoreOptionsAcc\0enableMainParams\0"
    "enableOsParams\0enableClientParams\0"
    "setNewCaps\0viewFromOpt\0onCloseView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClientSwitcherPlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       3,    1,   57,    2, 0x08 /* Private */,
       4,    1,   60,    2, 0x08 /* Private */,
       5,    1,   63,    2, 0x08 /* Private */,
       6,    1,   66,    2, 0x08 /* Private */,
       7,    1,   69,    2, 0x08 /* Private */,
       8,    0,   72,    2, 0x08 /* Private */,
       9,    2,   73,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,

       0        // eod
};

void ClientSwitcherPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ClientSwitcherPlugin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enableAccountsList((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->restoreOptionsAcc((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->enableMainParams((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->enableOsParams((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->enableClientParams((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setNewCaps((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->viewFromOpt(); break;
        case 7: _t->onCloseView((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ClientSwitcherPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ClientSwitcherPlugin.data,
    qt_meta_data_ClientSwitcherPlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClientSwitcherPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClientSwitcherPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClientSwitcherPlugin.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PsiPlugin"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "OptionAccessor"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "StanzaSender"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "StanzaFilter"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "PluginInfoProvider"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "PopupAccessor"))
        return static_cast< PopupAccessor*>(this);
    if (!strcmp(_clname, "ApplicationInfoAccessor"))
        return static_cast< ApplicationInfoAccessor*>(this);
    if (!strcmp(_clname, "AccountInfoAccessor"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "PsiAccountController"))
        return static_cast< PsiAccountController*>(this);
    if (!strcmp(_clname, "ContactInfoAccessor"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "IconFactoryAccessor"))
        return static_cast< IconFactoryAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.PsiPlugin/0.4"))
        return static_cast< PsiPlugin*>(this);
    if (!strcmp(_clname, "org.psi-im.OptionAccessor/0.1"))
        return static_cast< OptionAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaSender/0.1"))
        return static_cast< StanzaSender*>(this);
    if (!strcmp(_clname, "org.psi-im.StanzaFilter/0.1"))
        return static_cast< StanzaFilter*>(this);
    if (!strcmp(_clname, "org.psi-im.PluginInfoProvider/0.1"))
        return static_cast< PluginInfoProvider*>(this);
    if (!strcmp(_clname, "org.psi-im.PopupAccessor/0.1"))
        return static_cast< PopupAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.ApplicationInfoAccessor/0.1"))
        return static_cast< ApplicationInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.AccountInfoAccessor/0.1"))
        return static_cast< AccountInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.PsiAccountController/0.1"))
        return static_cast< PsiAccountController*>(this);
    if (!strcmp(_clname, "org.psi-im.ContactInfoAccessor/0.1"))
        return static_cast< ContactInfoAccessor*>(this);
    if (!strcmp(_clname, "org.psi-im.IconFactoryAccessor/0.1"))
        return static_cast< IconFactoryAccessor*>(this);
    return QObject::qt_metacast(_clname);
}

int ClientSwitcherPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

QT_PLUGIN_METADATA_SECTION
static constexpr unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x21,  'c',  'o',  'm',  '.',  'p', 
    's',  'i',  '-',  'p',  'l',  'u',  's',  '.', 
    'C',  'l',  'i',  'e',  'n',  't',  'S',  'w', 
    'i',  't',  'c',  'h',  'e',  'r',  'P',  'l', 
    'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x74,  'C',  'l',  'i',  'e',  'n',  't', 
    'S',  'w',  'i',  't',  'c',  'h',  'e',  'r', 
    'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(ClientSwitcherPlugin, ClientSwitcherPlugin)

QT_WARNING_POP
QT_END_MOC_NAMESPACE
